'use strict';

var tslib = require('tslib');
var React = require('react');
var i18nReactIntl = require('@cultureamp/i18n-react-intl');
require('../../Calendar/CalendarSingle/CalendarSingle.cjs');
require('../../Calendar/CalendarRange/CalendarRange.cjs');
require('date-fns');
var isInvalidDate = require('../../Calendar/utils/isInvalidDate.cjs');
var isDisabledDate = require('../../Calendar/utils/isDisabledDate.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var validateDate = function (_a) {
  var date = _a.date,
    inputValue = _a.inputValue,
    disabledDays = _a.disabledDays;
  var baseResponse = {
    date: date,
    inputValue: inputValue,
    status: undefined,
    validationMessage: undefined,
    isInvalid: false,
    isDisabled: false,
    isEmpty: false,
    isValidDate: false
  };
  if (date === undefined) {
    return {
      validationResponse: tslib.__assign(tslib.__assign({}, baseResponse), {
        isEmpty: true
      }),
      newDate: undefined
    };
  }
  if (isInvalidDate.isInvalidDate(date)) {
    return {
      validationResponse: tslib.__assign(tslib.__assign({}, baseResponse), {
        status: 'error',
        validationMessage: inputValue ? React__default.default.createElement(i18nReactIntl.FormattedMessage, {
          id: "date.validation.invalidDateWithValue",
          defaultMessage: "{inputValue} is an invalid date",
          description: "Error message when the user enters an invalid date and we know their input value",
          values: {
            inputValue: inputValue
          }
        }) : React__default.default.createElement(i18nReactIntl.FormattedMessage, {
          id: "date.validation.invalidDate",
          defaultMessage: "Date is invalid",
          description: "Error message when the user enters an invalid date and we do not know their input value"
        }),
        isInvalid: true
      }),
      newDate: undefined
    };
  }
  if (isDisabledDate.isDisabledDate(date, disabledDays)) {
    return {
      validationResponse: tslib.__assign(tslib.__assign({}, baseResponse), {
        status: 'error',
        validationMessage: React__default.default.createElement(i18nReactIntl.FormattedMessage, {
          id: "date.validation.unavailableDate",
          defaultMessage: "{inputValue} is not available, try another date",
          description: "Error message when the user tries to select a date that is unavailable",
          values: {
            inputValue: inputValue
          }
        }),
        isDisabled: true
      }),
      newDate: undefined
    };
  }
  return {
    validationResponse: tslib.__assign(tslib.__assign({}, baseResponse), {
      isValidDate: true
    }),
    newDate: date
  };
};
exports.validateDate = validateDate;
