'use strict';

var tslib = require('tslib');
var React = require('react');
var listbox = require('@react-aria/listbox');
var collections = require('@react-stately/collections');
var list = require('@react-stately/list');
var VisuallyHidden = require('../../../../VisuallyHidden/VisuallyHidden.cjs');
var MenuTriggerProvider = require('../MenuTriggerProvider/MenuTriggerProvider.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var SelectionContext = React__default.default.createContext({});
var SelectionProvider = function (props) {
  var onSearchInputChange = props.onSearchInputChange,
    otherProps = tslib.__rest(props, ["onSearchInputChange"]);
  var _a = React.useState(''),
    searchQuery = _a[0],
    setSearchQuery = _a[1];
  var menuProps = MenuTriggerProvider.useMenuTriggerContext().menuProps;
  /**
   * While the onSearchInputChange  is a side-effect, this useEffect should be fine.
   * If the search input state becomes controlled, this useEffect could cause synchronisation
   * issues and should be replaced.
   */
  React__default.default.useEffect(function () {
    if (onSearchInputChange) {
      onSearchInputChange(searchQuery);
    }
  }, [searchQuery, onSearchInputChange]);
  var searchFilter = React.useCallback(function (nodes) {
    return searchQuery ? Array.from(nodes).filter(function (f) {
      return f.textValue.toLowerCase().includes(searchQuery.toLowerCase());
    }) : nodes;
  }, [searchQuery]);
  // Create state based on the incoming props to manage the selection
  var state = list.useListState(tslib.__assign(tslib.__assign({}, otherProps), {
    children: function (item) {
      return React__default.default.createElement(collections.Item, {
        key: item.value
      }, item.label);
    },
    filter: onSearchInputChange ? undefined : searchFilter
  }));
  // Get A11y attributes and events for the listbox
  var ref = React__default.default.createRef();
  var _b = listbox.useListBox(tslib.__assign(tslib.__assign(tslib.__assign({}, menuProps), otherProps), {
      disallowEmptySelection: true
    }), state, ref),
    listBoxProps = _b.listBoxProps,
    labelProps = _b.labelProps;
  return React__default.default.createElement(SelectionContext.Provider, {
    value: {
      listBoxProps: listBoxProps,
      labelProps: labelProps,
      selectionState: state,
      listRef: ref,
      setSearchQuery: setSearchQuery,
      searchQuery: searchQuery
    }
  }, React__default.default.createElement(VisuallyHidden.VisuallyHidden, tslib.__assign({}, labelProps), otherProps.label), otherProps.children);
};
var useSelectionContext = function () {
  return React.useContext(SelectionContext);
};
var SelectionConsumer = function (_a) {
  var children = _a.children;
  return React__default.default.createElement(SelectionContext.Consumer, null, children);
};
exports.SelectionConsumer = SelectionConsumer;
exports.SelectionProvider = SelectionProvider;
exports.useSelectionContext = useSelectionContext;
