'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var SelectionProvider = require('../../context/SelectionProvider/SelectionProvider.cjs');
var ListBox_module = require('./ListBox.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var getItemsFromKeys = function (items, keys) {
  var itemKeys = Array.from(keys);
  return itemKeys.reduce(function (acc, itemKey) {
    var item = items.getItem(itemKey);
    return item ? tslib.__spreadArray(tslib.__spreadArray([], acc, true), [item], false) : acc;
  }, []);
};
var ListBox = function (_a) {
  var children = _a.children;
  var _b = SelectionProvider.useSelectionContext(),
    listBoxProps = _b.listBoxProps,
    listRef = _b.listRef,
    selectionState = _b.selectionState;
  var _c = React.useState(false),
    isOverflown = _c[0],
    setIsOverflown = _c[1];
  React.useEffect(function () {
    var listElement = listRef.current;
    if (!listElement) {
      return;
    }
    setIsOverflown(listElement.scrollHeight > listElement.clientHeight);
  }, [listRef]);
  var items = selectionState.collection,
    disabledKeys = selectionState.disabledKeys,
    selectedKeys = selectionState.selectionManager.selectedKeys;
  var disabledItems = getItemsFromKeys(items, disabledKeys);
  var selectedItems = getItemsFromKeys(items, selectedKeys);
  var unselectedItems = Array.from(items).filter(function (item) {
    return !disabledKeys.has(item.key) && !selectedKeys.has(item.key);
  });
  var allItems = Array.from(items);
  var hasNoItems = allItems.length === 0;
  var _d = React.useState({
      selectedItems: selectedItems,
      unselectedItems: unselectedItems,
      disabledItems: disabledItems,
      allItems: allItems,
      hasNoItems: hasNoItems
    }),
    itemsState = _d[0],
    setItemsState = _d[1];
  // Only update rendering of items when filtering.
  // Avoids re-ordering of items when making a selection
  React.useEffect(function () {
    setItemsState({
      selectedItems: selectedItems,
      disabledItems: disabledItems,
      unselectedItems: unselectedItems,
      allItems: allItems,
      hasNoItems: hasNoItems
    });
    // @todo: Fix if possible - avoiding breaking in eslint upgrade
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectionState.collection.size]);
  if (hasNoItems) {
    return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement("div", {
      className: ListBox_module.noResultsWrapper
    }, children(itemsState)), React__default.default.createElement("ul", {
      ref: listRef,
      className: ListBox_module.hidden
    }));
  }
  return React__default.default.createElement("ul", tslib.__assign({}, listBoxProps, {
    ref: listRef,
    className: classnames__default.default(ListBox_module.listBox, isOverflown && ListBox_module.overflown)
  }), children(itemsState));
};
ListBox.displayName = 'FilterMultiSelect.ListBox';
exports.ListBox = ListBox;
