'use strict';

var React = require('react');
var i18nReactIntl = require('@cultureamp/i18n-react-intl');
var classnames = require('classnames');
var VisuallyHidden = require('../../../../../VisuallyHidden/VisuallyHidden.cjs');
require('../../../context/MenuTriggerProvider/MenuTriggerProvider.cjs');
var SelectionProvider = require('../../../context/SelectionProvider/SelectionProvider.cjs');
var SelectionControlButton_module = require('../SelectionControlButton.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var ClearButton = function () {
  var selectionState = SelectionProvider.useSelectionContext().selectionState;
  var filteredOptions = Array.from(selectionState.collection.getKeys());
  var selectedOptions = Array.from(selectionState.selectionManager.selectedKeys);
  var isDisabled = filteredOptions.length === 0 || !filteredOptions.find(function (key) {
    return selectionState.selectionManager.isSelected(key);
  });
  return React__default.default.createElement("button", {
    type: "button",
    className: classnames__default.default(SelectionControlButton_module.button, isDisabled && SelectionControlButton_module.isDisabled),
    "aria-disabled": isDisabled,
    onClick: function () {
      if (!isDisabled) {
        selectionState.selectionManager.setSelectedKeys(selectedOptions.filter(function (option) {
          return !filteredOptions.includes(option);
        }));
      }
    }
  }, React__default.default.createElement(i18nReactIntl.FormattedMessage, {
    defaultMessage: "Clear<VisuallyHidden> selections</VisuallyHidden>",
    id: "filterMultiSelectClearButton.label",
    description: "Clear button label for filter multi-select",
    values: {
      VisuallyHidden: function (children) {
        return React__default.default.createElement(VisuallyHidden.VisuallyHidden, null, children);
      }
    }
  }));
};
ClearButton.displayName = 'FilterMultiSelect.ClearButton';
exports.ClearButton = ClearButton;
