'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Heading_module = require('./Heading.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var VARIANTS_24PX_OR_GREATER = ['display-0', 'heading-1', 'heading-2'];
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3074885298/Typography#Headings Guidance}
 * {@link https://cultureamp.design/?path=/docs/components-typography-heading--display-0 Storybook}
 */
const Heading = /*#__PURE__*/function () {
  const Heading = function (_a) {
    var children = _a.children,
      tag = _a.tag,
      variant = _a.variant,
      _b = _a.color,
      color = _b === void 0 ? 'dark' : _b,
      classNameOverride = _a.classNameOverride,
      restProps = tslib.__rest(_a, ["children", "tag", "variant", "color", "classNameOverride"]);
    var inferredTag = tag !== null && tag !== void 0 ? tag : translateHeadingLevelToTag(variant);
    var className = classnames__default.default(Heading_module.heading, Heading_module[variant], classNameOverride, Heading_module[color], VARIANTS_24PX_OR_GREATER.includes(variant) ? Heading_module.large : Heading_module.small);
    return React.createElement(inferredTag, tslib.__assign(tslib.__assign({}, restProps), {
      className: className
    }), children);
  };
  Heading.displayName = 'Heading';
  /**
   * A helper to infer the tag when not explicitly passed as a prop
   * @param headingLevel Level of the heading
   */
  return Heading;
}();
var translateHeadingLevelToTag = function (headingLevel) {
  switch (headingLevel) {
    case 'display-0':
    case 'composable-header-title':
    case 'heading-1':
      return 'h1';
    case 'heading-2':
      return 'h2';
    case 'heading-3':
      return 'h3';
    case 'heading-4':
      return 'h4';
    case 'heading-5':
      return 'h5';
    case 'heading-6':
    default:
      return 'h6';
  }
};
exports.Heading = Heading;
