'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var reactFocusOn = require('react-focus-on');
var reactPopper = require('react-popper');
var MenuDropdown_module = require('./MenuDropdown.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var MenuDropdown = function (_a) {
  var children = _a.children,
    referenceElement = _a.referenceElement,
    id = _a.id,
    hideMenuDropdown = _a.hideMenuDropdown,
    _b = _a.autoHide,
    autoHide = _b === void 0 ? 'on' : _b,
    _c = _a.align,
    align = _c === void 0 ? 'left' : _c,
    _d = _a.width,
    width = _d === void 0 ? 'default' : _d;
  var _e = React.useState(null),
    popperElement = _e[0],
    setPopperElement = _e[1];
  var _f = reactPopper.usePopper(referenceElement, popperElement, {
      modifiers: [{
        name: 'offset',
        options: {
          offset: [0, 6] // value used from the $spacing-xs scss variable,
        }
      }, {
        name: 'preventOverflow',
        options: {
          // Gives some room so the menu shadow doesn't get clipped if near the edge of the viewport.
          padding: 8
        }
      }],
      placement: align === 'left' ? 'bottom-start' : 'bottom-end'
    }),
    popperStyles = _f.styles,
    attributes = _f.attributes;
  // This callback handler will not run when autoHide === "off"
  var handleDocumentClickForAutoHide = React.useCallback(function (e) {
    if (popperElement && e.target instanceof Node && !popperElement.contains(e.target) && referenceElement !== e.target && !(referenceElement === null || referenceElement === void 0 ? void 0 : referenceElement.contains(e.target))) {
      hideMenuDropdown();
    }
  }, [popperElement, referenceElement, hideMenuDropdown]);
  var handleDocumentResize = React.useCallback(function () {
    hideMenuDropdown();
  }, [hideMenuDropdown]);
  var handleRootClick = function () {
    if (autoHide === 'on') {
      // ie. is not equal to "off" | "outside-click-only"
      hideMenuDropdown();
    }
  };
  React.useEffect(function () {
    window.addEventListener('resize', handleDocumentResize, false);
    return function () {
      window.removeEventListener('resize', handleDocumentResize, false);
    };
  }, [handleDocumentResize]);
  React.useEffect(function () {
    if (autoHide !== 'off') {
      document.addEventListener('click', handleDocumentClickForAutoHide, true);
    }
    return function () {
      if (autoHide !== 'off') {
        document.removeEventListener('click', handleDocumentClickForAutoHide, true);
      }
    };
  }, [autoHide, handleDocumentClickForAutoHide]);
  return React__default.default.createElement(reactFocusOn.FocusOn, {
    enabled: !!referenceElement,
    scrollLock: false,
    noIsolation: true,
    shards: referenceElement ? [referenceElement] : undefined,
    onEscapeKey: hideMenuDropdown,
    returnFocus: function () {
      referenceElement === null || referenceElement === void 0 ? void 0 : referenceElement.focus();
      return false;
    }
  }, React__default.default.createElement("div", tslib.__assign({
    id: id,
    ref: setPopperElement
  }, attributes.popper, {
    style: popperStyles.popper,
    className: classnames__default.default(MenuDropdown_module.menuContainer, width == 'default' && MenuDropdown_module.defaultWidth),
    onClick: handleRootClick
  }), children));
};
MenuDropdown.displayName = 'MenuDropdown';
exports.MenuDropdown = MenuDropdown;
