'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Heading = require('../../Heading/Heading.cjs');
var Spot = require('../../Illustration/Spot/Spot.cjs');
require('../../Illustration/Scene/BrandMomentCaptureIntro/BrandMomentCaptureIntro.cjs');
require('../../Illustration/Scene/Scene.cjs');
var GenericModal = require('../GenericModal/GenericModal.cjs');
require('../GenericModal/context/ModalContext.cjs');
var ModalAccessibleDescription = require('../GenericModal/subcomponents/ModalAccessibleDescription/ModalAccessibleDescription.cjs');
var ModalFooter = require('../GenericModal/subcomponents/ModalFooter/ModalFooter.cjs');
var ModalHeader = require('../GenericModal/subcomponents/ModalHeader/ModalHeader.cjs');
var ModalAccessibleLabel = require('../GenericModal/subcomponents/ModalAccessibleLabel/ModalAccessibleLabel.cjs');
var ModalBody = require('../GenericModal/subcomponents/ModalBody/ModalBody.cjs');
var Icon = require('../../__next__/Icon/Icon.cjs');
var ConfirmationModal_module = require('./ConfirmationModal.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var getIconName = function (variantName) {
  switch (variantName) {
    case 'cautionary':
      return 'warning';
    case 'informative':
      return 'info';
    case 'negative':
    case 'warning':
      return 'error';
    case 'positive':
    case 'success':
      return 'check_circle';
    case 'assertive':
      return 'error';
  }
};
var getIcon = function (variantName, isProminent) {
  if (isProminent) {
    switch (variantName) {
      case 'cautionary':
        return React__default.default.createElement(Spot.Cautionary, null);
      case 'informative':
        return React__default.default.createElement(Spot.Informative, null);
      case 'negative':
      case 'warning':
        return React__default.default.createElement(Spot.Negative, null);
      case 'positive':
      case 'success':
        return React__default.default.createElement(Spot.Positive, null);
      case 'assertive':
        return React__default.default.createElement(Spot.Assertive, null);
    }
  }
  var iconName = getIconName(variantName);
  return React__default.default.createElement(Icon.Icon, {
    name: iconName,
    isPresentational: true,
    isFilled: true
  });
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093114/Modal Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-modals-confirmationmodal--docs Storybook}
 */
var ConfirmationModal = function (_a) {
  var isOpen = _a.isOpen,
    _b = _a.isProminent,
    isProminent = _b === void 0 ? false : _b,
    _c = _a.unpadded,
    unpadded = _c === void 0 ? false : _c,
    mood = _a.mood,
    variant = _a.variant,
    title = _a.title,
    onConfirm = _a.onConfirm,
    onAfterLeave = _a.onAfterLeave,
    onAfterEnter = _a.onAfterEnter,
    _d = _a.confirmLabel,
    confirmLabel = _d === void 0 ? 'Confirm' : _d,
    _e = _a.dismissLabel,
    dismissLabel = _e === void 0 ? 'Cancel' : _e,
    confirmWorking = _a.confirmWorking,
    propsOnDismiss = _a.onDismiss,
    children = _a.children,
    className = _a.className,
    props = tslib.__rest(_a, ["isOpen", "isProminent", "unpadded", "mood", "variant", "title", "onConfirm", "onAfterLeave", "onAfterEnter", "confirmLabel", "dismissLabel", "confirmWorking", "onDismiss", "children", "className"]);
  var variantName = variant !== null && variant !== void 0 ? variant : mood;
  var onDismiss = confirmWorking ? undefined : propsOnDismiss;
  var footerActions = [];
  if (onConfirm) {
    var confirmAction = {
      label: confirmLabel,
      onClick: onConfirm
    };
    var workingProps = confirmWorking ? {
      working: true,
      workingLabel: confirmWorking.label,
      workingLabelHidden: confirmWorking.labelHidden
    } : {};
    footerActions.push(tslib.__assign(tslib.__assign({}, confirmAction), workingProps));
  }
  footerActions.push({
    label: dismissLabel,
    onClick: onDismiss,
    disabled: !!confirmWorking
  });
  return React__default.default.createElement(GenericModal.GenericModal, {
    isOpen: isOpen,
    onEscapeKeyup: onDismiss,
    onOutsideModalClick: onDismiss,
    onAfterLeave: onAfterLeave,
    onAfterEnter: onAfterEnter,
    className: className
  }, React__default.default.createElement("div", tslib.__assign({
    className: ConfirmationModal_module.modal,
    "data-modal": true
  }, props), React__default.default.createElement(ModalHeader.ModalHeader, {
    onDismiss: onDismiss
  }, React__default.default.createElement("div", {
    className: classnames__default.default(ConfirmationModal_module.header, variant ? ConfirmationModal_module[variant] : ConfirmationModal_module["".concat(mood, "Header")], isProminent && ConfirmationModal_module.prominent, !unpadded && ConfirmationModal_module.padded)
  }, React__default.default.createElement("div", {
    className: classnames__default.default(ConfirmationModal_module.iconContainer, isProminent && ConfirmationModal_module.prominent)
  }, React__default.default.createElement("div", {
    className: ConfirmationModal_module.spotIcon
  }, getIcon(variantName, isProminent))), React__default.default.createElement(ModalAccessibleLabel.ModalAccessibleLabel, {
    isProminent: isProminent
  }, React__default.default.createElement(Heading.Heading, {
    tag: "h2",
    variant: "heading-2"
  }, title)))), React__default.default.createElement(ModalBody.ModalBody, null, React__default.default.createElement("div", {
    className: classnames__default.default(isProminent && ConfirmationModal_module.prominent, !unpadded && ConfirmationModal_module.padded)
  }, React__default.default.createElement(ModalAccessibleDescription.ModalAccessibleDescription, null, children))), React__default.default.createElement(ModalFooter.ModalFooter, {
    actions: footerActions,
    appearance: mood === 'negative' || variant == 'warning' ? 'destructive' : 'primary',
    unpadded: unpadded
  })));
};
ConfirmationModal.displayName = 'ConfirmationModal';
exports.ConfirmationModal = ConfirmationModal;
