'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Heading = require('../../Heading/Heading.cjs');
var GenericModal = require('../GenericModal/GenericModal.cjs');
require('../GenericModal/context/ModalContext.cjs');
require('../GenericModal/subcomponents/ModalAccessibleDescription/ModalAccessibleDescription.cjs');
var ModalFooter = require('../GenericModal/subcomponents/ModalFooter/ModalFooter.cjs');
var ModalHeader = require('../GenericModal/subcomponents/ModalHeader/ModalHeader.cjs');
var ModalAccessibleLabel = require('../GenericModal/subcomponents/ModalAccessibleLabel/ModalAccessibleLabel.cjs');
var ModalBody = require('../GenericModal/subcomponents/ModalBody/ModalBody.cjs');
var ContextModal_module = require('./ContextModal.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093114/Modal Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-modals--contextmodal--docs Storybook}
 */
var ContextModal = function (_a) {
  var isOpen = _a.isOpen,
    _b = _a.unpadded,
    unpadded = _b === void 0 ? false : _b,
    _c = _a.layout,
    layout = _c === void 0 ? 'portrait' : _c,
    title = _a.title,
    onConfirm = _a.onConfirm,
    propsOnDismiss = _a.onDismiss,
    onAfterLeave = _a.onAfterLeave,
    onAfterEnter = _a.onAfterEnter,
    _d = _a.confirmLabel,
    confirmLabel = _d === void 0 ? 'Confirm' : _d,
    confirmWorking = _a.confirmWorking,
    renderBackground = _a.renderBackground,
    children = _a.children,
    contentHeader = _a.contentHeader,
    image = _a.image,
    secondaryLabel = _a.secondaryLabel,
    onSecondaryAction = _a.onSecondaryAction,
    className = _a.className,
    props = tslib.__rest(_a, ["isOpen", "unpadded", "layout", "title", "onConfirm", "onDismiss", "onAfterLeave", "onAfterEnter", "confirmLabel", "confirmWorking", "renderBackground", "children", "contentHeader", "image", "secondaryLabel", "onSecondaryAction", "className"]);
  var onDismiss = confirmWorking ? undefined : propsOnDismiss;
  var footerActions = [];
  var workingProps = confirmWorking ? {
    working: true,
    workingLabel: confirmWorking.label,
    workingLabelHidden: confirmWorking.labelHidden
  } : {};
  if (onConfirm) {
    var confirmAction = {
      label: confirmLabel,
      onClick: onConfirm
    };
    footerActions.push(tslib.__assign(tslib.__assign({}, confirmAction), workingProps));
  }
  if (secondaryLabel) {
    footerActions.push({
      label: secondaryLabel,
      onClick: onSecondaryAction,
      disabled: !!confirmWorking
    });
  }
  return React__default.default.createElement(GenericModal.GenericModal, {
    isOpen: isOpen,
    onEscapeKeyup: onDismiss,
    onOutsideModalClick: onDismiss,
    onAfterLeave: onAfterLeave,
    onAfterEnter: onAfterEnter,
    className: className
  }, React__default.default.createElement("div", tslib.__assign({
    className: ContextModal_module.modal,
    "data-modal": true
  }, props), renderBackground === null || renderBackground === void 0 ? void 0 : renderBackground(), React__default.default.createElement(ModalHeader.ModalHeader, {
    onDismiss: onDismiss
  }, React__default.default.createElement("div", {
    className: classnames__default.default(ContextModal_module.header, !unpadded && ContextModal_module.padded)
  }, React__default.default.createElement(ModalAccessibleLabel.ModalAccessibleLabel, null, React__default.default.createElement(Heading.Heading, {
    variant: "heading-2",
    tag: "h2"
  }, title)))), contentHeader && React__default.default.createElement("div", {
    className: ContextModal_module.contentHeader
  }, contentHeader), React__default.default.createElement(ModalBody.ModalBody, null, React__default.default.createElement("div", {
    className: classnames__default.default(ContextModal_module.contentLayout, ContextModal_module["".concat(layout, "Contentlayout")])
  }, image && React__default.default.createElement("div", {
    className: ContextModal_module.image
  }, image), React__default.default.createElement("div", {
    className: ContextModal_module.content
  }, children, onConfirm != null && React__default.default.createElement("div", {
    className: secondaryLabel ? ContextModal_module.footerWithSecondaryAction : ContextModal_module.footer
  })))), React__default.default.createElement(ModalFooter.ModalFooter, {
    variant: image ? 'context' : undefined,
    actions: footerActions,
    appearance: "primary",
    unpadded: unpadded
  })));
};
ContextModal.displayName = 'ContextModal';
exports.ContextModal = ContextModal;
