'use strict';

var React = require('react');
var ReactDOM = require('react-dom');
var react = require('@headlessui/react');
var classnames = require('classnames');
var FocusLock = require('react-focus-lock');
var console = require('../util/console.cjs');
var ModalContext = require('./context/ModalContext.cjs');
var GenericModal_module = require('./GenericModal.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var FocusLock__default = /*#__PURE__*/_interopDefault(FocusLock);
var GenericModal = function (_a) {
  var propsId = _a.id,
    children = _a.children,
    _b = _a.isOpen,
    isOpen = _b === void 0 ? true : _b,
    focusLockDisabled = _a.focusLockDisabled,
    onEscapeKeyup = _a.onEscapeKeyup,
    onOutsideModalClick = _a.onOutsideModalClick,
    onAfterEnter = _a.onAfterEnter,
    propsOnAfterLeave = _a.onAfterLeave,
    className = _a.className;
  var reactId = React.useId();
  var id = propsId !== null && propsId !== void 0 ? propsId : reactId;
  var labelledByID = React.useId();
  var describedByID = React.useId();
  var _c = React.useState(null),
    scrollLayer = _c[0],
    setScrollLayer = _c[1];
  var _d = React.useState(null),
    modalLayer = _d[0],
    setModalLayer = _d[1];
  var scrollModalToTop = function () {
    // If we have a really long modal, the autofocus could land on an element down below
    // causing the modal to scroll down and skipping over the content near the modal's top.
    // Ensure that when the modal opens, we are at the top of its content.
    requestAnimationFrame(function () {
      if (!scrollLayer) return;
      scrollLayer.scrollTop = 0;
    });
  };
  var outsideModalClickHandler = function (event) {
    if (event.target === scrollLayer || event.target === modalLayer) {
      onOutsideModalClick === null || onOutsideModalClick === void 0 ? void 0 : onOutsideModalClick(event);
    }
  };
  var focusOnAccessibleLabel = function () {
    // Check if focus already exists within the modal
    if (modalLayer === null || modalLayer === void 0 ? void 0 : modalLayer.contains(document.activeElement)) {
      return;
    }
    var labelElement = document.getElementById(labelledByID);
    labelElement === null || labelElement === void 0 ? void 0 : labelElement.focus();
  };
  var a11yWarn = function () {
    // Ensure that consumers have provided an element that labels the modal
    // to meet ARIA accessibility guidelines.
    if (!document.getElementById(labelledByID)) {
      console.warn("When using the Modal component, you must provide a label for the modal.\n        Make sure you have a <ModalAccessibleLabel /> component with content that labels the modal.");
    }
  };
  var preventBodyScroll = function () {
    var _a;
    var hasScrollbar = window.innerWidth > document.documentElement.clientWidth;
    var scrollStyles = [GenericModal_module.unscrollable];
    if (hasScrollbar) {
      scrollStyles.push(GenericModal_module.pseudoScrollbar);
    }
    (_a = document.documentElement.classList).add.apply(_a, scrollStyles);
  };
  var onAfterEnterHandler = function () {
    scrollModalToTop();
    if (modalLayer) {
      onAfterEnter === null || onAfterEnter === void 0 ? void 0 : onAfterEnter();
      focusOnAccessibleLabel();
      a11yWarn();
    }
  };
  var escapeKeyHandler = React.useCallback(function (event) {
    if (event.key === 'Escape') {
      onEscapeKeyup === null || onEscapeKeyup === void 0 ? void 0 : onEscapeKeyup(event);
    }
  }, [onEscapeKeyup]);
  var onBeforeEnterHandler = function () {
    preventBodyScroll();
    if (onEscapeKeyup) {
      document.addEventListener('keyup', escapeKeyHandler);
    }
  };
  var cleanUpAfterClose = function () {
    document.documentElement.classList.remove(GenericModal_module.unscrollable, GenericModal_module.pseudoScrollbar);
    if (onEscapeKeyup) {
      document.removeEventListener('keyup', escapeKeyHandler);
    }
  };
  /* Ensure sure add-on styles (e.g. unscrollable) and key event is cleaned up when the modal is unmounted*/
  // @todo: Fix if possible - avoiding breaking in eslint upgrade
  // eslint-disable-next-line react-hooks/exhaustive-deps
  React.useEffect(function () {
    return function () {
      return cleanUpAfterClose();
    };
  }, []);
  var onAfterLeaveHandler = function () {
    cleanUpAfterClose();
    propsOnAfterLeave === null || propsOnAfterLeave === void 0 ? void 0 : propsOnAfterLeave();
  };
  return ReactDOM.createPortal(React__default.default.createElement(react.Transition, {
    appear: true,
    show: isOpen,
    beforeEnter: onBeforeEnterHandler,
    afterEnter: onAfterEnterHandler,
    afterLeave: onAfterLeaveHandler,
    "data-generic-modal-transition-wrapper": true,
    enter: GenericModal_module.animatingEnter,
    leave: GenericModal_module.animatingLeave,
    as: "div",
    className: classnames__default.default(GenericModal_module.transitionLayer, className)
  }, React__default.default.createElement(FocusLock__default.default, {
    disabled: focusLockDisabled,
    returnFocus: true,
    // Disabling false positive
    // eslint-disable-next-line jsx-a11y/no-autofocus
    autoFocus: false
  }, React__default.default.createElement("div", {
    className: GenericModal_module.backdropLayer
  }), React__default.default.createElement("div", {
    className: GenericModal_module.scrollLayer,
    ref: function (scrollLayerRef) {
      setScrollLayer(scrollLayerRef);
    },
    onClick: outsideModalClickHandler,
    "data-testid": "".concat(id, "-scrollLayer")
  }, React__default.default.createElement(ModalContext.ModalContext.Provider, {
    value: {
      labelledByID: labelledByID,
      describedByID: describedByID
    }
  }, React__default.default.createElement("div", {
    role: "dialog",
    className: GenericModal_module.modalLayer,
    "aria-labelledby": labelledByID,
    "aria-describedby": describedByID,
    ref: function (modalLayerRef) {
      return setModalLayer(modalLayerRef);
    },
    "data-testid": id
  }, children))))), document.body);
};
GenericModal.displayName = 'GenericModal';
exports.GenericModal = GenericModal;
