'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var FieldMessage = require('../FieldMessage/FieldMessage.cjs');
var Heading = require('../Heading/Heading.cjs');
var MultiSelectOptions = require('./subcomponents/MultiSelectOptions/MultiSelectOptions.cjs');
var MultiSelectToggle = require('./subcomponents/MultiSelectToggle/MultiSelectToggle.cjs');
var Popover = require('./subcomponents/Popover/Popover.cjs');
var reactDom = require('@floating-ui/react-dom');
var MultiSelect_module = require('./MultiSelect.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var MultiSelect = function (_a) {
  var propsId = _a.id,
    label = _a.label,
    items = _a.items,
    selectedValues = _a.selectedValues,
    description = _a.description,
    onSelectedValuesChange = _a.onSelectedValuesChange,
    isOpen = _a.isOpen,
    onOpenChange = _a.onOpenChange,
    classNameOverride = _a.classNameOverride,
    validationMessage = _a.validationMessage,
    restProps = tslib.__rest(_a, ["id", "label", "items", "selectedValues", "description", "onSelectedValuesChange", "isOpen", "onOpenChange", "classNameOverride", "validationMessage"]);
  var fallbackId = React.useId();
  var id = propsId !== null && propsId !== void 0 ? propsId : fallbackId;
  var descriptionId = "".concat(id, "-description");
  var validationId = "".concat(id, "-validation-message");
  var toggleButtonRef = React.useRef(null);
  var refs = reactDom.useFloating().refs;
  var handleToggleClick = function () {
    return onOpenChange(!isOpen);
  };
  var handleClose = function () {
    return onOpenChange(false);
  };
  var onClickOutside = function (e) {
    var toggle = refs.reference.current;
    var isInToggle = toggle.contains(e.target);
    if (!isInToggle) {
      e.stopPropagation();
      handleClose();
    }
  };
  var itemsMap = items.reduce(function (acc, item) {
    acc[item.value] = item;
    return acc;
  }, {});
  var handleOnRemoveOption = function (optionValue) {
    var newValues = new Set(selectedValues.values());
    newValues.delete(optionValue);
    onSelectedValuesChange(newValues);
  };
  var handleRemoveAllOptions = function () {
    var newValues = new Set([]);
    onSelectedValuesChange(newValues);
  };
  return React__default.default.createElement("div", tslib.__assign({
    id: id,
    className: classnames__default.default(classNameOverride)
  }, restProps), React__default.default.createElement(Heading.Heading, {
    tag: "span",
    variant: "heading-6",
    id: "".concat(id, "--label")
  }, label), React__default.default.createElement("div", {
    ref: refs.setReference,
    className: MultiSelect_module.toggleContainer
  }, React__default.default.createElement(MultiSelectToggle.MultiSelectToggle, {
    ref: toggleButtonRef,
    id: "".concat(id, "--toggle"),
    "aria-labelledby": "".concat(id, "--label"),
    "aria-describedby": "".concat(validationId, " ").concat(descriptionId),
    "aria-controls": "".concat(id, "--popover"),
    onClick: handleToggleClick,
    isOpen: isOpen,
    selectedOptions: Array.from(selectedValues).map(function (value) {
      return itemsMap[value];
    }),
    status: validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.status,
    onRemoveOption: handleOnRemoveOption,
    onRemoveAllOptions: handleRemoveAllOptions
  })), validationMessage && React__default.default.createElement(FieldMessage.FieldMessage, tslib.__assign({
    id: validationId
  }, validationMessage)), description && React__default.default.createElement(FieldMessage.FieldMessage, {
    id: descriptionId,
    message: description
  }), isOpen && React__default.default.createElement(Popover.Popover, {
    refs: refs,
    id: "".concat(id, "--popover"),
    role: "dialog",
    "aria-modal": "true",
    tabIndex: -1,
    focusOnProps: {
      enabled: true,
      onClickOutside: onClickOutside,
      onEscapeKey: handleClose,
      shards: [toggleButtonRef],
      noIsolation: true,
      onActivation: function () {
        var _a, _b;
        return (_b = (_a = refs.floating) === null || _a === void 0 ? void 0 : _a.current) === null || _b === void 0 ? void 0 : _b.focus();
      }
    },
    classNameOverride: MultiSelect_module.popover
  }, React__default.default.createElement(MultiSelectOptions.MultiSelectOptions, {
    id: "".concat(id, "--options"),
    options: items,
    onChange: onSelectedValuesChange,
    selectedValues: selectedValues
  })));
};
MultiSelect.displayName = 'MultiSelect';
exports.MultiSelect = MultiSelect;
