'use strict';

var tslib = require('tslib');
var React = require('react');
var uuid = require('uuid');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var ToastNotificationContext = React__default.default.createContext(null);
var useToastNotificationContext = function () {
  var context = React.useContext(ToastNotificationContext);
  if (!context) {
    throw new Error('useToastNotificationContext must be used within the ToastNotificationContext.Provider');
  }
  return context;
};
var ToastNotificationProvider = function (_a) {
  var children = _a.children;
  var _b = React.useState([]),
    notifications = _b[0],
    setNotifications = _b[1];
  var addToastNotification = function (notification) {
    var uuid$1 = uuid.v4();
    var notificationWithId = tslib.__assign({
      id: uuid$1
    }, notification);
    setNotifications(function (existing) {
      var notificationExists = existing.find(function (_a) {
        var id = _a.id;
        return id === notification.id;
      });
      return notificationExists ? existing : tslib.__spreadArray(tslib.__spreadArray([], existing, true), [notificationWithId], false);
    });
  };
  var updateToastNotification = function (notification) {
    var notificationIndex = notifications.findIndex(function (_a) {
      var id = _a.id;
      return id === notification.id;
    });
    var copy = notifications.slice();
    copy.splice(notificationIndex, 1, notification); // Mutation to insert notification over itself
    setNotifications(copy);
  };
  var removeToastNotification = function (notificationID) {
    setNotifications(function (prev) {
      return prev.filter(function (_a) {
        var id = _a.id;
        return id !== notificationID;
      });
    });
  };
  var clearToastNotifications = function () {
    setNotifications([]);
  };
  var value = {
    notifications: notifications,
    addToastNotification: addToastNotification,
    updateToastNotification: updateToastNotification,
    removeToastNotification: removeToastNotification,
    clearToastNotifications: clearToastNotifications
  };
  return React__default.default.createElement(ToastNotificationContext.Provider, {
    value: value
  }, children);
};
ToastNotificationProvider.displayName = 'ToastNotificationProvider';
exports.ToastNotificationProvider = ToastNotificationProvider;
exports.useToastNotificationContext = useToastNotificationContext;
