'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var isRefObject = require('../../../utils/isRefObject.cjs');
var CancelButton = require('../CancelButton/CancelButton.cjs');
var NotificationHeading = require('../NotificationHeading/NotificationHeading.cjs');
var NotificationIcon = require('../NotificationIcon/NotificationIcon.cjs');
var GenericNotification_module = require('./GenericNotification.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var GenericNotification = React.forwardRef(function (_a, ref) {
  var type = _a.type,
    variant = _a.variant,
    style = _a.style,
    children = _a.children,
    title = _a.title,
    _b = _a.persistent,
    persistent = _b === void 0 ? false : _b,
    onHide = _a.onHide,
    noBottomMargin = _a.noBottomMargin,
    forceMultiline = _a.forceMultiline,
    headingProps = _a.headingProps,
    classNameOverride = _a.classNameOverride,
    restProps = tslib.__rest(_a, ["type", "variant", "style", "children", "title", "persistent", "onHide", "noBottomMargin", "forceMultiline", "headingProps", "classNameOverride"]);
  var _c = React.useState(true),
    isHidden = _c[0],
    setIsHidden = _c[1];
  var _d = React.useState(false),
    isRemoved = _d[0],
    setIsRemoved = _d[1];
  var fallbackRef = React.useRef(null);
  var containerRef = isRefObject.isRefObject(ref) ? ref : fallbackRef;
  React.useEffect(function () {
    requestAnimationFrame(function () {
      if (containerRef.current) {
        setIsHidden(false);
      }
    });
  }, [containerRef]);
  var getMarginTop = function () {
    if (isHidden && containerRef.current) {
      return -containerRef.current.clientHeight + 'px';
    }
    return '0';
  };
  var onTransitionEnd = function (e) {
    // Be careful: this assumes the final CSS property to be animated is "margin-top".
    if (isHidden && e.propertyName === 'margin-top') {
      setIsRemoved(true);
      onHide === null || onHide === void 0 ? void 0 : onHide();
    }
  };
  if (isRemoved) {
    return null;
  }
  return React__default.default.createElement("div", tslib.__assign({
    ref: containerRef,
    className: classnames__default.default(GenericNotification_module.notification, variant ? GenericNotification_module[variant] : GenericNotification_module[type], GenericNotification_module[style], isHidden && GenericNotification_module.hidden, noBottomMargin && GenericNotification_module.noBottomMargin, classNameOverride, persistent && GenericNotification_module.persistent),
    style: {
      marginTop: getMarginTop()
    },
    onTransitionEnd: onTransitionEnd
  }, restProps), React__default.default.createElement("div", {
    className: GenericNotification_module.icon
  }, type ? React__default.default.createElement(NotificationIcon.NotificationIconType, {
    type: type
  }) : React__default.default.createElement(NotificationIcon.NotificationIconVariant, {
    variant: variant
  })), React__default.default.createElement("div", {
    className: classnames__default.default(GenericNotification_module.textContainer, forceMultiline && GenericNotification_module.forceMultiline)
  }, style !== 'global' && React__default.default.createElement(NotificationHeading.NotificationHeading, {
    titleProp: title,
    headingProps: headingProps
  }), children && React__default.default.createElement("div", {
    className: GenericNotification_module.text
  }, children)), !persistent && React__default.default.createElement(CancelButton.CancelButton, {
    onClick: function () {
      return setIsHidden(true);
    }
  }));
});
GenericNotification.displayName = 'GenericNotification';
exports.GenericNotification = GenericNotification;
