'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Heading = require('../Heading/Heading.cjs');
var Label = require('./subcomponents/Label/Label.cjs');
var calculatePercentage = require('./utils/calculatePercentage.cjs');
var ProgressBar_module = require('./ProgressBar.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896891/Progress+Bar Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-progress-bar--docs Storybook}
 */
var ProgressBar = function (_a) {
  var value = _a.value,
    max = _a.max,
    isAnimating = _a.isAnimating,
    mood = _a.mood,
    color = _a.color,
    subtext = _a.subtext,
    label = _a.label,
    classNameOverride = _a.classNameOverride,
    _b = _a.isReversed,
    isReversed = _b === void 0 ? false : _b,
    restProps = tslib.__rest(_a, ["value", "max", "isAnimating", "mood", "color", "subtext", "label", "classNameOverride", "isReversed"]);
  var percentage = calculatePercentage.calculatePercentage({
    value: value,
    max: max
  });
  return React__default.default.createElement("div", tslib.__assign({
    role: "progressbar",
    "aria-valuenow": percentage,
    "aria-valuemin": 0,
    "aria-valuemax": 100,
    className: classNameOverride
  }, restProps), label && React__default.default.createElement(Label.Label, {
    content: label,
    isReversed: isReversed
  }), React__default.default.createElement("div", {
    className: ProgressBar_module.progressBackground
  }, React__default.default.createElement("div", {
    className: classnames__default.default(ProgressBar_module.progress, color ? ProgressBar_module[color] : ProgressBar_module[mood], isAnimating && ProgressBar_module.isAnimating),
    style: {
      transform: "translateX(-".concat(100 - percentage, "%")
    }
  })), subtext && React__default.default.createElement("div", {
    className: ProgressBar_module.subtext
  }, React__default.default.createElement(Heading.Heading, {
    variant: "heading-6",
    tag: "p",
    color: isReversed ? 'white' : 'dark'
  }, subtext)));
};
ProgressBar.displayName = 'ProgressBar';
exports.ProgressBar = ProgressBar;
