'use strict';

var tslib = require('tslib');
var constants = require('../constants.cjs');
require('prosemirror-commands');
require('prosemirror-keymap');
require('prosemirror-history');
require('prosemirror-state');
var ProseMirrorModel = require('prosemirror-model');
require('prosemirror-inputrules');
require('prosemirror-schema-list');
var marks = require('../utils/schema/marks.cjs');
var nodes = require('../utils/schema/nodes.cjs');
function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n.default = e;
  return Object.freeze(n);
}
var ProseMirrorModel__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorModel);
var createSchemaFromControls = function (controls) {
  if (!controls) {
    return createSchema();
  }
  var namesFromControls = controls.reduce(function (acc, c) {
    return tslib.__spreadArray(tslib.__spreadArray([], acc, true), [c.name], false);
  }, []);
  return createSchema(namesFromControls);
};
var createSchemaWithAll = function () {
  return createSchema(constants.TOOLBAR_CONTROLS);
};
var createSchema = function (controls) {
  var nodes$1 = nodes.getNodes();
  var marks$1 = marks.getMarks();
  var defaultNodes = {
    doc: nodes$1.doc,
    paragraph: nodes$1.paragraph,
    text: nodes$1.text,
    hardBreak: nodes$1.hardBreak
  };
  if (!controls) {
    return new ProseMirrorModel__namespace.Schema({
      nodes: defaultNodes
    });
  }
  var newNodes = tslib.__assign({}, defaultNodes);
  var newMarks = {};
  if (controls.includes('bold')) {
    newMarks.strong = marks$1.strong;
  }
  if (controls.includes('italic')) {
    newMarks.em = marks$1.em;
  }
  if (controls.includes('underline')) {
    newMarks.underline = marks$1.underline;
  }
  if (controls.includes('bulletList')) {
    newNodes.bulletList = nodes$1.bulletList;
    newNodes.listItem = nodes$1.listItem;
  }
  if (controls.includes('orderedList')) {
    newNodes.orderedList = nodes$1.orderedList;
    newNodes.listItem = nodes$1.listItem;
  }
  if (controls.includes('link')) {
    newMarks.link = marks$1.link;
  }
  return new ProseMirrorModel__namespace.Schema({
    nodes: newNodes,
    marks: newMarks
  });
};
exports.createSchemaFromControls = createSchemaFromControls;
exports.createSchemaWithAll = createSchemaWithAll;
