'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Toolbar_module = require('./Toolbar.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var determineValidKeypress = function (event) {
  var validKeys = {
    left: 'ArrowLeft',
    right: 'ArrowRight'
  };
  return Object.values(validKeys).includes(event.key);
};
var handleKeyDown = function (e, buttonIndex, buttonFocusIndex, setFocusIndex, toolbarButtons) {
  if (!determineValidKeypress(e)) return;
  var newFocusIndex;
  var lastButtonIndex = toolbarButtons.current.length - 1;
  if (e.key === 'ArrowLeft') {
    newFocusIndex = buttonIndex === 0 ? lastButtonIndex : buttonFocusIndex - 1;
  } else {
    newFocusIndex = buttonIndex === lastButtonIndex ? 0 : buttonFocusIndex + 1;
  }
  setFocusIndex(newFocusIndex);
  toolbarButtons.current[newFocusIndex].focus();
};
var Toolbar = function (props) {
  var toolbarChildren = props.children,
    classNameOverride = props.classNameOverride,
    toolbarProps = tslib.__rest(props, ["children", "classNameOverride"]);
  var _a = React__default.default.useState(0),
    buttonFocusIndex = _a[0],
    setButtonFocusIndex = _a[1];
  var toolbarButtonsRef = React__default.default.useRef([]);
  var buttonCount = 0;
  return React__default.default.createElement("div", tslib.__assign({
    className: classnames__default.default(Toolbar_module.toolbar, classNameOverride),
    role: "toolbar"
  }, toolbarProps), React__default.default.Children.map(toolbarChildren, function (toolbarSection, sectionIndex) {
    if (!React__default.default.isValidElement(toolbarSection)) {
      return toolbarChildren;
    }
    var _a = toolbarSection.props,
      sectionChildren = _a.children,
      toolbarSectionProps = tslib.__rest(_a, ["children"]);
    return React__default.default.createElement(toolbarSection.type, tslib.__assign({}, toolbarSectionProps, {
      key: "rte-section-".concat(sectionIndex)
    }), React__default.default.Children.map(sectionChildren, function (toolbarButton) {
      if (!React__default.default.isValidElement(toolbarButton)) {
        return;
      }
      var buttonIndex = buttonCount;
      buttonCount += 1;
      return React__default.default.createElement(toolbarButton.type, tslib.__assign({}, toolbarButton.props, {
        key: "rte-button-".concat(buttonIndex),
        tabIndex: buttonIndex === buttonFocusIndex ? 0 : -1,
        onKeyDown: function (e) {
          return handleKeyDown(e, buttonIndex, buttonFocusIndex, setButtonFocusIndex, toolbarButtonsRef);
        },
        ref: function (ref) {
          return toolbarButtonsRef.current[buttonIndex] = ref;
        }
      }));
    }));
  }));
};
Toolbar.displayName = 'Toolbar';
exports.Toolbar = Toolbar;
