'use strict';

var ProseMirrorState = require('prosemirror-state');
var prosemirrorView = require('prosemirror-view');

/**
 * createRichTextEditor
 * Initialize a ProseMirror EditorView
 */
var createRichTextEditor = function (_a) {
  var initialEditorState = _a.initialEditorState,
    node = _a.node,
    _b = _a.onChange,
    onChange = _b === void 0 ? function () {
      return undefined;
    } : _b,
    attributes = _a.attributes,
    _c = _a.isEditable,
    isEditable = _c === void 0 ? function () {
      return true;
    } : _c;
  var editorView = null;
  // Handle transactions eminating from the EditorView instance
  var dispatch = function (tx) {
    var newEditorState = editorView === null || editorView === void 0 ? void 0 : editorView.state.apply(tx);
    if (newEditorState) {
      onChange(newEditorState);
      editorView === null || editorView === void 0 ? void 0 : editorView.updateState(newEditorState);
    }
  };
  // Allow the dispatcher to handle either a Command or a Transaction so we can
  // change the state more ergonomically upstream
  var dispatchCommandOrTransaction = function (commandOrTransaction) {
    if (commandOrTransaction instanceof ProseMirrorState.Transaction) {
      dispatch(commandOrTransaction);
    } else if (editorView) {
      commandOrTransaction(editorView.state, dispatch);
    }
  };
  editorView = new prosemirrorView.EditorView(node, {
    state: initialEditorState,
    dispatchTransaction: dispatchCommandOrTransaction,
    attributes: attributes,
    editable: isEditable
  });
  return {
    destroy: function () {
      return editorView.destroy();
    },
    dispatchTransaction: dispatchCommandOrTransaction
  };
};
exports.createRichTextEditor = createRichTextEditor;
