'use strict';

var ProseMirrorModel = require('prosemirror-model');
var ProseMirrorState = require('prosemirror-state');

/**
 * createEditorState
 * Create a ProseMirror EditorState. Wrapper for EditorState.create to make the
 * API obvious to consumers
 */
var createEditorState = function (schema, doc, plugins) {
  if (plugins === void 0) {
    plugins = [];
  }
  return ProseMirrorState.EditorState.create({
    doc: doc,
    schema: schema,
    plugins: plugins
  });
};
/**
 * Create a ProseMirror doc node from the combination of a schema and the object
 * representation of a document
 */
var createDocNode = function (schema, docObject) {
  return ProseMirrorModel.Node.fromJSON(schema, docObject);
};
/**
 * Create a ProseMirror doc node from the combination of a schema and the doc’s
 * content array (rather than the top-level doc node).
 */
var createDocNodeFromContent = function (schema, docContent) {
  return createDocNode(schema, {
    type: 'doc',
    content: docContent
  });
};
exports.createDocNode = createDocNode;
exports.createDocNodeFromContent = createDocNodeFromContent;
exports.createEditorState = createEditorState;
