'use strict';

var tslib = require('tslib');
var React = require('react');
var Nanobus = require('nanobus');
var client = require('react-dom/client');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var Nanobus__default = /*#__PURE__*/_interopDefault(Nanobus);
var Wrapper = function (_a) {
  var emitter = _a.emitter,
    componentProps = _a.componentProps,
    Component = _a.Component;
  var _b = React.useState(componentProps),
    localComponentProps = _b[0],
    setLocalComponentProps = _b[1];
  React.useEffect(function () {
    var onUpdate = function (newComponentProps) {
      setLocalComponentProps(newComponentProps);
    };
    emitter.addListener('update', onUpdate);
    return function () {
      emitter.removeListener('update', onUpdate);
    };
  }, [emitter]);
  return React__default.default.createElement(Component, tslib.__assign({}, localComponentProps));
};
/**
 * Create a wrapping connector for rendering a React element into a separate
 * part of the DOM while being able to update it without remounting.
 */
var createReactTooltipWrapper = function (parentNode, Component, componentProps) {
  var emitter = new Nanobus__default.default();
  var container = document.createElement('div');
  parentNode.appendChild(container);
  var root = client.createRoot(container);
  root.render(React__default.default.createElement(Wrapper, {
    componentProps: componentProps,
    Component: Component,
    emitter: emitter
  }));
  function destroy() {
    root.unmount();
    emitter.removeAllListeners('*');
  }
  function update(props) {
    emitter.emit('update', props);
  }
  return {
    destroy: destroy,
    update: update
  };
};
exports.createReactTooltipWrapper = createReactTooltipWrapper;
