'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var ReactSelect = require('react-select');
var Async = require('react-select/async');
var FieldMessage = require('../FieldMessage/FieldMessage.cjs');
var Label = require('../Label/Label.cjs');
var Tag = require('../Tag/Tag.cjs');
var Icon = require('../__next__/Icon/Icon.cjs');
var Select_module = require('./Select.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var ReactSelect__default = /*#__PURE__*/_interopDefault(ReactSelect);
var Async__default = /*#__PURE__*/_interopDefault(Async);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896474/Select Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-select--docs Storybook}
 */
var Select = React__default.default.forwardRef(function (_a, ref) {
  var _b = _a.variant,
    variant = _b === void 0 ? 'default' : _b,
    _c = _a.status,
    status = _c === void 0 ? 'default' : _c,
    _d = _a.reversed,
    reversed = _d === void 0 ? false : _d,
    label = _a.label,
    validationMessage = _a.validationMessage,
    description = _a.description,
    propsFullWidth = _a.fullWidth,
    propsClassName = _a.className,
    placeholder = _a.placeholder,
    props = tslib.__rest(_a, ["variant", "status", "reversed", "label", "validationMessage", "description", "fullWidth", "className", "placeholder"]);
  var reactId = React.useId();
  // the default for fullWidth depends on the variant
  var fullWidth = propsFullWidth !== null && propsFullWidth !== void 0 ? propsFullWidth : !['secondary', 'secondary-small'].includes(variant);
  var classes = classnames__default.default(propsClassName, Select_module.specificityIncreaser, (!reversed || variant === 'default') && Select_module.default, reversed && Select_module.reversed, variant === 'secondary' && Select_module.secondary, variant === 'secondary-small' && Select_module.secondarySmall, !fullWidth && Select_module.notFullWidth, props.isDisabled && Select_module.disabled, status === 'error' && Select_module.error);
  var labelId = React.useState(label ? reactId : undefined)[0];
  return React__default.default.createElement(React__default.default.Fragment, null, label ? React__default.default.createElement(Label.Label, {
    reversed: reversed,
    id: labelId
  }, label) : null, React__default.default.createElement(ReactSelect__default.default, tslib.__assign({}, props, {
    ref: ref,
    "aria-labelledby": labelId,
    placeholder: placeholder !== null && placeholder !== void 0 ? placeholder : '',
    components: {
      Control: Control,
      Placeholder: Placeholder,
      DropdownIndicator: DropdownIndicator,
      Menu: Menu,
      GroupHeading: GroupHeading,
      Option: Option,
      NoOptionsMessage: NoOptionsMessage,
      Input: Input,
      SingleValue: SingleValue,
      MultiValue: MultiValue,
      IndicatorsContainer: IndicatorsContainer,
      ValueContainer: ValueContainer,
      ClearIndicator: ClearIndicator,
      IndicatorSeparator: null
    },
    className: classes
  })), validationMessage ? React__default.default.createElement(FieldMessage.FieldMessage, {
    message: validationMessage,
    status: status
  }) : null, description ? React__default.default.createElement(FieldMessage.FieldMessage, {
    message: description
  }) : null);
});
Select.displayName = 'Select';
var AsyncSelect = React__default.default.forwardRef(function (_a, ref) {
  var propsClassName = _a.className,
    placeholder = _a.placeholder,
    props = tslib.__rest(_a, ["className", "placeholder"]);
  return React__default.default.createElement(Async__default.default, tslib.__assign({}, props, {
    ref: ref,
    placeholder: placeholder !== null && placeholder !== void 0 ? placeholder : '',
    components: {
      Control: Control,
      Placeholder: Placeholder,
      DropdownIndicator: DropdownIndicator,
      Menu: Menu,
      Option: Option,
      NoOptionsMessage: NoOptionsMessage,
      Input: Input,
      SingleValue: SingleValue,
      MultiValue: MultiValue,
      IndicatorsContainer: IndicatorsContainer,
      ValueContainer: ValueContainer,
      ClearIndicator: undefined,
      IndicatorSeparator: null,
      LoadingMessage: LoadingMessage
    },
    className: classnames__default.default(Select_module.specificityIncreaser, propsClassName)
  }));
});
AsyncSelect.displayName = 'AsyncSelect';
var Control = function (props) {
  return React__default.default.createElement("div", {
    "data-automation-id": "Select__Control"
  }, React__default.default.createElement(ReactSelect.components.Control, tslib.__assign({}, props, {
    className: classnames__default.default(Select_module.control, props.isFocused && Select_module.focusedControl, props.isDisabled && Select_module.disabled)
  })));
};
var Placeholder = function (props) {
  return React__default.default.createElement(ReactSelect.components.Placeholder, tslib.__assign({}, props, {
    className: Select_module.placeholderOverrides
  }), React__default.default.createElement("span", {
    className: Select_module.placeholder
  }, props.children));
};
var DropdownIndicator = function (props) {
  return React__default.default.createElement(ReactSelect.components.DropdownIndicator, tslib.__assign({}, props, {
    className: Select_module.dropdownIndicator
  }), React__default.default.createElement(Icon.Icon, {
    name: props.selectProps.menuIsOpen ? 'keyboard_arrow_up' : 'keyboard_arrow_down',
    isPresentational: true
  }));
};
var LoadingMessage = function (props) {
  return React__default.default.createElement(ReactSelect.components.LoadingMessage, tslib.__assign({}, props, {
    className: Select_module.loadingMessage
  }));
};
var Menu = function (props) {
  return React__default.default.createElement(ReactSelect.components.Menu, tslib.__assign({}, props, {
    className: Select_module.menu
  }));
};
var GroupHeading = function (props) {
  return React__default.default.createElement(ReactSelect.components.GroupHeading, tslib.__assign({}, props, {
    className: Select_module.groupHeading
  }));
};
var Option = function (props) {
  return React__default.default.createElement("div", {
    "data-automation-id": "Select__Option"
  }, React__default.default.createElement(ReactSelect.components.Option, tslib.__assign({}, props, {
    className: classnames__default.default(Select_module.option, props.isFocused && Select_module.focusedOption, props.isSelected && Select_module.selectedOption, props.isDisabled && Select_module.disabledOption)
  })));
};
var NoOptionsMessage = function (props) {
  return React__default.default.createElement(ReactSelect.components.NoOptionsMessage, tslib.__assign({}, props), React__default.default.createElement("span", {
    className: Select_module.noOptionsMessage
  }, props.children));
};
var SingleValue = function (props) {
  return React__default.default.createElement(ReactSelect.components.SingleValue, tslib.__assign({}, props, {
    className: Select_module.singleValueOverrides
  }), React__default.default.createElement("span", {
    className: Select_module.singleValue
  }, props.children));
};
var MultiValue = function (props) {
  return React__default.default.createElement("div", {
    className: Select_module.multiValue
  }, React__default.default.createElement(Tag.Tag, {
    variant: "default",
    dismissible: true,
    inline: true,
    onDismiss: props.removeProps.onClick
  }, props.children));
};
var IndicatorsContainer = function (props) {
  return React__default.default.createElement(ReactSelect.components.IndicatorsContainer, tslib.__assign({}, props, {
    className: Select_module.indicatorsContainer
  }));
};
var Input = function (props) {
  return React__default.default.createElement(ReactSelect.components.Input, tslib.__assign({
    className: Select_module.input
  }, props));
};
var ValueContainer = function (props) {
  return React__default.default.createElement(ReactSelect.components.ValueContainer, tslib.__assign({}, props, {
    className: Select_module.valueContainer
  }));
};
var ClearIndicator = function (props) {
  return React__default.default.createElement(ReactSelect.components.ClearIndicator, tslib.__assign({}, props, {
    className: Select_module.clearIndicator
  }), React__default.default.createElement(Icon.Icon, {
    name: "cancel",
    isPresentational: true,
    isFilled: true
  }));
};
exports.AsyncSelect = AsyncSelect;
exports.Select = Select;
