'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Container = require('../Container/Container.cjs');
var Content = require('../Content/Content.cjs');
var useResizeObserver = require('../utils/useResizeObserver.cjs');
var Skirt_module = require('./Skirt.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var spacing = 24;
var maxHeight = 222;
var fallbackPercentage = 0.8;
var Skirt = function (_a) {
  var children = _a.children,
    _b = _a.variant,
    variant = _b === void 0 ? 'default' : _b,
    _c = _a.titleBlockHasNavigation,
    titleBlockHasNavigation = _c === void 0 ? true : _c,
    classNameOverride = _a.classNameOverride,
    restProps = tslib.__rest(_a, ["children", "variant", "titleBlockHasNavigation", "classNameOverride"]);
  var _d = useResizeObserver.useResizeObserver(function (entry) {
      if (entry.contentRect) {
        return deriveSkirtHeight(entry.contentRect, titleBlockHasNavigation);
      }
      return undefined;
    }),
    ref = _d[0],
    skirtHeight = _d[1];
  return React__default.default.createElement(Container.Container, tslib.__assign({
    ref: ref,
    classNameOverride: classnames__default.default(Skirt_module.container, classNameOverride)
  }, restProps), React__default.default.createElement("div", {
    style: tslib.__assign({}, skirtHeight && {
      height: "".concat(skirtHeight, "px")
    }),
    className: classnames__default.default(Skirt_module.underlay, Skirt_module["".concat(variant, "Variant")])
  }), React__default.default.createElement(Content.Content, {
    classNameOverride: Skirt_module.content
  }, children));
};
Skirt.displayName = 'Skirt';
var deriveSkirtHeight = function (rect, titleBlockHasNavigation) {
  var height = rect.height,
    width = rect.width;
  var responsiveOffset = 0;
  if (width > 768) {
    responsiveOffset = 2.8125 * 16;
  }
  // This ensures the maximum height of the skirt is consistent between pages
  // where the title block has/doesn’t have navigation
  var derivedMaxHeight = titleBlockHasNavigation ? maxHeight : maxHeight + responsiveOffset;
  var maxHeightWithSpacing = derivedMaxHeight + spacing;
  return Math.max(spacing, height > maxHeightWithSpacing ? derivedMaxHeight : height * fallbackPercentage - spacing);
};
exports.Skirt = Skirt;
