'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Checkbox = require('../Checkbox/Checkbox/Checkbox.cjs');
require('../Checkbox/CheckboxField/CheckboxField.cjs');
require('../Checkbox/CheckboxGroup/CheckboxGroup.cjs');
var Heading = require('../Heading/Heading.cjs');
var Tooltip = require('../Tooltip/Tooltip.cjs');
var Icon = require('../__next__/Icon/Icon.cjs');
var Table_module = require('./Table.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081929256/Table Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-table--docs Storybook}
 */
var TableContainer = function (_a) {
  var _b = _a.variant,
    variant = _b === void 0 ? 'compact' : _b,
    children = _a.children,
    otherProps = tslib.__rest(_a, ["variant", "children"]);
  return React__default.default.createElement("div", tslib.__assign({
    role: "table",
    className: classnames__default.default(Table_module.container, variant === 'default' && Table_module.defaultSpacing, variant === 'data' && Table_module.dataVariant)
  }, otherProps), children);
};
var TableHeader = function (_a) {
  var children = _a.children,
    otherProps = tslib.__rest(_a, ["children"]);
  return React__default.default.createElement("div", tslib.__assign({
    role: "rowgroup"
  }, otherProps), children);
};
var ratioToPercent = function (width) {
  return width != null ? "".concat(width * 100, "%") : width;
};
var TableHeaderRowCell = function (_a) {
  var _b;
  var labelText = _a.labelText,
    onClick = _a.onClick,
    href = _a.href,
    width = _a.width,
    flex = _a.flex,
    icon = _a.icon,
    checkable = _a.checkable,
    checkedStatus = _a.checkedStatus,
    checkboxLabel = _a.checkboxLabel,
    onCheck = _a.onCheck,
    reversed = _a.reversed,
    sortingRaw = _a.sorting,
    // I can't say for certain why "nowrap" was the default value. Normally you wouldn't
    // want to clip off information because it doesn't fit on one line.
    // My assumption is that because since the cell width rows are decoupled, a heading
    // cell with a word longer than the column width would push the columns out of
    // alignment? I'm not sure.
    // Anyway, we can override this default behaviour by setting wrapping to "wrap".
    _c = _a.wrapping,
    // I can't say for certain why "nowrap" was the default value. Normally you wouldn't
    // want to clip off information because it doesn't fit on one line.
    // My assumption is that because since the cell width rows are decoupled, a heading
    // cell with a word longer than the column width would push the columns out of
    // alignment? I'm not sure.
    // Anyway, we can override this default behaviour by setting wrapping to "wrap".
    wrapping = _c === void 0 ? 'nowrap' : _c,
    _d = _a.align,
    align = _d === void 0 ? 'start' : _d,
    tooltipInfo = _a.tooltipInfo,
    _e = _a.isTooltipIconHidden,
    isTooltipIconHidden = _e === void 0 ? false : _e,
    tooltipPortalSelector = _a.tooltipPortalSelector,
    sortingArrowsOnHover = _a.sortingArrowsOnHover,
    classNameOverride = _a.classNameOverride,
    // There aren't any other props in the type definition, so I'm unsure why we
    // have this spread.
    otherProps = tslib.__rest(_a, ["labelText", "onClick", "href", "width", "flex", "icon", "checkable", "checkedStatus", "checkboxLabel", "onCheck", "reversed", "sorting", "wrapping", "align", "tooltipInfo", "isTooltipIconHidden", "tooltipPortalSelector", "sortingArrowsOnHover", "classNameOverride"]);
  var sorting = sortingRaw;
  var _f = React__default.default.useState(false),
    isHovered = _f[0],
    setIsHovered = _f[1];
  var updateHoverState = function (hoverState) {
    if (sortingArrowsOnHover && hoverState != isHovered) setIsHovered(hoverState);
  };
  var headerColor = reversed ? 'white-reduced-opacity' : 'dark-reduced-opacity';
  var hoveredHeaderColor = reversed ? 'white' : 'dark';
  // For this "cellContents" variable, we start at the inner most child, and
  // wrap it elements, depending on what the props dictate.
  var cellContents = React__default.default.createElement("div", {
    className: Table_module.headerRowCellLabelAndIcons
  }, icon && React__default.default.createElement("span", {
    className: Table_module.headerRowCellIcon
  }, React.cloneElement(icon, (_b = {
    title: labelText
  }, _b['aria-label'] = labelText, _b.role = 'img', _b))), checkable && React__default.default.createElement("div", {
    className: Table_module.headerRowCellCheckbox
  }, React__default.default.createElement(Checkbox.Checkbox, {
    checkedStatus: checkedStatus,
    onCheck: onCheck,
    "aria-label": checkboxLabel
  })), tooltipInfo != null && !isTooltipIconHidden ? React__default.default.createElement("div", {
    className: Table_module.headerRowCellTooltipIcon
  }, React__default.default.createElement(Icon.Icon, {
    name: "error",
    isPresentational: true,
    isFilled: true
  })) : null, !icon ? React__default.default.createElement(Heading.Heading, {
    tag: "div",
    variant: "heading-6",
    color: sorting || isHovered ? hoveredHeaderColor : headerColor,
    classNameOverride: Table_module.headerRowCellLabel
  }, labelText) : null, (sorting !== null && sorting !== void 0 ? sorting : isHovered && sortingArrowsOnHover) && React__default.default.createElement("div", {
    className: classnames__default.default(align === 'center' && Table_module.headerRowCellIconAlignCenter, align === 'end' && Table_module.headerRowCellIconAlignEnd, reversed && Table_module.whiteText)
  }, sorting === 'ascending' || sortingArrowsOnHover === 'ascending' ? React__default.default.createElement(Icon.Icon, {
    name: "arrow_drop_up",
    isPresentational: true
  }) : React__default.default.createElement(Icon.Icon, {
    name: "arrow_drop_down",
    isPresentational: true
  })));
  cellContents = href ? React__default.default.createElement("a", {
    className: classnames__default.default(Table_module.headerRowCellButton, reversed && Table_module.headerRowCellButtonReversed),
    href: href,
    onClick: onClick,
    onMouseEnter: function () {
      return updateHoverState(true);
    },
    onFocus: function () {
      return updateHoverState(true);
    },
    onMouseLeave: function () {
      return updateHoverState(false);
    },
    onBlur: function () {
      return updateHoverState(false);
    }
  }, cellContents) : onClick ? React__default.default.createElement("button", {
    type: "button",
    className: classnames__default.default(Table_module.headerRowCellButton, reversed && Table_module.headerRowCellButtonReversed),
    onClick: onClick,
    onMouseEnter: function () {
      return updateHoverState(true);
    },
    onFocus: function () {
      return updateHoverState(true);
    },
    onMouseLeave: function () {
      return updateHoverState(false);
    },
    onBlur: function () {
      return updateHoverState(false);
    }
  }, cellContents) :
  // This div wrapper probably isn't needed, but it's a bit easier
  // for this flex positioning, to have the dom tree depth match for
  // each permutation.
  React__default.default.createElement("div", {
    className: Table_module.headerRowCellNoButton
  }, cellContents);
  cellContents = tooltipInfo != null ? React__default.default.createElement(Tooltip.Tooltip, {
    animationDuration: 0,
    classNameOverride: Table_module.headerRowCellTooltip,
    text: tooltipInfo,
    portalSelector: tooltipPortalSelector
  }, cellContents) :
  // Again, this wrapper is just to make the dom tree consistent between
  // different permutations.
  React__default.default.createElement("div", {
    className: Table_module.headerRowCellTooltip
  }, cellContents);
  return React__default.default.createElement("div", tslib.__assign({
    className: classnames__default.default(Table_module.headerRowCell, wrapping === 'nowrap' && Table_module.headerRowCellNoWrap, align === 'center' && Table_module.headerRowCellAlignCenter, align === 'end' && Table_module.headerRowCellAlignEnd, sorting && Table_module.headerRowCellActive, classNameOverride),
    style: {
      width: ratioToPercent(width),
      flex: flex
    },
    role: "columnheader"
  }, otherProps), cellContents);
};
var TableCard = function (_a) {
  var children = _a.children,
    expanded = _a.expanded,
    _b = _a.expandedStyle,
    expandedStyle = _b === void 0 ? 'well' : _b,
    onClick = _a.onClick,
    href = _a.href,
    _c = _a.forceHoverState,
    forceHoverState = _c === void 0 ? false : _c,
    classNameOverride = _a.classNameOverride,
    otherProps = tslib.__rest(_a, ["children", "expanded", "expandedStyle", "onClick", "href", "forceHoverState", "classNameOverride"]);
  var className = classnames__default.default(Table_module.card, expanded && Table_module.expanded, expanded && Table_module[expandedStyle], (forceHoverState || onClick != null || href != null) && Table_module.hasHoverState, classNameOverride);
  return href != null ? React__default.default.createElement("a", tslib.__assign({
    href: href,
    className: className,
    onClick: onClick
  }, otherProps), children) : onClick ? React__default.default.createElement("button", tslib.__assign({
    type: "button",
    className: className,
    onClick: onClick
  }, otherProps), children) : React__default.default.createElement("div", tslib.__assign({
    className: className
  }, otherProps), children);
};
var TableRow = function (_a) {
  var children = _a.children,
    classNameOverride = _a.classNameOverride,
    otherProps = tslib.__rest(_a, ["children", "classNameOverride"]);
  return React__default.default.createElement("div", tslib.__assign({
    className: classnames__default.default(Table_module.row, classNameOverride),
    role: "row"
  }, otherProps), children);
};
var TableRowCell = function (_a) {
  var children = _a.children,
    width = _a.width,
    flex = _a.flex,
    href = _a.href,
    classNameOverride = _a.classNameOverride,
    otherProps = tslib.__rest(_a, ["children", "width", "flex", "href", "classNameOverride"]);
  return href != null ? React__default.default.createElement("a", tslib.__assign({
    // eslint-disable-next-line jsx-a11y/no-interactive-element-to-noninteractive-role
    role: "cell",
    style: {
      width: ratioToPercent(width),
      flex: flex
    },
    className: classnames__default.default(Table_module.rowCell, classNameOverride),
    href: href
  }, otherProps), children) : React__default.default.createElement("div", tslib.__assign({
    role: "cell",
    style: {
      width: ratioToPercent(width),
      flex: flex
    },
    className: classnames__default.default(Table_module.rowCell, classNameOverride)
  }, otherProps), children);
};
exports.TableCard = TableCard;
exports.TableContainer = TableContainer;
exports.TableHeader = TableHeader;
exports.TableHeaderRowCell = TableHeaderRowCell;
exports.TableRow = TableRow;
exports.TableRowCell = TableRowCell;
