'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Avatar = require('../Avatar/Avatar.cjs');
var Icon = require('../__next__/Icon/Icon.cjs');
var LiveIcon = require('./subcomponents/LiveIcon/LiveIcon.cjs');
var Tag_module = require('./Tag.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var isJSXElement = function (imageElementOrAvatarProps) {
  return 'props' in imageElementOrAvatarProps;
};
var renderAvatar = function (imageElementOrAvatarProps) {
  return isJSXElement(imageElementOrAvatarProps) ? React__default.default.createElement(React__default.default.Fragment, null, imageElementOrAvatarProps) : React__default.default.createElement(Avatar.Avatar, tslib.__assign({}, imageElementOrAvatarProps, {
    size: "small"
  }));
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081928978/Tags Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-tag--docs Storybook}
 */
var Tag = function (props) {
  var children = props.children,
    _a = props.variant,
    variant = _a === void 0 ? 'default' : _a,
    _b = props.size,
    size = _b === void 0 ? 'medium' : _b,
    _c = props.inline,
    inline = _c === void 0 ? false : _c,
    _d = props.dismissible,
    dismissible = _d === void 0 ? false : _d,
    onDismiss = props.onDismiss,
    onMouseDown = props.onMouseDown,
    onMouseLeave = props.onMouseLeave,
    truncateWidth = props.truncateWidth;
  var isTruncated = truncateWidth && truncateWidth > 0;
  var canShowIcon = size === 'medium';
  return React__default.default.createElement("div", {
    className: classnames__default.default(Tag_module.root, Tag_module[variant], variant === 'profile' && Tag_module.default, Tag_module[size], inline && Tag_module.inline, dismissible && Tag_module.dismissible)
  }, React__default.default.createElement("div", {
    className: Tag_module.layoutContainer
  }, React__default.default.createElement(React__default.default.Fragment, null, canShowIcon && function () {
    switch (props.variant) {
      case 'validationPositive':
        return React__default.default.createElement("span", {
          className: Tag_module.validationIcon
        }, React__default.default.createElement(Icon.Icon, {
          name: "check_circle",
          isPresentational: true,
          isFilled: true
        }));
      case 'validationNegative':
        return React__default.default.createElement("span", {
          className: Tag_module.validationIcon
        }, React__default.default.createElement(Icon.Icon, {
          name: "error",
          isPresentational: true,
          isFilled: true
        }));
      case 'validationCautionary':
        return React__default.default.createElement("span", {
          className: Tag_module.validationIcon
        }, React__default.default.createElement(Icon.Icon, {
          name: "warning",
          isPresentational: true,
          isFilled: true
        }));
      case 'validationInformative':
        return React__default.default.createElement("span", {
          className: Tag_module.validationIcon
        }, React__default.default.createElement(Icon.Icon, {
          name: "info",
          isPresentational: true,
          isFilled: true
        }));
      case 'profile':
        return React__default.default.createElement("span", {
          className: Tag_module.profile
        }, props.avatar && renderAvatar(props.avatar));
      default:
        return null;
    }
  }(), React__default.default.createElement("span", {
    className: classnames__default.default(Tag_module.textContent, isTruncated && Tag_module.truncate),
    style: {
      maxWidth: isTruncated ? truncateWidth : undefined
    }
  }, children), dismissible && React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement("button", {
    type: "button",
    className: Tag_module.dismissButton,
    onClick: onDismiss,
    onMouseDown: onMouseDown,
    onMouseLeave: onMouseLeave
  }, React__default.default.createElement("div", {
    className: Tag_module.iconWrapper
  }, React__default.default.createElement(Icon.Icon, {
    name: "cancel",
    alt: "Dismiss",
    isFilled: true
  })))), variant === 'statusLive' && React__default.default.createElement(LiveIcon.LiveIcon, null))));
};
Tag.displayName = 'Tag';
exports.Tag = Tag;
