'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var FieldGroup = require('../FieldGroup/FieldGroup.cjs');
var FieldMessage = require('../FieldMessage/FieldMessage.cjs');
var Label = require('../Label/Label.cjs');
var TextArea = require('../TextArea/TextArea.cjs');
var TextAreaField_module = require('./TextAreaField.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081895966/Text+Area+Field Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-text-area-field--docs Storybook}
 */
var TextAreaField = function (_a) {
  var labelText = _a.labelText,
    _b = _a.inline,
    inline = _b === void 0 ? false : _b,
    validationMessage = _a.validationMessage,
    description = _a.description,
    _c = _a.variant,
    variant = _c === void 0 ? 'default' : _c,
    propsId = _a.id,
    _d = _a.reversed,
    reversed = _d === void 0 ? false : _d,
    _e = _a.status,
    status = _e === void 0 ? 'default' : _e,
    disabled = _a.disabled,
    restProps = tslib.__rest(_a, ["labelText", "inline", "validationMessage", "description", "variant", "id", "reversed", "status", "disabled"]);
  var fallbackId = React.useId();
  var id = propsId !== null && propsId !== void 0 ? propsId : fallbackId;
  var validationMessageAria = validationMessage ? "".concat(id, "-field-validation-message") : '';
  var descriptionAria = description ? "".concat(id, "-field-message") : '';
  var ariaDescribedBy = [validationMessageAria, descriptionAria].reduce(function (prev, curr) {
    return curr ? [curr, prev].join(' ') : prev;
  }, '');
  var renderDescriptionOnTop = variant === 'prominent';
  var renderDescription = function (position) {
    if (!description) return null;
    return React__default.default.createElement("div", {
      className: classnames__default.default(TextAreaField_module.message, disabled && TextAreaField_module.disabled)
    }, React__default.default.createElement(FieldMessage.FieldMessage, {
      id: descriptionAria,
      "data-testid": "".concat(id, "-field-description"),
      message: description,
      reversed: reversed,
      position: position
    }));
  };
  return React__default.default.createElement(FieldGroup.FieldGroup, {
    id: "".concat(id, "-field-group"),
    inline: inline,
    "data-testid": "".concat(id, "-field-group"),
    classNameOverride: disabled ? TextAreaField_module.disabled : undefined
  }, React__default.default.createElement("div", {
    className: classnames__default.default(TextAreaField_module.textareaLabel, variant === 'prominent' && TextAreaField_module.textareaLabelProminent)
  }, React__default.default.createElement(Label.Label, {
    id: "".concat(id, "-field-label"),
    "data-testid": "".concat(id, "-field-label"),
    htmlFor: "".concat(id, "-field-textarea"),
    labelText: labelText,
    reversed: reversed,
    variant: variant,
    disabled: disabled
  })), renderDescriptionOnTop && renderDescription('top'), React__default.default.createElement(TextArea.TextArea, tslib.__assign({
    id: "".concat(id, "-field-textarea"),
    "data-testid": "".concat(id, "-field-textarea"),
    reversed: reversed,
    status: status,
    disabled: disabled,
    "aria-describedby": ariaDescribedBy
  }, restProps)), !disabled && validationMessage && React__default.default.createElement(FieldMessage.FieldMessage, {
    id: validationMessageAria,
    "data-testid": validationMessageAria,
    message: validationMessage,
    status: status,
    reversed: reversed
  }), !renderDescriptionOnTop && renderDescription('bottom'));
};
TextAreaField.displayName = 'TextAreaField';
exports.TextAreaField = TextAreaField;
