'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Avatar = require('../Avatar/Avatar.cjs');
require('../Button/Button/Button.cjs');
var IconButton = require('../Button/IconButton/IconButton.cjs');
var Heading = require('../Heading/Heading.cjs');
var Select = require('../Select/Select.cjs');
var Tag = require('../Tag/Tag.cjs');
var Icon = require('../__next__/Icon/Icon.cjs');
var useMediaQueries = require('../utils/useMediaQueries.cjs');
var MainActions = require('./subcomponents/MainActions.cjs');
var MobileActions = require('./subcomponents/MobileActions.cjs');
var SecondaryActions = require('./subcomponents/SecondaryActions.cjs');
var utils = require('./utils.cjs');
var TitleBlockZen_module = require('./TitleBlockZen.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var renderTag = function (surveyStatus) {
  var tagVariant;
  if (tagVariant === 'profile') {
    return null;
  }
  if (surveyStatus.status === 'draft') {
    tagVariant = 'statusDraft';
  }
  /*
    scheduled is actually a draft survey status that has a launch job scheduled
    still, we want to differentiate on the UI and render a specific tag
    the styles must be identical to the draft style
       we have similar behaviour on programs index page's table
  */
  if (surveyStatus.status === 'scheduled') {
    tagVariant = 'statusClosed';
  }
  if (surveyStatus.status === 'live') {
    tagVariant = 'statusLive';
  }
  if (surveyStatus.status === 'closed') {
    tagVariant = 'statusClosed';
  }
  if (surveyStatus.status === 'sentimentPositive') {
    tagVariant = 'sentimentPositive';
  }
  if (surveyStatus.status === 'default') {
    tagVariant = 'default';
  }
  return React__default.default.createElement("div", {
    "data-automation-id": "survey-status-tag",
    "data-testid": "survey-status-tag",
    className: TitleBlockZen_module.tag
  }, React__default.default.createElement(Tag.Tag, {
    variant: tagVariant,
    size: "small"
  }, surveyStatus.text));
};
var isJSXElement = function (imageElementOrAvatarProps) {
  return 'props' in imageElementOrAvatarProps;
};
var renderAvatar = function (imageElementOrAvatarProps, avatarAutomationId) {
  return isJSXElement(imageElementOrAvatarProps) ? React__default.default.createElement("div", {
    "data-automation-id": avatarAutomationId,
    "data-testid": avatarAutomationId,
    className: classnames__default.default(TitleBlockZen_module.avatar, TitleBlockZen_module.withBorder)
  }, imageElementOrAvatarProps) : React__default.default.createElement("div", {
    "data-automation-id": avatarAutomationId,
    "data-testid": avatarAutomationId,
    className: TitleBlockZen_module.avatar
  }, React__default.default.createElement(Avatar.Avatar, tslib.__assign({}, imageElementOrAvatarProps, {
    size: "medium"
  })));
};
var renderSubtitle = function (subtitle, subtitleAutomationId) {
  return React__default.default.createElement("div", {
    className: TitleBlockZen_module.subtitle
  }, React__default.default.createElement("span", {
    "data-automation-id": subtitleAutomationId,
    "data-testid": subtitleAutomationId,
    className: TitleBlockZen_module.subtitleText
  }, subtitle));
};
var defaultRenderSectionTitle = function (sectionTitle, sectionTitleDescription, variant, sectionTitleAutomationId, sectionTitleDescriptionAutomationId) {
  return React__default.default.createElement(React__default.default.Fragment, null, sectionTitle && React__default.default.createElement("div", {
    className: TitleBlockZen_module.sectionTitle
  }, React__default.default.createElement(Heading.Heading, {
    variant: "heading-2",
    color: utils.isReversed(variant) ? 'white' : 'dark',
    classNameOverride: TitleBlockZen_module.sectionTitleOverride,
    "data-automation-id": sectionTitleAutomationId,
    "data-testid": sectionTitleAutomationId
  }, sectionTitle)), sectionTitleDescription && React__default.default.createElement("div", {
    "data-automation-id": sectionTitleDescriptionAutomationId,
    "data-testid": sectionTitleDescriptionAutomationId,
    className: classnames__default.default(TitleBlockZen_module.sectionTitleDescription, !utils.isReversed(variant) && TitleBlockZen_module.dark)
  }, sectionTitleDescription));
};
var Breadcrumb = function (_a) {
  var breadcrumb = _a.breadcrumb,
    automationId = _a.automationId,
    textAutomationId = _a.textAutomationId,
    textDirection = _a.textDirection;
  var path = breadcrumb.path,
    handleClick = breadcrumb.handleClick,
    text = breadcrumb.text,
    render = breadcrumb.render;
  var InnerContents = function () {
    return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement("div", {
      className: TitleBlockZen_module.circle
    }, React__default.default.createElement(Icon.Icon, {
      name: "arrow_back",
      isPresentational: true,
      shouldMirrorInRTL: true
    })), React__default.default.createElement("span", {
      className: TitleBlockZen_module.breadcrumbTextLink,
      "data-automation-id": textAutomationId,
      "data-testid": textAutomationId
    }, React__default.default.createElement("span", {
      className: TitleBlockZen_module.breadcrumbText
    }, text)));
  };
  if (render) {
    var CustomRender = render;
    return React__default.default.createElement(CustomRender, {
      breadcrumb: breadcrumb,
      className: TitleBlockZen_module.breadcrumb,
      automationId: automationId,
      textAutomationId: textAutomationId,
      textDirection: textDirection
    }, React__default.default.createElement(InnerContents, null));
  }
  var TagName = path ? 'a' : 'button';
  return React__default.default.createElement(TagName, tslib.__assign({}, path && {
    href: path
  }, {
    className: TitleBlockZen_module.breadcrumb,
    "data-automation-id": automationId,
    "data-testid": automationId,
    onClick: handleClick
  }), React__default.default.createElement(InnerContents, null));
};
// We want to accept undefined here because the NavigationTabs container is
// important for the flex-based layout (it pushes Secondary Actions over to the right)
var renderNavigationTabs = function (navigationTabs, collapse, ariaLabel) {
  return React__default.default.createElement("div", {
    className: TitleBlockZen_module.navigationTabScrollerContainer
  }, React__default.default.createElement("div", {
    className: classnames__default.default(TitleBlockZen_module.navigationTabsContainer, collapse && TitleBlockZen_module.navigationTabsContainerCollapsed)
  }, !collapse && navigationTabs !== undefined && React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement("span", {
    className: TitleBlockZen_module.navigationTabEdgeShadowLeft
  }), React__default.default.createElement("nav", {
    className: TitleBlockZen_module.navigationTabsNav,
    "aria-label": ariaLabel
  }, React__default.default.createElement("ul", {
    className: TitleBlockZen_module.navigationTabsList
  }, navigationTabs.map(function (navigationTab, index) {
    return React__default.default.createElement("li", {
      key: index
    }, navigationTab);
  }))), React__default.default.createElement("span", {
    className: TitleBlockZen_module.navigationTabEdgeShadowRight
  }))));
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3075605782/Title+Block Guidance} |
 * {@link https://cultureamp.design/?path=/story/components-titleblock--docs Storybook}
 */
var TitleBlockZen = function (_a) {
  var _b, _c, _d, _e;
  var title = _a.title,
    variant = _a.variant,
    breadcrumb = _a.breadcrumb,
    avatar = _a.avatar,
    subtitle = _a.subtitle,
    sectionTitle = _a.sectionTitle,
    sectionTitleDescription = _a.sectionTitleDescription,
    renderSectionTitle = _a.renderSectionTitle,
    pageSwitcherSelect = _a.pageSwitcherSelect,
    handleHamburgerClick = _a.handleHamburgerClick,
    primaryAction = _a.primaryAction,
    defaultAction = _a.defaultAction,
    secondaryActions = _a.secondaryActions,
    secondaryOverflowMenuItems = _a.secondaryOverflowMenuItems,
    navigationTabs = _a.navigationTabs,
    _f = _a.collapseNavigationAreaWhenPossible,
    collapseNavigationAreaWhenPossible = _f === void 0 ? false : _f,
    textDirection = _a.textDirection,
    surveyStatus = _a.surveyStatus,
    id = _a.id,
    _g = _a.titleAutomationId,
    titleAutomationId = _g === void 0 ? 'TitleBlock__Title' : _g,
    _h = _a.avatarAutomationId,
    avatarAutomationId = _h === void 0 ? 'TitleBlock__Avatar' : _h,
    _j = _a.subtitleAutomationId,
    subtitleAutomationId = _j === void 0 ? 'TitleBlock__Subtitle' : _j,
    _k = _a.sectionTitleAutomationId,
    sectionTitleAutomationId = _k === void 0 ? 'TitleBlock__SectionTitle' : _k,
    _l = _a.sectionTitleDescriptionAutomationId,
    sectionTitleDescriptionAutomationId = _l === void 0 ? 'TitleBlock__SectionTitleDescription' : _l,
    _m = _a.breadcrumbAutomationId,
    breadcrumbAutomationId = _m === void 0 ? 'TitleBlock__Breadcrumb' : _m,
    _o = _a.breadcrumbTextAutomationId,
    breadcrumbTextAutomationId = _o === void 0 ? 'TitleBlock__BreadcrumbText' : _o,
    _p = _a.autoHideMobileActionsMenu,
    autoHideMobileActionsMenu = _p === void 0 ? false : _p;
  var hasNavigationTabs = navigationTabs && navigationTabs.length > 0;
  var collapseNavigationArea = collapseNavigationAreaWhenPossible && !hasNavigationTabs && secondaryActions === undefined;
  var _q = useMediaQueries.useMediaQueries().queries,
    isSmall = _q.isSmall,
    isMedium = _q.isMedium;
  var isSmallOrMediumViewport = isMedium || isSmall;
  return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement("div", {
    id: id,
    className: classnames__default.default(TitleBlockZen_module.titleBlock, TitleBlockZen_module["".concat(variant, "Variant")], Boolean(subtitle) && TitleBlockZen_module.hasSubtitle, Boolean(pageSwitcherSelect) && TitleBlockZen_module.hasPageSwitcherSelect, collapseNavigationArea && !((_b = sectionTitle !== null && sectionTitle !== void 0 ? sectionTitle : sectionTitleDescription) !== null && _b !== void 0 ? _b : renderSectionTitle) && TitleBlockZen_module.collapseNavigationArea, title && title.length >= 30 && TitleBlockZen_module.hasLongTitle, subtitle && typeof subtitle === 'string' && subtitle.length >= 18 && TitleBlockZen_module.hasLongSubtitle, hasNavigationTabs && TitleBlockZen_module.hasNavigationTabs)
  }, React__default.default.createElement("div", {
    className: TitleBlockZen_module.titleRow
  }, React__default.default.createElement("div", {
    className: TitleBlockZen_module.titleRowInner
  }, React__default.default.createElement("div", {
    className: TitleBlockZen_module.titleRowInnerContent
  }, React__default.default.createElement("div", {
    className: TitleBlockZen_module.titleAndAdjacent
  }, breadcrumb && React__default.default.createElement(Breadcrumb, {
    breadcrumb: breadcrumb,
    automationId: breadcrumbAutomationId,
    textAutomationId: breadcrumbTextAutomationId,
    textDirection: textDirection
  }), React__default.default.createElement("div", {
    className: TitleBlockZen_module.titleAndAdjacentNotBreadcrumb
  }, React__default.default.createElement(React__default.default.Fragment, null, handleHamburgerClick && React__default.default.createElement("div", {
    className: TitleBlockZen_module.hamburger
  }, React__default.default.createElement(IconButton.IconButton, {
    onClick: handleHamburgerClick,
    icon: React__default.default.createElement(Icon.Icon, {
      name: "menu",
      isPresentational: true
    }),
    label: "Open menu",
    reversed: utils.isReversed(variant)
  })), avatar && renderAvatar(avatar, avatarAutomationId), React__default.default.createElement("div", {
    className: TitleBlockZen_module.titleAndSubtitle
  }, React__default.default.createElement("div", {
    className: TitleBlockZen_module.titleAndSubtitleInner
  }, React__default.default.createElement("div", {
    className: TitleBlockZen_module.title
  }, React__default.default.createElement(Heading.Heading, {
    variant: "composable-header-title",
    color: utils.isReversed(variant) ? 'white' : 'dark',
    classNameOverride: TitleBlockZen_module.titleTextOverride,
    "data-automation-id": titleAutomationId,
    "data-testid": titleAutomationId
  }, title)), isSmallOrMediumViewport && pageSwitcherSelect && React__default.default.createElement("div", {
    className: TitleBlockZen_module.pageSwitcherSelectUnderneathTitle
  }, React__default.default.createElement(Select.Select, tslib.__assign({}, pageSwitcherSelect, {
    variant: "secondary-small",
    reversed: true
  }))), subtitle && renderSubtitle(subtitle, subtitleAutomationId))), surveyStatus && renderTag(surveyStatus), !isSmallOrMediumViewport && pageSwitcherSelect && React__default.default.createElement("div", {
    className: TitleBlockZen_module.pageSwitcherSelectNextToTitle
  }, React__default.default.createElement(Select.Select, tslib.__assign({}, pageSwitcherSelect, {
    variant: "secondary",
    reversed: true,
    fullWidth: true
  })))))), ((_d = (_c = primaryAction !== null && primaryAction !== void 0 ? primaryAction : defaultAction) !== null && _c !== void 0 ? _c : secondaryActions) !== null && _d !== void 0 ? _d : secondaryOverflowMenuItems) && React__default.default.createElement(MainActions.MainActions, {
    primaryAction: primaryAction,
    defaultAction: defaultAction,
    reversed: utils.isReversed(variant),
    overflowMenuItems: utils.createTabletOverflowMenuItems(secondaryActions, secondaryOverflowMenuItems),
    showOverflowMenu: isSmallOrMediumViewport
  })))), React__default.default.createElement("div", {
    className: TitleBlockZen_module.rowBelowSeparator
  }, React__default.default.createElement("div", {
    className: TitleBlockZen_module.rowBelowSeparatorInner
  }, React__default.default.createElement("div", {
    className: TitleBlockZen_module.rowBelowSeparatorInnerContent
  }, ((_e = sectionTitle !== null && sectionTitle !== void 0 ? sectionTitle : sectionTitleDescription) !== null && _e !== void 0 ? _e : renderSectionTitle) && React__default.default.createElement("div", {
    className: TitleBlockZen_module.sectionTitleContainer
  }, React__default.default.createElement("div", {
    className: TitleBlockZen_module.sectionTitleInner
  }, renderSectionTitle ? renderSectionTitle({
    sectionTitle: sectionTitle,
    sectionTitleAutomationId: sectionTitleAutomationId,
    sectionTitleDescription: sectionTitleDescription,
    sectionTitleDescriptionAutomationId: sectionTitleDescriptionAutomationId
  }) : defaultRenderSectionTitle(sectionTitle, sectionTitleDescription, variant, sectionTitleAutomationId, sectionTitleDescriptionAutomationId))), renderNavigationTabs(navigationTabs, collapseNavigationArea, title), (secondaryActions !== null && secondaryActions !== void 0 ? secondaryActions : secondaryOverflowMenuItems) && React__default.default.createElement(SecondaryActions.SecondaryActions, {
    secondaryActions: secondaryActions,
    secondaryOverflowMenuItems: secondaryOverflowMenuItems,
    reversed: utils.isReversed(variant)
  })))), React__default.default.createElement(MobileActions.MobileActions, {
    primaryAction: primaryAction,
    defaultAction: defaultAction,
    secondaryActions: secondaryActions,
    secondaryOverflowMenuItems: secondaryOverflowMenuItems,
    drawerHandleLabelIconPosition: primaryAction && 'iconPosition' in primaryAction ? primaryAction.iconPosition : undefined,
    autoHide: autoHideMobileActionsMenu
  })));
};
TitleBlockZen.displayName = 'TitleBlockZen';
exports.TitleBlockZen = TitleBlockZen;
