'use strict';

var tslib = require('tslib');
var React = require('react');
var reactAriaComponents = require('react-aria-components');
var VisuallyHidden = require('../../VisuallyHidden/VisuallyHidden.cjs');
var ReversedColors = require('../../utils/ReversedColors/ReversedColors.cjs');
var mergeClassNames = require('../../utils/mergeClassNames.cjs');
var OverlayArrow = require('./OverlayArrow.cjs');
var Tooltip_module = require('./Tooltip.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);

/**
 * A tooltip displays a description of an element on hover or focus.
 */
var Tooltip = React.forwardRef(function (_a, ref) {
  var children = _a.children,
    className = _a.className,
    props = tslib.__rest(_a, ["children", "className"]);
  var triggerRef = reactAriaComponents.useContextProps(tslib.__assign({
    children: children,
    className: className
  }, props), ref, reactAriaComponents.TooltipContext)[0].triggerRef;
  var contextState = React.useContext(reactAriaComponents.TooltipTriggerStateContext);
  var reverseColors = ReversedColors.useReversedColors();
  var _b = React.useState(false),
    shouldInlineHiddenContent = _b[0],
    setShouldInlineHiddenContent = _b[1];
  React.useLayoutEffect(function () {
    var _a;
    setShouldInlineHiddenContent(!!((_a = triggerRef === null || triggerRef === void 0 ? void 0 : triggerRef.current) === null || _a === void 0 ? void 0 : _a.getAttribute('data-inline-hidden-content')));
  }, [triggerRef]);
  return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement(reactAriaComponents.Tooltip, tslib.__assign({
    ref: ref,
    offset: 8
  }, props, {
    className: mergeClassNames.mergeClassNames(Tooltip_module.tooltip, className, reverseColors && Tooltip_module.reversed)
  }), function (renderProps) {
    return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement(OverlayArrow.OverlayArrow, null), typeof children === 'function' ? children(renderProps) : children);
  }), shouldInlineHiddenContent ? React__default.default.createElement(VisuallyHidden.VisuallyHidden, null, typeof children === 'function' ? contextState && children({
    placement: 'center',
    isEntering: false,
    isExiting: false,
    state: contextState,
    defaultChildren: undefined
  }) : children) : null);
});
Tooltip.displayName = 'Tooltip';
Object.defineProperty(exports, "TooltipContext", {
  enumerable: true,
  get: function () {
    return reactAriaComponents.TooltipContext;
  }
});
exports.Tooltip = Tooltip;
