'use strict';

var classnames = require('classnames');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * Helper to merge classnames together with support for functions that receive state (render props).
 * This is useful when working with react-aria-components which have a feature where you can pass a function that receives state and returns a classname.
 * https://react-spectrum.adobe.com/react-aria/styling.html#render-props
 */
var mergeClassNames = function () {
  var classNames = [];
  for (var _i = 0; _i < arguments.length; _i++) {
    classNames[_i] = arguments[_i];
  }
  var containsFunction = classNames.some(function (className) {
    return typeof className === 'function';
  });
  // "as any" is used because TS is not smart enough to know that containsFunction means that ClassNameType doesn't extend Function
  if (!containsFunction) return classnames__default.default.apply(void 0, classNames);
  // "as any" is used because TS is not smart enough to know that containsFunction means that ClassNameType doesn't extend Function
  return function (state) {
    return classnames__default.default.apply(void 0, classNames.map(function (className) {
      return typeof className === 'function' ? className(state) : className;
    }));
  };
};
exports.mergeClassNames = mergeClassNames;
