'use strict';

var React = require('react');
var ResizeObserver = require('resize-observer-polyfill');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var ResizeObserver__default = /*#__PURE__*/_interopDefault(ResizeObserver);
var defaultCallback = function (entry) {
  return entry;
};
/**
 * Hook for observing changes to a DOM element via ResizeObserver.
 *
 * @param {resolveEntryCallback} resolveEntry - Callback for resolving the
 * desired value from each ResizeObserverEntry emitted by ResizeObserver
 * @return {Array} An array containing a ref for binding to the observed DOM
 * element, and the current value of the callback-resolved ResizeObserverEntry
 * @callback resolveEntryCallback
 * @deprecated use native `ResizeObserver` DOM API instead
 */
var useResizeObserver = function (resolveEntry) {
  if (resolveEntry === void 0) {
    resolveEntry = defaultCallback;
  }
  var destroyResizeObserverRef = React.useRef(undefined);
  var _a = React.useState(undefined),
    dimensions = _a[0],
    setDimensions = _a[1];
  var resolveEntryRef = React.useRef(resolveEntry);
  var ref = React.useCallback(function (node) {
    if (node) {
      var resizeObserver_1 = new ResizeObserver__default.default(function (entries) {
        for (var _i = 0, entries_1 = entries; _i < entries_1.length; _i++) {
          var entry = entries_1[_i];
          var value = resolveEntryRef.current(entry);
          if (value) {
            setDimensions(value);
          }
        }
      });
      resizeObserver_1.observe(node);
      destroyResizeObserverRef.current = function () {
        resizeObserver_1.disconnect();
      };
    }
  }, [destroyResizeObserverRef, setDimensions, resolveEntryRef]);
  // Ensure the resolveEntryRef has the latest value
  React.useEffect(function () {
    resolveEntryRef.current = resolveEntry;
  }, [resolveEntry]);
  // Destroy the observer on unmount
  React.useEffect(function () {
    return function () {
      if (destroyResizeObserverRef.current) {
        destroyResizeObserverRef.current();
      }
    };
  }, []);
  return [ref, dimensions];
};
exports.useResizeObserver = useResizeObserver;
