import { __rest, __assign } from 'tslib';
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import classnames from 'classnames';
import { useLink, useFocusable } from 'react-aria';
import { useContextProps, LinkContext } from 'react-aria-components';
import { BadgeAnimated, Badge } from '../../Badge/Badge.mjs';
import '../../Loading/LoadingGraphic/LoadingGraphic.mjs';
import '../../Loading/LoadingHeading/LoadingHeading.mjs';
import '../../Loading/LoadingInput/LoadingInput.mjs';
import '../../Loading/LoadingParagraph/LoadingParagraph.mjs';
import { LoadingSpinner } from '../../Loading/LoadingSpinner/LoadingSpinner.mjs';
import styles from './GenericButton.module.scss.mjs';

// We're treating custom props as anything that is kebab cased.
// This is so we can support properties like aria-* or data-*
var getCustomProps = function (props) {
  var keys = Object.keys(props).filter(function (k) {
    return k.includes('-');
  });
  return keys.reduce(function (acc, val) {
    acc[val] = props[val];
    return acc;
  }, {});
};
const GenericButton = /*#__PURE__*/function () {
  const GenericButton = /*#__PURE__*/forwardRef(function (_a, ref) {
    var _b = _a.iconPosition,
      iconPosition = _b === void 0 ? 'start' : _b,
      _c = _a.iconButton,
      iconButton = _c === void 0 ? false : _c,
      _d = _a.primary,
      primary = _d === void 0 ? false : _d,
      _e = _a.secondary,
      secondary = _e === void 0 ? false : _e,
      _f = _a.newTabAndIUnderstandTheAccessibilityImplications,
      newTabAndIUnderstandTheAccessibilityImplications = _f === void 0 ? false : _f,
      _g = _a.disableTabFocusAndIUnderstandTheAccessibilityImplications,
      disableTabFocusAndIUnderstandTheAccessibilityImplications = _g === void 0 ? false : _g,
      _h = _a.type,
      type = _h === void 0 ? 'button' : _h,
      otherProps = __rest(_a, ["iconPosition", "iconButton", "primary", "secondary", "newTabAndIUnderstandTheAccessibilityImplications", "disableTabFocusAndIUnderstandTheAccessibilityImplications", "type"]);
    var buttonRef = useRef();
    var wrapperRef = useRef(null);
    useImperativeHandle(ref, function () {
      return {
        focus: function () {
          var _a;
          (_a = buttonRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
      };
    });
    var props = __assign({
      iconPosition: iconPosition,
      iconButton: iconButton,
      primary: primary,
      secondary: secondary,
      newTabAndIUnderstandTheAccessibilityImplications: newTabAndIUnderstandTheAccessibilityImplications,
      disableTabFocusAndIUnderstandTheAccessibilityImplications: disableTabFocusAndIUnderstandTheAccessibilityImplications,
      type: type
    }, otherProps);
    if (props.component) {
      return renderCustomComponent(props.component, props, wrapperRef);
    }
    return /*#__PURE__*/React.createElement("span", {
      ref: wrapperRef,
      className: classnames(styles.container, props.fullWidth && styles.fullWidth),
      "aria-live": 'workingLabel' in props ? 'polite' : undefined
    }, props.href && !props.disabled && !props.working ? renderLink(props, buttonRef) : renderButton(props, buttonRef));
  });
  GenericButton.displayName = 'GenericButton';
  return GenericButton;
}();
var renderCustomComponent = function (CustomComponent, props, ref) {
  var passedInProps = __assign({
    'id': props.id,
    'className': buttonClass(props),
    'disabled': props.disabled,
    'href': props.href,
    'onClick': props.onClick,
    'onFocus': props.onFocus,
    'onBlur': props.onBlur,
    'aria-label': generateAriaLabel(props)
  }, getCustomProps(props));
  var _a = useContextProps(passedInProps, ref,
    // @ts-expect-error we're using span ref on link context, but that's ok because we need only sizing
    LinkContext),
    contextProps = _a[0],
    contextRef = _a[1];
  // @ts-expect-error Not fixing as a new Button component exists
  // @todo: Make a wrapper and take it out of Button
  var linkProps = useLink(contextProps, contextRef).linkProps;
  // Unset this because the one defined in buttonProps shows
  // focus-visible styles on click, in future we'll style using [data-focus-visible] which is consistent across browsers
  delete linkProps.onPointerDown;
  return /*#__PURE__*/React.createElement("span", {
    ref: contextRef,
    className: classnames(styles.container, props.fullWidth && styles.fullWidth),
    "aria-live": 'workingLabel' in props ? 'polite' : undefined
  }, /*#__PURE__*/React.createElement(CustomComponent, __assign({}, contextProps, linkProps, {
    "aria-describedby": props['aria-describedby'] === null ? undefined : linkProps['aria-describedby']
  }), renderContent(props)));
};
var renderButton = function (props, ref) {
  var _a;
  var disableActions = Boolean(props.disabled || props.working);
  var passedInProps = __assign({
    'id': props.id,
    'disabled': props.disabled,
    'onClick': !disableActions ? props.onClick : undefined,
    'onMouseDown': !disableActions ? props.onMouseDown : undefined,
    'type': props.type,
    'onFocus': props.onFocus,
    'onBlur': props.onBlur,
    'form': props.form,
    'formAction': props.formAction,
    'formMethod': props.formMethod,
    'formEncType': props.formEncType,
    'formTarget': props.formTarget,
    'formNoValidate': props.formNoValidate,
    'className': buttonClass(props),
    'aria-label': generateAriaLabel(props),
    'aria-disabled': props.disabled || props.working ? true : undefined,
    'tabIndex': props.disableTabFocusAndIUnderstandTheAccessibilityImplications ? -1 : undefined
  }, getCustomProps(props));
  // @ts-expect-error we're using useFocusable instead of useButton because at this stage we want to hook only to focusable.
  // Not standardize button behavior as we're currently relying on some weird native behaviours (like onClick firing on enter key press) see https://react-spectrum.adobe.com/blog/building-a-button-part-1.html
  var focusableProps = useFocusable(passedInProps, ref).focusableProps;
  return (
    /*#__PURE__*/
    // eslint-disable-next-line react/button-has-type
    React.createElement("button", __assign({}, passedInProps, focusableProps, {
      "aria-describedby": props['aria-describedby'] === null ? undefined : (_a = props['aria-describedby']) !== null && _a !== void 0 ? _a : focusableProps['aria-describedby'],
      // Unset this because the one defined in buttonProps shows
      // focus-visible styles on click
      onPointerDown: undefined,
      ref: ref
    }), renderContent(props))
  );
};
var renderLink = function (props, ref) {
  var _a;
  var target = props.newTabAndIUnderstandTheAccessibilityImplications ? '_blank' : '_self';
  var passedInProps = __assign({
    'id': props.id,
    'href': props.href,
    target: target,
    'rel': target === '_blank' ? 'noopener noreferrer' : undefined,
    'className': buttonClass(props),
    'onClick': props.onClick,
    'onFocus': props.onFocus,
    'onBlur': props.onBlur,
    'aria-label': generateAriaLabel(props)
  }, getCustomProps(props));
  // @ts-expect-error we're using useFocusable instead of useLink because at this stage we want to hook only to focusable.
  // Not standardize button behavior as we're currently relying on some weird native behaviours (like onClick firing on enter key press) see https://react-spectrum.adobe.com/blog/building-a-button-part-1.html
  var focusableProps = useFocusable(passedInProps, ref).focusableProps;
  return /*#__PURE__*/React.createElement("a", __assign({}, passedInProps, focusableProps, {
    "aria-describedby": props['aria-describedby'] === null ? undefined : (_a = props['aria-describedby']) !== null && _a !== void 0 ? _a : focusableProps['aria-describedby'],
    // Unset this because the one defined in linkProps shows
    // focus-visible styles on click
    onPointerDown: undefined,
    ref: ref
  }), renderContent(props));
};
var buttonClass = function (props) {
  var isDefault = !props.primary && !props.destructive && !props.secondary;
  return classnames(styles.button, isDefault && styles.default,
  // @ts-expect-error aria-disabled exists in props
  Boolean(props.disabled || props['aria-disabled']) && styles.disabled, props.primary && styles.primary, props.destructive && styles.destructive, props.secondary && styles.secondary, props.size && styles[props.size], props.reversed && styles.reversed, props.iconButton && styles.iconButton, props.working && styles.working, Boolean(props.directionalLink || props.paginationLink) && styles.circleButton, props.directionalLink && styles.directionalLink, props.paginationLink && styles.paginationLink, props.isActive && styles.isPaginationLinkActive, props.classNameOverride);
};
var renderLoadingSpinner = function () {
  return /*#__PURE__*/React.createElement("div", {
    className: styles.loadingSpinner
  }, /*#__PURE__*/React.createElement(LoadingSpinner, {
    accessibilityLabel: "",
    size: "sm"
  }));
};
var renderWorkingContent = function (props) {
  if (props.workingLabelHidden) {
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
      className: styles.hidden,
      "aria-hidden": "true"
    }, renderDefaultContent(props)), /*#__PURE__*/React.createElement("span", {
      className: styles.centeredLoadingSpinner
    }, renderLoadingSpinner()));
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, props.iconPosition !== 'end' && renderLoadingSpinner(), /*#__PURE__*/React.createElement("span", {
    className: styles.label
  }, props.workingLabel), props.additionalContent && (/*#__PURE__*/React.createElement("span", {
    className: styles.additionalContentWrapper
  }, props.additionalContent)), props.iconPosition === 'end' && renderLoadingSpinner());
};
var renderDefaultContent = function (props) {
  return /*#__PURE__*/React.createElement(React.Fragment, null, props.icon && props.iconPosition !== 'end' && renderIcon(props.icon), (!props.icon || !props.iconButton) && /*#__PURE__*/React.createElement("span", {
    className: styles.label
  }, props.label), props.additionalContent && (/*#__PURE__*/React.createElement("span", {
    className: styles.additionalContentWrapper
  }, props.additionalContent)), renderBadge(props), props.icon && props.iconPosition === 'end' && renderIcon(props.icon));
};
var renderBadge = function (props) {
  if (!props.badge) return null;
  var _a = props.badge,
    text = _a.text,
    animateChange = _a.animateChange,
    reversed = _a.reversed,
    variant = _a.variant;
  if (animateChange) {
    return /*#__PURE__*/React.createElement(BadgeAnimated, {
      variant: variant,
      reversed: reversed
    }, text);
  }
  return /*#__PURE__*/React.createElement(Badge, {
    variant: variant,
    reversed: reversed
  }, text);
};
var renderContent = function (props) {
  return /*#__PURE__*/React.createElement("span", {
    className: styles.content
  }, props.working ? renderWorkingContent(props) : renderDefaultContent(props));
};
var renderIcon = function (icon) {
  return /*#__PURE__*/React.createElement("span", {
    className: styles.iconWrapper
  }, icon);
};
// We only want an aria-label in the case that the button has just an icon and no text
// This can happen when the button is working and workingLabelHidden is true,
// or when this is an IconButton
var generateAriaLabel = function (props) {
  if (props.working && props.workingLabelHidden) {
    return props.workingLabel;
  }
  if (props.iconButton) {
    return props.label;
  }
  return undefined;
};
export { GenericButton };
