import { __assign } from 'tslib';
import React from 'react';
import { useIntl, FormattedMessage } from '@cultureamp/i18n-react-intl';
import classnames from 'classnames';
import { BrandMoment } from '../BrandMoment/BrandMoment.mjs';
import '../Illustration/subcomponents/Base/Base.mjs';
import '../Illustration/Scene/BrandMomentCaptureIntro/BrandMomentCaptureIntro.mjs';
import { BrandMomentError } from '../Illustration/Scene/Scene.mjs';
import { Text } from '../Text/Text.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
import { useErrorMessages } from './hooks/useErrorMessages.mjs';
import styles from './ErrorPage.module.scss.mjs';
var getMailToHref = function (code) {
  var supportEmail = 'support@cultureamp.com';
  var subject = 'Houston we have a problem';
  var body = "Hi there,\n\nI received a ".concat(code, " error page while I was trying to...");
  return encodeURI("mailto:".concat(supportEmail, "?subject=").concat(subject, "&amp;body=").concat(body));
};
var HOME_HREF = '/app/home';
const ErrorPage = /*#__PURE__*/function () {
  const ErrorPage = function (_a) {
    var _b;
    var code = _a.code,
      title = _a.title,
      message = _a.message,
      callToAction = _a.callToAction,
      classNameOverride = _a.classNameOverride;
    var formatMessage = useIntl().formatMessage;
    var content = useErrorMessages(code);
    var actions = {
      primary: {
        href: (_b = callToAction === null || callToAction === void 0 ? void 0 : callToAction.homeHref) !== null && _b !== void 0 ? _b : HOME_HREF
      },
      secondary: (callToAction === null || callToAction === void 0 ? void 0 : callToAction.onContactSupport) ? {
        onClick: callToAction.onContactSupport
      } : {
        href: getMailToHref(code)
      }
    };
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(classNameOverride)
    }, /*#__PURE__*/React.createElement(BrandMoment, {
      header: /*#__PURE__*/React.createElement(React.Fragment, null),
      body: /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
        className: styles.paragraphPadding
      }, /*#__PURE__*/React.createElement(Text, {
        variant: "intro-lede"
      }, message !== null && message !== void 0 ? message : content.message)), /*#__PURE__*/React.createElement(Text, {
        color: "dark-reduced-opacity",
        variant: "small"
      }, /*#__PURE__*/React.createElement(FormattedMessage, {
        id: "kzErrorPage.errorCode",
        defaultMessage: "Error code {code}",
        values: {
          code: code
        }
      }))),
      illustration: /*#__PURE__*/React.createElement(BrandMomentError, {
        isAnimated: true,
        loop: true
      }),
      variant: "warning",
      primaryAction: __assign(__assign({}, actions.primary), {
        icon: /*#__PURE__*/React.createElement(Icon, {
          name: "arrow_forward",
          isPresentational: true,
          shouldMirrorInRTL: true
        }),
        iconPosition: 'end',
        label: formatMessage({
          id: 'kzErrorPage.goToHome',
          defaultMessage: 'Go to Home',
          description: 'Home button label'
        })
      }),
      secondaryAction: __assign(__assign({}, actions.secondary), {
        icon: /*#__PURE__*/React.createElement(Icon, {
          name: "mail",
          isPresentational: true,
          isFilled: true
        }),
        label: formatMessage({
          id: 'kzErrorPage',
          defaultMessage: 'Contact support',
          description: 'Label for contact button'
        })
      }),
      text: {
        title: title !== null && title !== void 0 ? title : content.title
      }
    }));
  };
  ErrorPage.displayName = 'ErrorPage';
  return ErrorPage;
}();
export { ErrorPage };
