import { __rest, __assign } from 'tslib';
import React, { forwardRef } from 'react';
import { useIntl } from '@cultureamp/i18n-react-intl';
import classnames from 'classnames';
import { ButtonGroup } from '../../../ButtonGroup/ButtonGroup.mjs';
import { Tooltip } from '../../../Tooltip/Tooltip.mjs';
import { Icon } from '../../../__next__/Icon/Icon.mjs';
import { isRefObject } from '../../../utils/isRefObject.mjs';
import { FilterButton } from '../FilterButton/FilterButton.mjs';
import { FilterButtonBase } from '../subcomponents/FilterButtonBase/FilterButtonBase.mjs';
import styles from './FilterButtonRemovable.module.css.mjs';
const FilterButtonRemovable = /*#__PURE__*/function () {
  const FilterButtonRemovable = /*#__PURE__*/forwardRef(function (_a, ref) {
    var _b;
    var triggerButtonProps = _a.triggerButtonProps,
      removeButtonProps = _a.removeButtonProps,
      restProps = __rest(_a, ["triggerButtonProps", "removeButtonProps"]);
    var formatMessage = useIntl().formatMessage;
    var removeButtonLabelFallback = formatMessage({
      id: 'filterButton.removable.removeButtonLabel',
      defaultMessage: 'Remove filter - {filterLabel}',
      description: 'Button label to remove a single filter from the filter bar'
    }, {
      filterLabel: triggerButtonProps === null || triggerButtonProps === void 0 ? void 0 : triggerButtonProps.label
    });
    var customRefObject = isRefObject(ref) ? ref.current : null;
    var removeButtonRef = customRefObject === null || customRefObject === void 0 ? void 0 : customRefObject.removeButtonRef;
    var removeButtonLabel = (_b = removeButtonProps === null || removeButtonProps === void 0 ? void 0 : removeButtonProps.tooltipText) !== null && _b !== void 0 ? _b : removeButtonLabelFallback;
    return /*#__PURE__*/React.createElement(ButtonGroup, __assign({}, restProps), /*#__PURE__*/React.createElement(FilterButton, __assign({
      ref: ref
    }, triggerButtonProps)), /*#__PURE__*/React.createElement(Tooltip, {
      text: removeButtonLabel,
      display: "inline-block",
      position: "below"
    }, /*#__PURE__*/React.createElement(FilterButtonBase, __assign({
      ref: removeButtonRef,
      classNameOverride: classnames(styles.filterButtonBase, restProps.classNameOverride)
    }, removeButtonProps), /*#__PURE__*/React.createElement(Icon, {
      name: "cancel",
      alt: removeButtonLabel,
      isFilled: true
    }))));
  });
  FilterButtonRemovable.displayName = 'FilterButtonRemovable';
  return FilterButtonRemovable;
}();
export { FilterButtonRemovable };
