import '../../../Calendar/CalendarSingle/CalendarSingle.mjs';
import '../../../Calendar/CalendarRange/CalendarRange.mjs';
import 'tslib';
import { formatDateAsNumeral } from '../../../Calendar/utils/formatDateAsNumeral.mjs';
import { formatDateAsText } from '../../../Calendar/utils/formatDateAsText.mjs';
import { isDisabledDate } from '../../../Calendar/utils/isDisabledDate.mjs';
import { isInvalidDate } from '../../../Calendar/utils/isInvalidDate.mjs';
import { isSelectingDayInCalendar } from '../../../Calendar/utils/isSelectingDayInCalendar.mjs';
import { parseDateFromNumeralFormatValue } from '../../../Calendar/utils/parseDateFromNumeralFormatValue.mjs';
import { parseDateFromTextFormatValue } from '../../../Calendar/utils/parseDateFromTextFormatValue.mjs';
var useDateInputHandlers = function (_a) {
  var locale = _a.locale,
    disabledDays = _a.disabledDays,
    setInputValue = _a.setInputValue,
    onDateChange = _a.onDateChange,
    onDateSubmit = _a.onDateSubmit,
    onChange = _a.onChange,
    onFocus = _a.onFocus,
    onBlur = _a.onBlur,
    onKeyDown = _a.onKeyDown;
  var isValidDate = function (date) {
    return !isInvalidDate(date) && !isDisabledDate(date, disabledDays);
  };
  var handleChange = function (e) {
    setInputValue(e.currentTarget.value);
    onChange === null || onChange === void 0 ? void 0 : onChange(e);
  };
  var handleFocus = function (e) {
    var date = parseDateFromTextFormatValue(e.currentTarget.value, locale);
    if (!isInvalidDate(date)) {
      var newInputValue = formatDateAsNumeral(date, locale);
      setInputValue(newInputValue);
    }
    onFocus === null || onFocus === void 0 ? void 0 : onFocus(e);
  };
  var handleBlur = function (e) {
    if (isSelectingDayInCalendar(e.relatedTarget)) return;
    if (e.currentTarget.value === '') {
      onDateChange(undefined);
      onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
      return;
    }
    var date = parseDateFromNumeralFormatValue(e.currentTarget.value, locale);
    if (isValidDate(date)) {
      var newInputValue = formatDateAsText(date, disabledDays, locale);
      setInputValue(newInputValue);
    }
    onDateChange(date);
    onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
  };
  var handleKeyDown = function (e) {
    if (e.key === 'Enter') {
      e.preventDefault();
      var date = parseDateFromNumeralFormatValue(e.currentTarget.value, locale);
      onDateChange(date);
      onDateSubmit === null || onDateSubmit === void 0 ? void 0 : onDateSubmit(date);
    }
    onKeyDown === null || onKeyDown === void 0 ? void 0 : onKeyDown(e);
  };
  return {
    onChange: handleChange,
    onFocus: handleFocus,
    onBlur: handleBlur,
    onKeyDown: handleKeyDown
  };
};
export { useDateInputHandlers };
