import { __rest, __assign } from 'tslib';
import React from 'react';
import { useIntl } from '@cultureamp/i18n-react-intl';
import { DateInput } from '../../../../DateInput/DateInput/DateInput.mjs';
import { DateInputDescription } from '../../../../DateInput/DateInputDescription/DateInputDescription.mjs';
import '../../../../DateInput/DateInputWithIconButton/DateInputWithIconButton.mjs';
import { FieldMessage } from '../../../../FieldMessage/FieldMessage.mjs';
import styles from './DateInputField.module.scss.mjs';
const DateInputField = /*#__PURE__*/function () {
  const DateInputField = /*#__PURE__*/React.forwardRef(function (_a, ref) {
    var id = _a.id,
      labelText = _a.labelText,
      description = _a.description,
      disabled = _a.disabled,
      _b = _a.isReversed,
      isReversed = _b === void 0 ? false : _b,
      validationMessage = _a.validationMessage,
      locale = _a.locale,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["id", "labelText", "description", "disabled", "isReversed", "validationMessage", "locale", "classNameOverride"]);
    var formatMessage = useIntl().formatMessage;
    var dateInputLabelFallback = formatMessage({
      id: 'filterDatePickerDateInputField.dateInputLabelFallback',
      defaultMessage: 'Date',
      description: 'Default label for date input field'
    });
    var descriptionId = "".concat(id, "--field-message");
    var errorMessageId = validationMessage ? "".concat(id, "--date-error-message") : undefined;
    var inputDescribedBy = errorMessageId ? "".concat(errorMessageId, " ").concat(descriptionId) : descriptionId;
    var dateIsInvalid = errorMessageId !== undefined;
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(DateInput, __assign({
      ref: ref,
      id: id,
      labelText: labelText !== null && labelText !== void 0 ? labelText : dateInputLabelFallback,
      "aria-describedby": inputDescribedBy,
      "aria-errormessage": errorMessageId,
      "aria-invalid": dateIsInvalid,
      autoComplete: "off",
      disabled: disabled,
      status: validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.status,
      classNameOverride: classNameOverride
    }, restProps)), validationMessage && (/*#__PURE__*/React.createElement(FieldMessage, {
      id: errorMessageId,
      message: validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.message,
      status: validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.status,
      reversed: isReversed
    })), /*#__PURE__*/React.createElement(FieldMessage, {
      id: descriptionId,
      message: /*#__PURE__*/React.createElement(DateInputDescription, {
        description: description,
        locale: locale
      }),
      reversed: isReversed,
      classNameOverride: disabled ? styles.disabled : undefined
    }));
  });
  DateInputField.displayName = 'DateInputField';
  return DateInputField;
}();
export { DateInputField };
