import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { DateInput } from '../../../../DateInput/DateInput/DateInput.mjs';
import { DateInputDescription } from '../../../../DateInput/DateInputDescription/DateInputDescription.mjs';
import '../../../../DateInput/DateInputWithIconButton/DateInputWithIconButton.mjs';
import { FieldMessage } from '../../../../FieldMessage/FieldMessage.mjs';
import { VisuallyHidden } from '../../../../VisuallyHidden/VisuallyHidden.mjs';
import { isRefObject } from '../../../../utils/isRefObject.mjs';
import { DateRangeValidationMessage } from '../DateRangeValidationMessage/DateRangeValidationMessage.mjs';
import styles from './DateRangeInputField.module.scss.mjs';
const DateRangeInputField = /*#__PURE__*/function () {
  const DateRangeInputField = /*#__PURE__*/React.forwardRef(function (_a, ref) {
    var _b, _c;
    var id = _a.id,
      legend = _a.legend,
      inputStartDateProps = _a.inputStartDateProps,
      inputEndDateProps = _a.inputEndDateProps,
      description = _a.description,
      disabled = _a.disabled,
      _d = _a.isReversed,
      isReversed = _d === void 0 ? false : _d,
      validationMessage = _a.validationMessage,
      locale = _a.locale,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["id", "legend", "inputStartDateProps", "inputEndDateProps", "description", "disabled", "isReversed", "validationMessage", "locale", "classNameOverride"]);
    var customRefObject = isRefObject(ref) ? ref.current : null;
    var inputStartDateRef = customRefObject === null || customRefObject === void 0 ? void 0 : customRefObject.inputStartDateRef;
    var inputEndDateRef = customRefObject === null || customRefObject === void 0 ? void 0 : customRefObject.inputEndDateRef;
    var descriptionId = "".concat(id, "--field-message");
    // Date Start aria labels
    var dateStartErrorMessageId = (validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.dateStart) ? "".concat(id, "--date-start-error-message") : undefined;
    var dateStartInputDescribedBy = dateStartErrorMessageId ? "".concat(dateStartErrorMessageId, " ").concat(descriptionId) : descriptionId;
    var dateStartIsInvalid = dateStartErrorMessageId !== undefined;
    // Date End aria labels
    var dateEndErrorMessageId = (validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.dateEnd) ? "".concat(id, "--date-end-error-message") : undefined;
    var dateEndInputDescribedBy = dateEndErrorMessageId ? "".concat(dateEndErrorMessageId, " ").concat(descriptionId) : descriptionId;
    var dateEndIsInvalid = dateEndErrorMessageId !== undefined;
    return /*#__PURE__*/React.createElement("div", __assign({
      className: classNameOverride
    }, restProps), /*#__PURE__*/React.createElement("fieldset", {
      className: styles.dateRangeInputContainer
    }, /*#__PURE__*/React.createElement("legend", null, /*#__PURE__*/React.createElement(VisuallyHidden, null, legend)), /*#__PURE__*/React.createElement(DateInput, __assign({
      ref: inputStartDateRef,
      id: "".concat(id, "--from"),
      "aria-describedby": dateStartInputDescribedBy,
      "aria-errormessage": dateStartErrorMessageId,
      "aria-invalid": dateStartIsInvalid,
      autoComplete: "off",
      disabled: disabled,
      status: (_b = validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.dateStart) === null || _b === void 0 ? void 0 : _b.status
    }, inputStartDateProps, {
      classNameOverride: classnames(styles.inputStartDate, inputStartDateProps.classNameOverride)
    })), /*#__PURE__*/React.createElement(DateInput, __assign({
      ref: inputEndDateRef,
      id: "".concat(id, "--to"),
      "aria-describedby": dateEndInputDescribedBy,
      "aria-errormessage": dateEndErrorMessageId,
      "aria-invalid": dateEndIsInvalid,
      autoComplete: "off",
      disabled: disabled,
      status: (_c = validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.dateEnd) === null || _c === void 0 ? void 0 : _c.status
    }, inputEndDateProps, {
      classNameOverride: classnames(styles.inputEndDate, inputEndDateProps.classNameOverride)
    }))), validationMessage && (/*#__PURE__*/React.createElement(DateRangeValidationMessage, {
      validationMessage: validationMessage,
      isReversed: isReversed,
      dateStartId: dateStartErrorMessageId,
      dateEndId: dateEndErrorMessageId
    })), /*#__PURE__*/React.createElement(FieldMessage, {
      id: descriptionId,
      message: /*#__PURE__*/React.createElement(DateInputDescription, {
        description: description,
        locale: locale
      }),
      reversed: isReversed,
      classNameOverride: disabled ? styles.disabled : undefined
    }));
  });
  DateRangeInputField.displayName = 'DateRangeInputField';
  return DateRangeInputField;
}();
export { DateRangeInputField };
