import { __rest, __assign } from 'tslib';
import React, { useReducer, useEffect } from 'react';
import { useIntl } from '@cultureamp/i18n-react-intl';
import classnames from 'classnames';
import '../../../../Calendar/CalendarSingle/CalendarSingle.mjs';
import { CalendarRange } from '../../../../Calendar/CalendarRange/CalendarRange.mjs';
import 'date-fns';
import { isInvalidDate } from '../../../../Calendar/utils/isInvalidDate.mjs';
import { formatDateAsText } from '../../../../Calendar/utils/formatDateAsText.mjs';
import 'react-day-picker';
import { parseDateFromTextFormatValue } from '../../../../Calendar/utils/parseDateFromTextFormatValue.mjs';
import { getLocale } from '../../../../DatePicker/utils/getLocale.mjs';
import { useDateInputHandlers } from '../../../FilterDatePicker/hooks/useDateInputHandlers.mjs';
import { useMediaQueries } from '../../../../utils/useMediaQueries.mjs';
import { DateRangeInputField } from '../DateRangeInputField/DateRangeInputField.mjs';
import { filterDatePickerFieldReducer } from './filterDateRangePickerFieldReducer.mjs';
import { useEndDateValidation } from './hooks/useEndDateValidation.mjs';
import { useStartDateValidation } from './hooks/useStartDateValidation.mjs';
import { isValidRange } from './utils/isValidRange.mjs';
import styles from './FilterDateRangePickerField.module.scss.mjs';
const FilterDateRangePickerField = /*#__PURE__*/function () {
  const FilterDateRangePickerField = function (_a) {
    var _b, _c;
    var id = _a.id,
      label = _a.label,
      propsLocale = _a.locale,
      defaultMonth = _a.defaultMonth,
      selectedRange = _a.selectedRange,
      onRangeChange = _a.onRangeChange,
      disabledDays = _a.disabledDays,
      inputStartDateProps = _a.inputStartDateProps,
      inputEndDateProps = _a.inputEndDateProps,
      description = _a.description,
      validationMessage = _a.validationMessage,
      onValidate = _a.onValidate,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["id", "label", "locale", "defaultMonth", "selectedRange", "onRangeChange", "disabledDays", "inputStartDateProps", "inputEndDateProps", "description", "validationMessage", "onValidate", "classNameOverride"]);
    var formatMessage = useIntl().formatMessage;
    var locale = getLocale(propsLocale);
    var queries = useMediaQueries().queries;
    var translatedDateFrom = formatMessage({
      id: 'filterDateRangePicker.dateFrom',
      defaultMessage: 'Date from',
      description: "Label for the 'Date from' field"
    });
    var translatedDateTo = formatMessage({
      id: 'filterDateRangePicker.dateTo',
      defaultMessage: 'Date to',
      description: "Label for the 'date to' field"
    });
    var inputStartDateLabel = (_b = inputStartDateProps === null || inputStartDateProps === void 0 ? void 0 : inputStartDateProps.labelText) !== null && _b !== void 0 ? _b : translatedDateFrom;
    var inputEndDateLabel = (_c = inputEndDateProps === null || inputEndDateProps === void 0 ? void 0 : inputEndDateProps.labelText) !== null && _c !== void 0 ? _c : translatedDateTo;
    var transformDateToInputValue = function (date) {
      return date ? formatDateAsText(date, disabledDays, locale) : '';
    };
    var handleDateRangeChange = function (dateRange) {
      onRangeChange(dateRange);
    };
    var dateStartValidation = useStartDateValidation({
      inputLabel: inputStartDateLabel,
      disabledDays: disabledDays,
      validationMessage: validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.dateStart,
      onValidate: onValidate === null || onValidate === void 0 ? void 0 : onValidate.dateStart
    });
    var dateEndValidation = useEndDateValidation({
      inputLabel: inputEndDateLabel,
      disabledDays: disabledDays,
      validationMessage: validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.dateEnd,
      onValidate: onValidate === null || onValidate === void 0 ? void 0 : onValidate.dateEnd
    });
    var validateStartDate = function (date, inputValue) {
      return dateStartValidation.validateDate({
        date: date,
        inputValue: inputValue
      });
    };
    var validateEndDate = function (date, inputValue) {
      return dateEndValidation.validateDate({
        endDate: date,
        endDateInputValue: inputValue,
        startDate: selectedRange === null || selectedRange === void 0 ? void 0 : selectedRange.from,
        startDateFieldLabel: inputStartDateLabel
      });
    };
    var _d = useReducer(filterDatePickerFieldReducer, {
        selectedStartDate: selectedRange === null || selectedRange === void 0 ? void 0 : selectedRange.from,
        selectedEndDate: selectedRange === null || selectedRange === void 0 ? void 0 : selectedRange.to,
        inputStartValue: transformDateToInputValue(selectedRange === null || selectedRange === void 0 ? void 0 : selectedRange.from),
        inputEndValue: transformDateToInputValue(selectedRange === null || selectedRange === void 0 ? void 0 : selectedRange.to),
        startMonth: (selectedRange === null || selectedRange === void 0 ? void 0 : selectedRange.from) && !isInvalidDate(selectedRange.from) ? selectedRange.from : defaultMonth !== null && defaultMonth !== void 0 ? defaultMonth : new Date()
      }),
      state = _d[0],
      dispatch = _d[1];
    var inputStartDateHandlers = useDateInputHandlers(__assign({
      locale: locale,
      disabledDays: disabledDays,
      setInputValue: function (value) {
        dispatch({
          type: 'update_input_start_field',
          inputValue: value
        });
      },
      onDateChange: function (date) {
        var newDate = validateStartDate(date, state.inputStartValue);
        // We need to parse the date from the input field due to the
        // state.selectedEndDate being set to undefined whenever range is invalid
        var endDate = parseDateFromTextFormatValue(state.inputEndValue, locale);
        var isRangeValid = isValidRange(newDate, endDate);
        dispatch({
          type: 'update_selected_start_date',
          date: newDate
        });
        // If the range ends up being invalid due to the change in start date
        // we need to remove the end date as its now deemed invalid.
        dispatch({
          type: 'update_selected_end_date',
          date: isRangeValid ? endDate : undefined
        });
        handleDateRangeChange({
          from: newDate,
          to: isRangeValid ? endDate : undefined
        });
        if (newDate && endDate && !isInvalidDate(endDate)) {
          // Update validation messages
          dateEndValidation.validateEndDateBeforeStartDate({
            startDate: newDate,
            startDateFieldLabel: inputStartDateLabel,
            endDate: endDate,
            endDateInputValue: state.inputEndValue
          });
        }
      }
    }, inputStartDateProps));
    var inputEndDateHandlers = useDateInputHandlers(__assign({
      locale: locale,
      disabledDays: disabledDays,
      setInputValue: function (value) {
        dispatch({
          type: 'update_input_end_field',
          inputValue: value
        });
      },
      onDateChange: function (date) {
        var startDate = state.selectedStartDate;
        var newEndDate = validateEndDate(date, state.inputEndValue);
        var isRangeValid = isValidRange(startDate, newEndDate);
        dispatch({
          type: 'update_selected_end_date',
          date: isRangeValid ? newEndDate : undefined
        });
        handleDateRangeChange({
          from: startDate,
          to: isRangeValid ? newEndDate : undefined
        });
      }
    }, inputEndDateProps));
    var handleCalendarSelectRange = function (range) {
      var inputStartValue = transformDateToInputValue(range === null || range === void 0 ? void 0 : range.from);
      var inputEndValue = transformDateToInputValue(range === null || range === void 0 ? void 0 : range.to);
      var newStartDate = validateStartDate(range === null || range === void 0 ? void 0 : range.from, inputStartValue);
      var newEndDate = validateEndDate(range === null || range === void 0 ? void 0 : range.to, inputEndValue);
      dispatch({
        type: 'update_selected_start_date',
        date: newStartDate,
        inputValue: inputStartValue
      });
      dispatch({
        type: 'update_selected_end_date',
        date: newEndDate,
        inputValue: inputEndValue
      });
      handleDateRangeChange({
        from: newStartDate,
        to: newEndDate
      });
    };
    useEffect(function () {
      if (inputStartDateLabel === ' ' || inputEndDateLabel === ' ') {
        // Translations are loading
        return;
      }
      if (state.inputStartValue === '' && state.inputEndValue === '') {
        return;
      }
      var newStartDate = validateStartDate(selectedRange === null || selectedRange === void 0 ? void 0 : selectedRange.from, state.inputStartValue);
      var newEndDate = validateEndDate(selectedRange === null || selectedRange === void 0 ? void 0 : selectedRange.to, state.inputEndValue);
      if (newStartDate && !isValidRange(newStartDate, newEndDate)) {
        dispatch({
          type: 'update_selected_end_date',
          date: undefined
        });
      }
      handleDateRangeChange({
        from: newStartDate,
        to: newEndDate
      });
      // We only want to run this effect on the first render after translations have loaded
      // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [inputStartDateLabel, inputEndDateLabel]);
    return /*#__PURE__*/React.createElement("div", __assign({
      className: classnames(styles.filterDateRangePickerField, classNameOverride)
    }, restProps), /*#__PURE__*/React.createElement(DateRangeInputField, {
      id: "".concat(id, "--input"),
      legend: label,
      inputStartDateProps: __assign(__assign({
        labelText: inputStartDateLabel,
        value: state.inputStartValue
      }, inputStartDateProps), inputStartDateHandlers),
      inputEndDateProps: __assign(__assign({
        labelText: inputEndDateLabel,
        value: state.inputEndValue
      }, inputEndDateProps), inputEndDateHandlers),
      locale: locale,
      description: description,
      validationMessage: {
        dateStart: dateStartValidation.validationMessage,
        dateEnd: dateEndValidation.validationMessage
      },
      classNameOverride: classnames(styles.dateRangeInputField)
    }), /*#__PURE__*/React.createElement(CalendarRange, {
      disabled: disabledDays,
      locale: locale,
      selected: {
        from: state.selectedStartDate,
        to: state.selectedEndDate
      },
      onSelect: handleCalendarSelectRange,
      month: state.startMonth,
      numberOfMonths: queries.isSmall ? 1 : 2,
      onMonthChange: function (value) {
        return dispatch({
          type: 'navigate_months',
          date: value
        });
      }
    }));
  };
  FilterDateRangePickerField.displayName = 'FilterDateRangePickerField';
  return FilterDateRangePickerField;
}();
export { FilterDateRangePickerField };
