import { __assign } from 'tslib';
import React from 'react';
import { MenuTriggerProvider, MenuTriggerConsumer } from './context/MenuTriggerProvider/MenuTriggerProvider.mjs';
import { SelectionProvider, SelectionConsumer } from './context/SelectionProvider/SelectionProvider.mjs';
import { ListBox } from './subcomponents/ListBox/ListBox.mjs';
import { ListBoxSection } from './subcomponents/ListBoxSection/ListBoxSection.mjs';
import { LoadMoreButton } from './subcomponents/LoadMoreButton/LoadMoreButton.mjs';
import { MenuFooter } from './subcomponents/MenuLayout/MenuFooter/MenuFooter.mjs';
import { MenuLoadingSkeleton } from './subcomponents/MenuLayout/MenuLoadingSkeleton/MenuLoadingSkeleton.mjs';
import { MenuPopup } from './subcomponents/MenuPopup/MenuPopup.mjs';
import { MultiSelectOption } from './subcomponents/MultiSelectOption/MultiSelectOption.mjs';
import { NoResults } from './subcomponents/NoResults/NoResults.mjs';
import { SearchInput } from './subcomponents/SearchInput/SearchInput.mjs';
import { SectionDivider } from './subcomponents/SectionDivider/SectionDivider.mjs';
import { ClearButton } from './subcomponents/SelectionControlButton/ClearButton/ClearButton.mjs';
import { SelectAllButton } from './subcomponents/SelectionControlButton/SelectAllButton/SelectAllButton.mjs';
import { FilterTriggerButton } from './subcomponents/Trigger/FilterTriggerButton/FilterTriggerButton.mjs';
import { RemovableFilterTrigger } from './subcomponents/Trigger/RemovableFilterTrigger/RemovableFilterTrigger.mjs';
const FilterMultiSelect = /*#__PURE__*/function () {
  const FilterMultiSelect = function (_a) {
    var trigger = _a.trigger,
      children = _a.children,
      isOpen = _a.isOpen,
      defaultOpen = _a.defaultOpen,
      onOpenChange = _a.onOpenChange,
      isLoading = _a.isLoading,
      loadingSkeleton = _a.loadingSkeleton,
      label = _a.label,
      items = _a.items,
      selectedKeys = _a.selectedKeys,
      defaultSelectedKeys = _a.defaultSelectedKeys,
      onSelectionChange = _a.onSelectionChange,
      _b = _a.selectionMode,
      selectionMode = _b === void 0 ? 'multiple' : _b,
      onSearchInputChange = _a.onSearchInputChange,
      triggerRef = _a.triggerRef,
      className = _a.className;
    var menuTriggerProps = {
      isOpen: isOpen,
      defaultOpen: defaultOpen,
      onOpenChange: onOpenChange,
      triggerRef: triggerRef
    };
    var menuPopupProps = {
      isLoading: isLoading,
      loadingSkeleton: loadingSkeleton
    };
    var disabledKeys = new Set(items === null || items === void 0 ? void 0 : items.filter(function (item) {
      return item.isDisabled === true;
    }).map(function (disabledItem) {
      return disabledItem.value;
    }));
    var selectionProps = {
      label: label,
      items: items,
      selectedKeys: selectedKeys,
      defaultSelectedKeys: defaultSelectedKeys,
      onSelectionChange: onSelectionChange,
      selectionMode: selectionMode,
      disabledKeys: disabledKeys,
      onSearchInputChange: onSearchInputChange
    };
    return /*#__PURE__*/React.createElement(MenuTriggerProvider, __assign({}, menuTriggerProps), /*#__PURE__*/React.createElement("div", {
      className: className
    }, /*#__PURE__*/React.createElement(MenuTriggerConsumer, null, trigger), /*#__PURE__*/React.createElement(MenuPopup, __assign({}, menuPopupProps), /*#__PURE__*/React.createElement(SelectionProvider, __assign({}, selectionProps), /*#__PURE__*/React.createElement(SelectionConsumer, null, children)))));
  };
  FilterMultiSelect.displayName = 'FilterMultiSelect';
  FilterMultiSelect.TriggerButton = FilterTriggerButton;
  FilterMultiSelect.RemovableTrigger = RemovableFilterTrigger;
  FilterMultiSelect.SearchInput = SearchInput;
  FilterMultiSelect.ListBox = ListBox;
  FilterMultiSelect.ListBoxSection = ListBoxSection;
  FilterMultiSelect.SectionDivider = SectionDivider;
  FilterMultiSelect.Option = MultiSelectOption;
  FilterMultiSelect.SelectAllButton = SelectAllButton;
  FilterMultiSelect.ClearButton = ClearButton;
  FilterMultiSelect.MenuFooter = MenuFooter; // For layout
  // Menu Loading Skeleton example
  FilterMultiSelect.MenuLoadingSkeleton = MenuLoadingSkeleton;
  FilterMultiSelect.LoadMoreButton = LoadMoreButton;
  FilterMultiSelect.NoResults = NoResults;
  return FilterMultiSelect;
}();
export { FilterMultiSelect };
