import { __rest, __assign } from 'tslib';
import React, { useState } from 'react';
import { useButton } from '@react-aria/button';
import { useSelect, HiddenSelect } from '@react-aria/select';
import { useSelectState } from '@react-stately/select';
import { Filter } from '../Filter/Filter.mjs';
import { FilterContents } from '../Filter/subcomponents/FilterContents/FilterContents.mjs';
import { SelectProvider } from '../../__next__/Select/context/SelectContext.mjs';
import '../../__next__/Select/subcomponents/ListBox/ListBox.mjs';
import { ListBoxSection } from '../../__next__/Select/subcomponents/ListBoxSection/ListBoxSection.mjs';
import { ListItem } from '../../__next__/Select/subcomponents/ListItem/ListItem.mjs';
import '../../__next__/Select/subcomponents/ListItems/ListItems.mjs';
import { Option } from '../../__next__/Select/subcomponents/Option/Option.mjs';
import '../../__next__/Select/subcomponents/Overlay/Overlay.mjs';
import { SectionDivider } from '../../__next__/Select/subcomponents/SectionDivider/SectionDivider.mjs';
import { SelectPopoverContents } from '../../__next__/Select/subcomponents/SelectPopoverContents/SelectPopoverContents.mjs';
import '../../__next__/Select/subcomponents/SelectToggle/SelectToggle.mjs';
import { getDisabledKeysFromItems } from '../../__next__/Select/utils/getDisabledKeysFromItems.mjs';
import { transformSelectItemToCollectionElement } from '../../__next__/Select/utils/transformSelectItemToCollectionElement.mjs';
import styles from './FilterSelect.module.css.mjs';
const FilterSelect = /*#__PURE__*/function () {
  const FilterSelect = function (_a) {
    var isOpen = _a.isOpen,
      setIsOpen = _a.setIsOpen,
      renderTrigger = _a.renderTrigger,
      label = _a.label,
      children = _a.children,
      items = _a.items,
      classNameOverride = _a.classNameOverride,
      selectedKey = _a.selectedKey,
      restProps = __rest(_a, ["isOpen", "setIsOpen", "renderTrigger", "label", "children", "items", "classNameOverride", "selectedKey"]);
    // Ref will be populated by Filter
    var _b = useState({
        current: null
      }),
      triggerRef = _b[0],
      setTriggerRef = _b[1];
    var disabledKeys = getDisabledKeysFromItems(items);
    var ariaSelectProps = __assign({
      label: label,
      items: items,
      children: transformSelectItemToCollectionElement,
      isOpen: isOpen,
      onOpenChange: setIsOpen,
      disabledKeys: disabledKeys,
      selectedKey: typeof selectedKey === 'number' ? selectedKey.toString() : selectedKey
    }, restProps);
    var state = useSelectState(ariaSelectProps);
    var _c = useSelect(ariaSelectProps, state, triggerRef),
      triggerProps = _c.triggerProps,
      menuProps = _c.menuProps;
    var buttonProps = useButton(triggerProps, triggerRef).buttonProps;
    // `aria-labelledby` and `aria-controls` are being remapped because the `buttonProps` ids generated by React Aria point to nothing.
    // This should ideally be refactored but for now the `aria-controls` is set to the Filter's Listbox (menuProps.id) and the `aria-labelledby` to undefined so the accessible name is derived from the buttons content.
    var renderTriggerButtonProps = __assign(__assign({}, buttonProps), {
      'aria-labelledby': undefined,
      'aria-controls': menuProps.id
    });
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(HiddenSelect, {
      label: label,
      state: state,
      triggerRef: triggerRef
    }), /*#__PURE__*/React.createElement(Filter, {
      isOpen: isOpen,
      setIsOpen: setIsOpen,
      renderTrigger: function () {
        var _a;
        return renderTrigger(__assign({
          selectedValue: (_a = state.selectedItem) === null || _a === void 0 ? void 0 : _a.textValue,
          label: label,
          isOpen: isOpen
        }, renderTriggerButtonProps));
      },
      onMount: setTriggerRef,
      classNameOverride: classNameOverride
    }, /*#__PURE__*/React.createElement(FilterContents, {
      classNameOverride: styles.filterContents
    }, /*#__PURE__*/React.createElement(SelectProvider, {
      state: state
    }, /*#__PURE__*/React.createElement(SelectPopoverContents, {
      menuProps: __assign(__assign({}, menuProps), {
        'aria-labelledby': buttonProps.id
      })
    }, children)))));
  };
  FilterSelect.displayName = 'FilterSelect';
  FilterSelect.Section = ListBoxSection;
  FilterSelect.SectionDivider = SectionDivider;
  FilterSelect.Option = Option;
  FilterSelect.ItemDefaultRender = ListItem;
  return FilterSelect;
}();
export { FilterSelect };
