import { __rest, __assign } from 'tslib';
import { createElement } from 'react';
import classnames from 'classnames';
import styles from './Heading.module.scss.mjs';
var VARIANTS_24PX_OR_GREATER = ['display-0', 'heading-1', 'heading-2'];
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3074885298/Typography#Headings Guidance}
 * {@link https://cultureamp.design/?path=/docs/components-typography-heading--display-0 Storybook}
 */
var Heading = function (_a) {
  var children = _a.children,
    tag = _a.tag,
    variant = _a.variant,
    _b = _a.color,
    color = _b === void 0 ? 'dark' : _b,
    classNameOverride = _a.classNameOverride,
    restProps = __rest(_a, ["children", "tag", "variant", "color", "classNameOverride"]);
  var inferredTag = tag !== null && tag !== void 0 ? tag : translateHeadingLevelToTag(variant);
  var className = classnames(styles.heading, styles[variant], classNameOverride, styles[color], VARIANTS_24PX_OR_GREATER.includes(variant) ? styles.large : styles.small);
  return /*#__PURE__*/createElement(inferredTag, __assign(__assign({}, restProps), {
    className: className
  }), children);
};
Heading.displayName = 'Heading';
/**
 * A helper to infer the tag when not explicitly passed as a prop
 * @param headingLevel Level of the heading
 */
var translateHeadingLevelToTag = function (headingLevel) {
  switch (headingLevel) {
    case 'display-0':
    case 'composable-header-title':
    case 'heading-1':
      return 'h1';
    case 'heading-2':
      return 'h2';
    case 'heading-3':
      return 'h3';
    case 'heading-4':
      return 'h4';
    case 'heading-5':
      return 'h5';
    case 'heading-6':
    default:
      return 'h6';
  }
};
export { Heading };
