import { __rest, __assign } from 'tslib';
import React, { useState } from 'react';
import { Base } from '../../subcomponents/Base/Base.mjs';
import { VideoPlayer } from '../../subcomponents/VideoPlayer/VideoPlayer.mjs';

/**
 * This component is a snowflake. It plays two assets one after the other:
 *  - An "initial" animation that is only ever played once, never looping
 *  - An "ambient" animation that can be looped, depending on the props passed into it
 */
const BrandMomentCaptureIntro = /*#__PURE__*/function () {
  const BrandMomentCaptureIntro = function (_a) {
    var isAnimated = _a.isAnimated,
      alt = _a.alt,
      enableAspectRatio = _a.enableAspectRatio,
      otherProps = __rest(_a, ["isAnimated", "alt", "enableAspectRatio"]);
    var _b = useState(false),
      firstAnimationComplete = _b[0],
      setFirstAnimationComplete = _b[1];
    var aspectRatio = enableAspectRatio ? 'landscape' : undefined;
    if (!isAnimated) {
      return /*#__PURE__*/React.createElement(Base, __assign({
        aspectRatio: aspectRatio,
        alt: alt !== null && alt !== void 0 ? alt : ''
      }, otherProps, {
        name: "illustrations/heart/scene/brand-moments-capture-intro-loop.png"
      }));
    }
    if (firstAnimationComplete) {
      return /*#__PURE__*/React.createElement(VideoPlayer, __assign({}, otherProps, {
        aspectRatio: aspectRatio,
        fallback: "illustrations/heart/scene/brand-moments-capture-intro-loop",
        source: "illustrations/heart/scene/brand-moments-capture-intro-loop",
        autoplay: firstAnimationComplete ? otherProps.autoplay : false
      }));
    }
    return /*#__PURE__*/React.createElement(VideoPlayer, __assign({}, otherProps, {
      aspectRatio: aspectRatio,
      fallback: "illustrations/heart/scene/brand-moments-capture-intro",
      source: "illustrations/heart/scene/brand-moments-capture-intro",
      onEnded: function () {
        return setFirstAnimationComplete(true);
      },
      loop: false
    }));
  };
  BrandMomentCaptureIntro.displayName = 'BrandMomentCaptureIntro';
  return BrandMomentCaptureIntro;
}();
export { BrandMomentCaptureIntro };
