import { __assign } from 'tslib';
import React, { useState, useCallback, useEffect } from 'react';
import classnames from 'classnames';
import { FocusOn } from 'react-focus-on';
import { usePopper } from 'react-popper';
import styles from './MenuDropdown.module.scss.mjs';
const MenuDropdown = /*#__PURE__*/function () {
  const MenuDropdown = function (_a) {
    var children = _a.children,
      referenceElement = _a.referenceElement,
      id = _a.id,
      hideMenuDropdown = _a.hideMenuDropdown,
      _b = _a.autoHide,
      autoHide = _b === void 0 ? 'on' : _b,
      _c = _a.align,
      align = _c === void 0 ? 'left' : _c,
      _d = _a.width,
      width = _d === void 0 ? 'default' : _d;
    var _e = useState(null),
      popperElement = _e[0],
      setPopperElement = _e[1];
    var _f = usePopper(referenceElement, popperElement, {
        modifiers: [{
          name: 'offset',
          options: {
            offset: [0, 6] // value used from the $spacing-xs scss variable,
          }
        }, {
          name: 'preventOverflow',
          options: {
            // Gives some room so the menu shadow doesn't get clipped if near the edge of the viewport.
            padding: 8
          }
        }],
        placement: align === 'left' ? 'bottom-start' : 'bottom-end'
      }),
      popperStyles = _f.styles,
      attributes = _f.attributes;
    // This callback handler will not run when autoHide === "off"
    var handleDocumentClickForAutoHide = useCallback(function (e) {
      if (popperElement && e.target instanceof Node && !popperElement.contains(e.target) && referenceElement !== e.target && !(referenceElement === null || referenceElement === void 0 ? void 0 : referenceElement.contains(e.target))) {
        hideMenuDropdown();
      }
    }, [popperElement, referenceElement, hideMenuDropdown]);
    var handleDocumentResize = useCallback(function () {
      hideMenuDropdown();
    }, [hideMenuDropdown]);
    var handleRootClick = function () {
      if (autoHide === 'on') {
        // ie. is not equal to "off" | "outside-click-only"
        hideMenuDropdown();
      }
    };
    useEffect(function () {
      window.addEventListener('resize', handleDocumentResize, false);
      return function () {
        window.removeEventListener('resize', handleDocumentResize, false);
      };
    }, [handleDocumentResize]);
    useEffect(function () {
      if (autoHide !== 'off') {
        document.addEventListener('click', handleDocumentClickForAutoHide, true);
      }
      return function () {
        if (autoHide !== 'off') {
          document.removeEventListener('click', handleDocumentClickForAutoHide, true);
        }
      };
    }, [autoHide, handleDocumentClickForAutoHide]);
    return /*#__PURE__*/React.createElement(FocusOn, {
      enabled: !!referenceElement,
      scrollLock: false,
      noIsolation: true,
      shards: referenceElement ? [referenceElement] : undefined,
      onEscapeKey: hideMenuDropdown,
      returnFocus: function () {
        referenceElement === null || referenceElement === void 0 ? void 0 : referenceElement.focus();
        return false;
      }
    }, /*#__PURE__*/React.createElement("div", __assign({
      id: id,
      ref: setPopperElement
    }, attributes.popper, {
      style: popperStyles.popper,
      className: classnames(styles.menuContainer, width == 'default' && styles.defaultWidth),
      onClick: handleRootClick
    }), children));
  };
  MenuDropdown.displayName = 'MenuDropdown';
  return MenuDropdown;
}();
export { MenuDropdown };
