import { __rest, __assign } from 'tslib';
import React, { useId, useRef } from 'react';
import classnames from 'classnames';
import { FieldMessage } from '../FieldMessage/FieldMessage.mjs';
import { Heading } from '../Heading/Heading.mjs';
import { MultiSelectOptions } from './subcomponents/MultiSelectOptions/MultiSelectOptions.mjs';
import { MultiSelectToggle } from './subcomponents/MultiSelectToggle/MultiSelectToggle.mjs';
import { Popover } from './subcomponents/Popover/Popover.mjs';
import { useFloating } from '@floating-ui/react-dom';
import styles from './MultiSelect.module.scss.mjs';
const MultiSelect = /*#__PURE__*/function () {
  const MultiSelect = function (_a) {
    var propsId = _a.id,
      label = _a.label,
      items = _a.items,
      selectedValues = _a.selectedValues,
      description = _a.description,
      onSelectedValuesChange = _a.onSelectedValuesChange,
      isOpen = _a.isOpen,
      onOpenChange = _a.onOpenChange,
      classNameOverride = _a.classNameOverride,
      validationMessage = _a.validationMessage,
      restProps = __rest(_a, ["id", "label", "items", "selectedValues", "description", "onSelectedValuesChange", "isOpen", "onOpenChange", "classNameOverride", "validationMessage"]);
    var fallbackId = useId();
    var id = propsId !== null && propsId !== void 0 ? propsId : fallbackId;
    var descriptionId = "".concat(id, "-description");
    var validationId = "".concat(id, "-validation-message");
    var toggleButtonRef = useRef(null);
    var refs = useFloating().refs;
    var handleToggleClick = function () {
      return onOpenChange(!isOpen);
    };
    var handleClose = function () {
      return onOpenChange(false);
    };
    var onClickOutside = function (e) {
      var toggle = refs.reference.current;
      var isInToggle = toggle.contains(e.target);
      if (!isInToggle) {
        e.stopPropagation();
        handleClose();
      }
    };
    var itemsMap = items.reduce(function (acc, item) {
      acc[item.value] = item;
      return acc;
    }, {});
    var handleOnRemoveOption = function (optionValue) {
      var newValues = new Set(selectedValues.values());
      newValues.delete(optionValue);
      onSelectedValuesChange(newValues);
    };
    var handleRemoveAllOptions = function () {
      var newValues = new Set([]);
      onSelectedValuesChange(newValues);
    };
    return /*#__PURE__*/React.createElement("div", __assign({
      id: id,
      className: classnames(classNameOverride)
    }, restProps), /*#__PURE__*/React.createElement(Heading, {
      tag: "span",
      variant: "heading-6",
      id: "".concat(id, "--label")
    }, label), /*#__PURE__*/React.createElement("div", {
      ref: refs.setReference,
      className: styles.toggleContainer
    }, /*#__PURE__*/React.createElement(MultiSelectToggle, {
      ref: toggleButtonRef,
      id: "".concat(id, "--toggle"),
      "aria-labelledby": "".concat(id, "--label"),
      "aria-describedby": "".concat(validationId, " ").concat(descriptionId),
      "aria-controls": "".concat(id, "--popover"),
      onClick: handleToggleClick,
      isOpen: isOpen,
      selectedOptions: Array.from(selectedValues).map(function (value) {
        return itemsMap[value];
      }),
      status: validationMessage === null || validationMessage === void 0 ? void 0 : validationMessage.status,
      onRemoveOption: handleOnRemoveOption,
      onRemoveAllOptions: handleRemoveAllOptions
    })), validationMessage && /*#__PURE__*/React.createElement(FieldMessage, __assign({
      id: validationId
    }, validationMessage)), description && /*#__PURE__*/React.createElement(FieldMessage, {
      id: descriptionId,
      message: description
    }), isOpen && (/*#__PURE__*/React.createElement(Popover, {
      refs: refs,
      id: "".concat(id, "--popover"),
      role: "dialog",
      "aria-modal": "true",
      tabIndex: -1,
      focusOnProps: {
        enabled: true,
        onClickOutside: onClickOutside,
        onEscapeKey: handleClose,
        shards: [toggleButtonRef],
        noIsolation: true,
        onActivation: function () {
          var _a, _b;
          return (_b = (_a = refs.floating) === null || _a === void 0 ? void 0 : _a.current) === null || _b === void 0 ? void 0 : _b.focus();
        }
      },
      classNameOverride: styles.popover
    }, /*#__PURE__*/React.createElement(MultiSelectOptions, {
      id: "".concat(id, "--options"),
      options: items,
      onChange: onSelectedValuesChange,
      selectedValues: selectedValues
    }))));
  };
  MultiSelect.displayName = 'MultiSelect';
  return MultiSelect;
}();
export { MultiSelect };
