import { __assign, __spreadArray } from 'tslib';
import React, { useState, useContext } from 'react';
import { v4 } from 'uuid';
var ToastNotificationContext = /*#__PURE__*/React.createContext(null);
var useToastNotificationContext = function () {
  var context = useContext(ToastNotificationContext);
  if (!context) {
    throw new Error('useToastNotificationContext must be used within the ToastNotificationContext.Provider');
  }
  return context;
};
const ToastNotificationProvider = /*#__PURE__*/function () {
  const ToastNotificationProvider = function (_a) {
    var children = _a.children;
    var _b = useState([]),
      notifications = _b[0],
      setNotifications = _b[1];
    var addToastNotification = function (notification) {
      var uuid = v4();
      var notificationWithId = __assign({
        id: uuid
      }, notification);
      setNotifications(function (existing) {
        var notificationExists = existing.find(function (_a) {
          var id = _a.id;
          return id === notification.id;
        });
        return notificationExists ? existing : __spreadArray(__spreadArray([], existing, true), [notificationWithId], false);
      });
    };
    var updateToastNotification = function (notification) {
      var notificationIndex = notifications.findIndex(function (_a) {
        var id = _a.id;
        return id === notification.id;
      });
      var copy = notifications.slice();
      copy.splice(notificationIndex, 1, notification); // Mutation to insert notification over itself
      setNotifications(copy);
    };
    var removeToastNotification = function (notificationID) {
      setNotifications(function (prev) {
        return prev.filter(function (_a) {
          var id = _a.id;
          return id !== notificationID;
        });
      });
    };
    var clearToastNotifications = function () {
      setNotifications([]);
    };
    var value = {
      notifications: notifications,
      addToastNotification: addToastNotification,
      updateToastNotification: updateToastNotification,
      removeToastNotification: removeToastNotification,
      clearToastNotifications: clearToastNotifications
    };
    return /*#__PURE__*/React.createElement(ToastNotificationContext.Provider, {
      value: value
    }, children);
  };
  ToastNotificationProvider.displayName = 'ToastNotificationProvider';
  return ToastNotificationProvider;
}();
export { ToastNotificationProvider, useToastNotificationContext };
