import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { useMediaQueries } from '../utils/useMediaQueries.mjs';
import '../utils/ReversedColors/ReversedColors.mjs';
import { DirectionalLink } from './subcomponents/DirectionalLink/DirectionalLink.mjs';
import { PaginationLink } from './subcomponents/PaginationLink/PaginationLink.mjs';
import { TruncateIndicator } from './subcomponents/TruncateIndicator/TruncateIndicator.mjs';
import { createRange } from './utils/createRange.mjs';
import styles from './Pagination.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082092975/Pagination Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-pagination--docs Storybook}
 */
var Pagination = function (_a) {
  var _b = _a.currentPage,
    currentPage = _b === void 0 ? 1 : _b,
    pageCount = _a.pageCount,
    ariaLabelNextPage = _a.ariaLabelNextPage,
    ariaLabelPreviousPage = _a.ariaLabelPreviousPage,
    ariaLabelPage = _a.ariaLabelPage,
    onPageChange = _a.onPageChange,
    classNameOverride = _a.classNameOverride,
    restProps = __rest(_a, ["currentPage", "pageCount", "ariaLabelNextPage", "ariaLabelPreviousPage", "ariaLabelPage", "onPageChange", "classNameOverride"]);
  var queries = useMediaQueries().queries;
  // Click event for all pagination buttons (next, prev, and the actual numbers)
  var handleButtonClick = function (newPage) {
    if (newPage === 'prev') {
      onPageChange(currentPage - 1);
      return;
    }
    if (newPage === 'next') {
      onPageChange(currentPage + 1);
      return;
    }
    onPageChange(newPage);
  };
  var paginationIndicator = function (page) {
    return /*#__PURE__*/React.createElement(PaginationLink, {
      key: page,
      pageNumber: page,
      isActive: currentPage === page,
      "aria-label": "".concat(ariaLabelPage, " ").concat(page),
      onClick: function () {
        return handleButtonClick(page);
      }
    });
  };
  var pagination = function (boundaryPagesRange, siblingPagesRange) {
    var items = [];
    // truncateSize is 1 now but could be 0 if we add the ability to hide it.
    var truncateSize = 1;
    var showAllPages = 1 + 2 * truncateSize + 2 * siblingPagesRange + 2 * boundaryPagesRange >= pageCount;
    // Simplify generation of pages if number of available items is equal or greater than total pages to show
    if (showAllPages) {
      return createRange(1, pageCount).map(paginationIndicator);
    } else {
      // Calculate group of first pages
      var firstPagesStart = 1;
      var firstPagesEnd = boundaryPagesRange;
      var firstPages = createRange(firstPagesStart, firstPagesEnd).map(paginationIndicator);
      // Calculate group of last pages
      var lastPagesStart = pageCount + 1 - boundaryPagesRange;
      var lastPagesEnd = pageCount;
      var lastPages = createRange(lastPagesStart, lastPagesEnd).map(paginationIndicator);
      // Calculate group of main pages
      var mainPagesStart = Math.min(Math.max(currentPage - siblingPagesRange, firstPagesEnd + truncateSize + 1), lastPagesStart - truncateSize - 2 * siblingPagesRange - 1);
      var mainPagesEnd = mainPagesStart + 2 * siblingPagesRange;
      var mainPages = createRange(mainPagesStart, mainPagesEnd).map(paginationIndicator);
      // Add group of first pages
      items.push.apply(items, firstPages);
      // Calculate and add truncate before group of main pages
      var firstEllipsisPageNumber = mainPagesStart - 1;
      var showPageInsteadOfFirstEllipsis = firstEllipsisPageNumber === firstPagesEnd + 1;
      items.push(showPageInsteadOfFirstEllipsis ? paginationIndicator(firstEllipsisPageNumber) : (/*#__PURE__*/React.createElement(TruncateIndicator, {
        key: firstEllipsisPageNumber
      })));
      // Add group of main pages
      items.push.apply(items, mainPages);
      // Calculate and add truncate after group of main pages
      var secondEllipsisPageNumber = mainPagesEnd + 1;
      var showPageInsteadOfSecondEllipsis = secondEllipsisPageNumber === lastPagesStart - 1;
      items.push(showPageInsteadOfSecondEllipsis ? paginationIndicator(secondEllipsisPageNumber) : (/*#__PURE__*/React.createElement(TruncateIndicator, {
        key: secondEllipsisPageNumber
      })));
      // Add group of last pages
      items.push.apply(items, lastPages);
    }
    return items;
  };
  var previousPageDisabled = currentPage <= 1;
  var nextPageDisabled = currentPage >= pageCount;
  return /*#__PURE__*/React.createElement("nav", __assign({
    className: classnames(styles.container, classNameOverride)
  }, restProps), /*#__PURE__*/React.createElement(DirectionalLink, {
    label: ariaLabelPreviousPage,
    direction: "prev",
    disabled: previousPageDisabled,
    onClick: function () {
      return handleButtonClick('prev');
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: styles.pagesIndicatorWrapper
  }, pagination(queries.isMediumOrSmaller ? 0 : 1, queries.isSmall ? 0 : 1)), /*#__PURE__*/React.createElement(DirectionalLink, {
    label: ariaLabelNextPage,
    direction: "next",
    disabled: nextPageDisabled,
    onClick: function () {
      return handleButtonClick('next');
    }
  }));
};
export { Pagination };
