import { __rest, __assign } from 'tslib';
import React, { useState, useMemo } from 'react';
import classnames from 'classnames';
import { usePopper } from 'react-popper';
import { Heading } from '../Heading/Heading.mjs';
import { Text } from '../Text/Text.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
import { mapSizeToClass, mapVariantToBoxClass, mapVariantToIconClass, mapVariantToIcon, mapLineVariant, mapArrowVariantToClass } from './utils/classMappers.mjs';
import styles from './Popover.module.scss.mjs';

// Sync with styles.scss
var arrowWidth = 14;
var arrowHeight = 7;
/**
 * {@link https://cultureamp.design/components/popover/ Guidance} |
 * {@link https://cultureamp.design/storybook/?path=/docs/components-popover--default-kaizen-site-demo Storybook}
 */
const Popover = /*#__PURE__*/function () {
  const Popover = function (_a) {
    var children = _a.children,
      _b = _a.variant,
      variant = _b === void 0 ? 'default' : _b,
      _c = _a.placement,
      placement = _c === void 0 ? 'top' : _c,
      _d = _a.size,
      size = _d === void 0 ? 'small' : _d,
      heading = _a.heading,
      _e = _a.dismissible,
      dismissible = _e === void 0 ? false : _e,
      onClose = _a.onClose,
      _f = _a.singleLine,
      singleLine = _f === void 0 ? false : _f,
      customIcon = _a.customIcon,
      referenceElement = _a.referenceElement,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["children", "variant", "placement", "size", "heading", "dismissible", "onClose", "singleLine", "customIcon", "referenceElement", "classNameOverride"]);
    var _g = useState(null),
      popperElement = _g[0],
      setPopperElement = _g[1];
    var _h = useState(null),
      arrowElement = _h[0],
      setArrowElement = _h[1];
    var _j = usePopper(referenceElement, popperElement, {
        modifiers: [{
          name: 'arrow',
          options: {
            element: arrowElement,
            // Ensures that the arrow doesn't go too far to the left or right
            // of the tooltip.
            padding: arrowWidth / 2 + 10
          }
        }, {
          name: 'offset',
          options: {
            offset: [0, arrowHeight + 6]
          }
        }, {
          name: 'preventOverflow',
          options: {
            // Makes sure that the popover isn't flush up against the end of the
            // viewport
            padding: 8,
            altAxis: true,
            altBoundary: true,
            tetherOffset: 50
          }
        }, {
          name: 'flip',
          options: {
            padding: 8,
            altBoundary: true,
            fallbackPlacements: ['left', 'top', 'bottom', 'right']
          }
        }],
        placement: placement
      }),
      popperStyles = _j.styles,
      attributes = _j.attributes;
    return /*#__PURE__*/React.createElement("div", __assign({
      ref: setPopperElement,
      style: popperStyles.popper
    }, attributes.popper, {
      className: classnames(styles.root, mapSizeToClass(size), classNameOverride)
    }, restProps), /*#__PURE__*/React.createElement("div", {
      className: mapVariantToBoxClass(variant)
    }, heading && (/*#__PURE__*/React.createElement("div", {
      className: styles.header
    }, variant !== 'default' && (/*#__PURE__*/React.createElement("span", {
      className: classnames(styles.icon, mapVariantToIconClass(variant))
    }, customIcon !== null && customIcon !== void 0 ? customIcon : mapVariantToIcon(variant))), /*#__PURE__*/React.createElement(Heading, {
      variant: "heading-6",
      classNameOverride: styles.singleLine
    }, heading), dismissible && (/*#__PURE__*/React.createElement("button", {
      className: styles.close,
      onClick: onClose,
      type: "button",
      "aria-label": "close"
    }, /*#__PURE__*/React.createElement(Icon, {
      name: "close",
      isPresentational: true,
      isFilled: true
    }))))), /*#__PURE__*/React.createElement(Text, {
      tag: "div",
      variant: "small",
      classNameOverride: classnames(styles.container, mapLineVariant(singleLine))
    }, children)), /*#__PURE__*/React.createElement("div", {
      ref: setArrowElement,
      style: popperStyles.arrow,
      className: styles.arrowWrapper
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.arrow, mapArrowVariantToClass(variant))
    })));
  };
  Popover.displayName = 'Popover';
  /**
   * How to use:
   *
   * const [referenceElementRef, Popover] = usePopover()
   *
   * return (<>
   *   <button ref={referenceElementRef}>
   *     Hello world
   *   </button>
   *   <Popover>Hello world</Popover>
   * </>)
   *
   * The purpose of this hook is to abstract away some of the awkwardness with the
   * requirement of passing in refs with popper. We need to use `useState` instead
   * of `useRef`, which may not be immediately intuitive.
   *
   * The popper documentation to help provide more context:
   *   https://popper.js.org/react-popper/v2/hook/
   */
  return Popover;
}();
var usePopover = function () {
  var _a = useState(null),
    referenceElement = _a[0],
    setReferenceElement = _a[1];
  // I guess the problem with this pattern, is that every time referenceElement
  // changes, a brand new component is generated, which would be bad for memoization.
  // In this situation however, the value is rarely going to change, and
  // popovers aren't going to include content with expensive render times.
  var PopoverWithRef = useMemo(
  // eslint-disable-next-line react/display-name
  function () {
    return function (props) {
      return referenceElement ? /*#__PURE__*/React.createElement(Popover, __assign({}, props, {
        referenceElement: referenceElement
      })) : null;
    };
  }, [referenceElement]);
  return [setReferenceElement, PopoverWithRef];
};
export { Popover, usePopover };
