import { __rest, __assign, __spreadArray } from 'tslib';
import React, { useId, useState, useEffect } from 'react';
import classnames from 'classnames';
import { FieldMessage } from '../../FieldMessage/FieldMessage.mjs';
import { Label } from '../../Label/Label.mjs';
import { InlineNotification } from '../../Notification/InlineNotification/InlineNotification.mjs';
import '../../Notification/GlobalNotification/GlobalNotification.mjs';
import '../../Notification/ToastNotification/ToastNotification/ToastNotification.mjs';
import '../../Notification/ToastNotification/ToastNotificationsList/ToastNotificationsList.mjs';
import '../../Notification/ToastNotification/context/ToastNotificationContext.mjs';
import * as ProseMirrorState from 'prosemirror-state';
import 'prosemirror-view';
import { useRichTextEditor } from '../utils/core/hooks/useRichTextEditor.mjs';
import * as ProseMirrorModel from 'prosemirror-model';
import 'prosemirror-inputrules';
import { createLinkManager } from '../utils/plugins/LinkManager/LinkManager.mjs';
import '../utils/plugins/LinkManager/components/LinkEditor/LinkEditor.mjs';
import '../utils/plugins/LinkManager/components/LinkModal/LinkModal.mjs';
import '../utils/plugins/LinkManager/components/LinkPopover/LinkPopover.mjs';
import * as ProseMirrorCommands from 'prosemirror-commands';
import * as ProseMirrorKeymap from 'prosemirror-keymap';
import * as ProseMirrorHistory from 'prosemirror-history';
import 'prosemirror-schema-list';
import { createSchemaFromControls } from './schema.mjs';
import { ToggleIconButton } from './subcomponents/ToggleIconButton/ToggleIconButton.mjs';
import { Toolbar } from './subcomponents/Toolbar/Toolbar.mjs';
import { ToolbarSection } from './subcomponents/ToolbarSection/ToolbarSection.mjs';
import { buildControlMap } from './utils/controlmap.mjs';
import { buildInputRules } from './utils/inputrules.mjs';
import { buildKeymap } from './utils/keymap.mjs';
import styles from './RichTextEditor.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896752/Rich+Text+Editor Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-richtexteditor--docs Storybook}
 */
const RichTextEditor = /*#__PURE__*/function () {
  const RichTextEditor = function (_a) {
    var id = _a.id,
      onChange = _a.onChange,
      defaultValue = _a.defaultValue,
      labelText = _a.labelText,
      labelledBy = _a["aria-labelledby"],
      describedBy = _a["aria-describedby"],
      classNameOverride = _a.classNameOverride,
      controls = _a.controls,
      _b = _a.rows,
      rows = _b === void 0 ? 3 : _b,
      dataError = _a.dataError,
      onDataError = _a.onDataError,
      validationMessage = _a.validationMessage,
      description = _a.description,
      _c = _a.status,
      status = _c === void 0 ? 'default' : _c,
      restProps = __rest(_a, ["id", "onChange", "defaultValue", "labelText", 'aria-labelledby', 'aria-describedby', "classNameOverride", "controls", "rows", "dataError", "onDataError", "validationMessage", "description", "status"]);
    var generatedId = useId();
    var schema = useState(createSchemaFromControls(controls))[0];
    var editorId = id !== null && id !== void 0 ? id : generatedId;
    var labelId = labelledBy !== null && labelledBy !== void 0 ? labelledBy : "".concat(editorId, "-rte-label");
    var validationMessageAria = validationMessage ? "".concat(editorId, "-rte-validation-message") : '';
    var descriptionAria = description ? "".concat(editorId, "-rte-description") : '';
    var ariaDescribedBy = classnames(validationMessageAria, descriptionAria, describedBy);
    var useRichTextEditorResult = function () {
      try {
        // @todo: Fix if possible - avoiding breaking in eslint upgrade
        // eslint-disable-next-line react-hooks/rules-of-hooks
        return useRichTextEditor(ProseMirrorState.EditorState.create({
          doc: ProseMirrorModel.Node.fromJSON(schema, {
            type: 'doc',
            // we're converting empty arrays to the ProseMirror default "empty" state because when
            // given an empty array ProseMirror returns undefined, breaking the type
            content: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.length) > 0 ? defaultValue : [{
              type: 'paragraph'
            }]
          }),
          schema: schema,
          plugins: getPlugins(controls, schema)
        }), {
          'aria-labelledby': labelId,
          'role': 'textbox',
          'aria-describedby': ariaDescribedBy
        });
      } catch (_a) {
        return new Error('Bad data error');
      }
    }();
    if (useRichTextEditorResult instanceof Error) {
      onDataError === null || onDataError === void 0 ? void 0 : onDataError();
      return /*#__PURE__*/React.createElement(InlineNotification, {
        headingProps: {
          children: 'Error',
          variant: 'heading-6'
        },
        type: "negative",
        persistent: true
      }, dataError !== null && dataError !== void 0 ? dataError : 'Something went wrong');
    }
    var editorRef = useRichTextEditorResult[0],
      editorState = useRichTextEditorResult[1],
      dispatchTransaction = useRichTextEditorResult[2];
    var controlMap = buildControlMap(schema, editorState, controls);
    // @todo: Fix if possible - avoiding breaking in eslint upgrade
    // eslint-disable-next-line react-hooks/rules-of-hooks
    useEffect(function () {
      onChange(editorState);
      // Including `onContentChange` in the dependencies here will cause a 'Maximum update depth exceeded' issue
      // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [editorState]);
    return /*#__PURE__*/React.createElement(React.Fragment, null, !labelledBy && labelText && (/*#__PURE__*/React.createElement(Label, {
      classNameOverride: styles.editorLabel,
      id: labelId,
      labelText: labelText
    })), /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.editorWrapper, styles[status])
    }, controls && (/*#__PURE__*/React.createElement(Toolbar, {
      "aria-controls": editorId,
      "aria-label": "Text formatting",
      classNameOverride: styles.toolbar
    }, controlMap.map(function (section, index) {
      return /*#__PURE__*/React.createElement(ToolbarSection, {
        key: index
      }, section.map(function (controlConfig, controlKeyIndex) {
        return /*#__PURE__*/React.createElement(ToggleIconButton, {
          key: controlKeyIndex,
          icon: controlConfig.icon,
          disabled: controlConfig.disabled,
          label: controlConfig.label,
          isActive: controlConfig.isActive,
          onClick: function () {
            return dispatchTransaction(controlConfig.action);
          }
        });
      }));
    }))), /*#__PURE__*/React.createElement("div", __assign({
      id: editorId,
      ref: editorRef,
      className: classnames(styles.editor, styles["rows".concat(rows)], classNameOverride, controls != null && controls.length > 0 && styles.hasToolbar)
    }, restProps))), validationMessage && (/*#__PURE__*/React.createElement(FieldMessage, {
      id: validationMessageAria,
      message: validationMessage,
      status: status
    })), description && /*#__PURE__*/React.createElement(FieldMessage, {
      id: descriptionAria,
      message: description
    }));
  };
  RichTextEditor.displayName = 'RichTextEditor';
  return RichTextEditor;
}();
function getPlugins(controls, schema) {
  var allControlNames = controls ? controls.reduce(function (acc, c) {
    return __spreadArray(__spreadArray([], acc, true), [c.name], false);
  }, []) : [];
  var plugins = [ProseMirrorHistory.history(), ProseMirrorKeymap.keymap(buildKeymap(schema)), ProseMirrorKeymap.keymap(ProseMirrorCommands.baseKeymap), buildInputRules(schema)];
  if (allControlNames.includes('link')) {
    plugins.push(createLinkManager({
      markType: schema.marks.link
    }));
  }
  return plugins;
}
export { RichTextEditor };
