import { getMarkRange } from './getMarkRange.mjs';

/** Remove part or all of the Mark from the current selection */
var removeMark = function (type, options) {
  if (options === void 0) {
    options = {
      toExtent: false
    };
  }
  return function (state, dispatch) {
    var _a;
    var tr = state.tr,
      selection = state.selection,
      doc = state.doc;
    var from = selection.from,
      to = selection.to;
    var $from = selection.$from;
    if (!dispatch) return false;
    if (selection.empty) {
      dispatch(tr.removeStoredMark(type));
    } else {
      if (options.range || options.toExtent) {
        var range = (_a = options.range) !== null && _a !== void 0 ? _a : getMarkRange($from, type);
        if (range) {
          from = range.from;
          to = range.to;
        }
      }
      var hasMark = doc.rangeHasMark(from, to, type);
      if (hasMark) {
        tr.removeMark(from, to, type);
      }
      dispatch(tr);
    }
    return true;
  };
};
export { removeMark };
