import { getMarkRange } from './getMarkRange.mjs';

/** Update Mark attributes, create nested Marks or split Marks of the same type   */
var updateMark = function (type, attrs, options) {
  if (options === void 0) {
    options = {
      toExtent: false
    };
  }
  return function (state, dispatch) {
    if (!dispatch) return false;
    var tr = state.tr,
      selection = state.selection,
      doc = state.doc;
    var from = selection.from,
      to = selection.to;
    var $from = selection.$from,
      empty = selection.empty;
    if (empty || options.toExtent) {
      var range = getMarkRange($from, type);
      if (range) {
        from = range.from;
        to = range.to;
      }
    }
    var hasMark = doc.rangeHasMark(from, to, type);
    if (hasMark) {
      tr.removeMark(from, to, type);
    }
    tr.addMark(from, to, type.create(attrs));
    dispatch(tr);
    return true;
  };
};
export { updateMark };
