import { __rest, __assign } from 'tslib';
import React, { useId, useState } from 'react';
import classnames from 'classnames';
import ReactSelect, { components } from 'react-select';
import Async from 'react-select/async';
import { FieldMessage } from '../FieldMessage/FieldMessage.mjs';
import { Label } from '../Label/Label.mjs';
import { Tag } from '../Tag/Tag.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
import styles from './Select.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896474/Select Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-select--docs Storybook}
 */
const Select = /*#__PURE__*/function () {
  const Select = /*#__PURE__*/React.forwardRef(function (_a, ref) {
    var _b = _a.variant,
      variant = _b === void 0 ? 'default' : _b,
      _c = _a.status,
      status = _c === void 0 ? 'default' : _c,
      _d = _a.reversed,
      reversed = _d === void 0 ? false : _d,
      label = _a.label,
      validationMessage = _a.validationMessage,
      description = _a.description,
      propsFullWidth = _a.fullWidth,
      propsClassName = _a.className,
      placeholder = _a.placeholder,
      props = __rest(_a, ["variant", "status", "reversed", "label", "validationMessage", "description", "fullWidth", "className", "placeholder"]);
    var reactId = useId();
    // the default for fullWidth depends on the variant
    var fullWidth = propsFullWidth !== null && propsFullWidth !== void 0 ? propsFullWidth : !['secondary', 'secondary-small'].includes(variant);
    var classes = classnames(propsClassName, styles.specificityIncreaser, (!reversed || variant === 'default') && styles.default, reversed && styles.reversed, variant === 'secondary' && styles.secondary, variant === 'secondary-small' && styles.secondarySmall, !fullWidth && styles.notFullWidth, props.isDisabled && styles.disabled, status === 'error' && styles.error);
    var labelId = useState(label ? reactId : undefined)[0];
    return /*#__PURE__*/React.createElement(React.Fragment, null, label ? (/*#__PURE__*/React.createElement(Label, {
      reversed: reversed,
      id: labelId
    }, label)) : null, /*#__PURE__*/React.createElement(ReactSelect, __assign({}, props, {
      ref: ref,
      "aria-labelledby": labelId,
      placeholder: placeholder !== null && placeholder !== void 0 ? placeholder : '',
      components: {
        Control: Control,
        Placeholder: Placeholder,
        DropdownIndicator: DropdownIndicator,
        Menu: Menu,
        GroupHeading: GroupHeading,
        Option: Option,
        NoOptionsMessage: NoOptionsMessage,
        Input: Input,
        SingleValue: SingleValue,
        MultiValue: MultiValue,
        IndicatorsContainer: IndicatorsContainer,
        ValueContainer: ValueContainer,
        ClearIndicator: ClearIndicator,
        IndicatorSeparator: null
      },
      className: classes
    })), validationMessage ? /*#__PURE__*/React.createElement(FieldMessage, {
      message: validationMessage,
      status: status
    }) : null, description ? /*#__PURE__*/React.createElement(FieldMessage, {
      message: description
    }) : null);
  });
  Select.displayName = 'Select';
  return Select;
}();
const AsyncSelect = /*#__PURE__*/function () {
  const AsyncSelect = /*#__PURE__*/React.forwardRef(function (_a, ref) {
    var propsClassName = _a.className,
      placeholder = _a.placeholder,
      props = __rest(_a, ["className", "placeholder"]);
    return /*#__PURE__*/React.createElement(Async, __assign({}, props, {
      ref: ref,
      placeholder: placeholder !== null && placeholder !== void 0 ? placeholder : '',
      components: {
        Control: Control,
        Placeholder: Placeholder,
        DropdownIndicator: DropdownIndicator,
        Menu: Menu,
        Option: Option,
        NoOptionsMessage: NoOptionsMessage,
        Input: Input,
        SingleValue: SingleValue,
        MultiValue: MultiValue,
        IndicatorsContainer: IndicatorsContainer,
        ValueContainer: ValueContainer,
        ClearIndicator: undefined,
        IndicatorSeparator: null,
        LoadingMessage: LoadingMessage
      },
      className: classnames(styles.specificityIncreaser, propsClassName)
    }));
  });
  AsyncSelect.displayName = 'AsyncSelect';
  return AsyncSelect;
}();
var Control = function (props) {
  return /*#__PURE__*/React.createElement("div", {
    "data-automation-id": "Select__Control"
  }, /*#__PURE__*/React.createElement(components.Control, __assign({}, props, {
    className: classnames(styles.control, props.isFocused && styles.focusedControl, props.isDisabled && styles.disabled)
  })));
};
var Placeholder = function (props) {
  return /*#__PURE__*/React.createElement(components.Placeholder, __assign({}, props, {
    className: styles.placeholderOverrides
  }), /*#__PURE__*/React.createElement("span", {
    className: styles.placeholder
  }, props.children));
};
var DropdownIndicator = function (props) {
  return /*#__PURE__*/React.createElement(components.DropdownIndicator, __assign({}, props, {
    className: styles.dropdownIndicator
  }), /*#__PURE__*/React.createElement(Icon, {
    name: props.selectProps.menuIsOpen ? 'keyboard_arrow_up' : 'keyboard_arrow_down',
    isPresentational: true
  }));
};
var LoadingMessage = function (props) {
  return /*#__PURE__*/React.createElement(components.LoadingMessage, __assign({}, props, {
    className: styles.loadingMessage
  }));
};
var Menu = function (props) {
  return /*#__PURE__*/React.createElement(components.Menu, __assign({}, props, {
    className: styles.menu
  }));
};
var GroupHeading = function (props) {
  return /*#__PURE__*/React.createElement(components.GroupHeading, __assign({}, props, {
    className: styles.groupHeading
  }));
};
var Option = function (props) {
  return /*#__PURE__*/React.createElement("div", {
    "data-automation-id": "Select__Option"
  }, /*#__PURE__*/React.createElement(components.Option, __assign({}, props, {
    className: classnames(styles.option, props.isFocused && styles.focusedOption, props.isSelected && styles.selectedOption, props.isDisabled && styles.disabledOption)
  })));
};
var NoOptionsMessage = function (props) {
  return /*#__PURE__*/React.createElement(components.NoOptionsMessage, __assign({}, props), /*#__PURE__*/React.createElement("span", {
    className: styles.noOptionsMessage
  }, props.children));
};
var SingleValue = function (props) {
  return /*#__PURE__*/React.createElement(components.SingleValue, __assign({}, props, {
    className: styles.singleValueOverrides
  }), /*#__PURE__*/React.createElement("span", {
    className: styles.singleValue
  }, props.children));
};
var MultiValue = function (props) {
  return /*#__PURE__*/React.createElement("div", {
    className: styles.multiValue
  }, /*#__PURE__*/React.createElement(Tag, {
    variant: "default",
    dismissible: true,
    inline: true,
    onDismiss: props.removeProps.onClick
  }, props.children));
};
var IndicatorsContainer = function (props) {
  return /*#__PURE__*/React.createElement(components.IndicatorsContainer, __assign({}, props, {
    className: styles.indicatorsContainer
  }));
};
var Input = function (props) {
  return /*#__PURE__*/React.createElement(components.Input, __assign({
    className: styles.input
  }, props));
};
var ValueContainer = function (props) {
  return /*#__PURE__*/React.createElement(components.ValueContainer, __assign({}, props, {
    className: styles.valueContainer
  }));
};
var ClearIndicator = function (props) {
  return /*#__PURE__*/React.createElement(components.ClearIndicator, __assign({}, props, {
    className: styles.clearIndicator
  }), /*#__PURE__*/React.createElement(Icon, {
    name: "cancel",
    isPresentational: true,
    isFilled: true
  }));
};
export { AsyncSelect, Select };
