import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { Container } from '../Container/Container.mjs';
import { Content } from '../Content/Content.mjs';
import { useResizeObserver } from '../utils/useResizeObserver.mjs';
import styles from './Skirt.module.scss.mjs';
var spacing = 24;
var maxHeight = 222;
var fallbackPercentage = 0.8;
const Skirt = /*#__PURE__*/function () {
  const Skirt = function (_a) {
    var children = _a.children,
      _b = _a.variant,
      variant = _b === void 0 ? 'default' : _b,
      _c = _a.titleBlockHasNavigation,
      titleBlockHasNavigation = _c === void 0 ? true : _c,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["children", "variant", "titleBlockHasNavigation", "classNameOverride"]);
    var _d = useResizeObserver(function (entry) {
        if (entry.contentRect) {
          return deriveSkirtHeight(entry.contentRect, titleBlockHasNavigation);
        }
        return undefined;
      }),
      ref = _d[0],
      skirtHeight = _d[1];
    return /*#__PURE__*/React.createElement(Container, __assign({
      ref: ref,
      classNameOverride: classnames(styles.container, classNameOverride)
    }, restProps), /*#__PURE__*/React.createElement("div", {
      style: __assign({}, skirtHeight && {
        height: "".concat(skirtHeight, "px")
      }),
      className: classnames(styles.underlay, styles["".concat(variant, "Variant")])
    }), /*#__PURE__*/React.createElement(Content, {
      classNameOverride: styles.content
    }, children));
  };
  Skirt.displayName = 'Skirt';
  return Skirt;
}();
var deriveSkirtHeight = function (rect, titleBlockHasNavigation) {
  var height = rect.height,
    width = rect.width;
  var responsiveOffset = 0;
  if (width > 768) {
    responsiveOffset = 2.8125 * 16;
  }
  // This ensures the maximum height of the skirt is consistent between pages
  // where the title block has/doesn’t have navigation
  var derivedMaxHeight = titleBlockHasNavigation ? maxHeight : maxHeight + responsiveOffset;
  var maxHeightWithSpacing = derivedMaxHeight + spacing;
  return Math.max(spacing, height > maxHeightWithSpacing ? derivedMaxHeight : height * fallbackPercentage - spacing);
};
export { Skirt };
