import { __rest, __assign } from 'tslib';
import React, { cloneElement } from 'react';
import classnames from 'classnames';
import { Checkbox } from '../Checkbox/Checkbox/Checkbox.mjs';
import '../Checkbox/CheckboxField/CheckboxField.mjs';
import '../Checkbox/CheckboxGroup/CheckboxGroup.mjs';
import { Heading } from '../Heading/Heading.mjs';
import { Tooltip } from '../Tooltip/Tooltip.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
import styles from './Table.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081929256/Table Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-table--docs Storybook}
 */
var TableContainer = function (_a) {
  var _b = _a.variant,
    variant = _b === void 0 ? 'compact' : _b,
    children = _a.children,
    otherProps = __rest(_a, ["variant", "children"]);
  return /*#__PURE__*/React.createElement("div", __assign({
    role: "table",
    className: classnames(styles.container, variant === 'default' && styles.defaultSpacing, variant === 'data' && styles.dataVariant)
  }, otherProps), children);
};
var TableHeader = function (_a) {
  var children = _a.children,
    otherProps = __rest(_a, ["children"]);
  return /*#__PURE__*/React.createElement("div", __assign({
    role: "rowgroup"
  }, otherProps), children);
};
var ratioToPercent = function (width) {
  return width != null ? "".concat(width * 100, "%") : width;
};
var TableHeaderRowCell = function (_a) {
  var _b;
  var labelText = _a.labelText,
    onClick = _a.onClick,
    href = _a.href,
    width = _a.width,
    flex = _a.flex,
    icon = _a.icon,
    checkable = _a.checkable,
    checkedStatus = _a.checkedStatus,
    checkboxLabel = _a.checkboxLabel,
    onCheck = _a.onCheck,
    reversed = _a.reversed,
    sortingRaw = _a.sorting,
    // I can't say for certain why "nowrap" was the default value. Normally you wouldn't
    // want to clip off information because it doesn't fit on one line.
    // My assumption is that because since the cell width rows are decoupled, a heading
    // cell with a word longer than the column width would push the columns out of
    // alignment? I'm not sure.
    // Anyway, we can override this default behaviour by setting wrapping to "wrap".
    _c = _a.wrapping,
    // I can't say for certain why "nowrap" was the default value. Normally you wouldn't
    // want to clip off information because it doesn't fit on one line.
    // My assumption is that because since the cell width rows are decoupled, a heading
    // cell with a word longer than the column width would push the columns out of
    // alignment? I'm not sure.
    // Anyway, we can override this default behaviour by setting wrapping to "wrap".
    wrapping = _c === void 0 ? 'nowrap' : _c,
    _d = _a.align,
    align = _d === void 0 ? 'start' : _d,
    tooltipInfo = _a.tooltipInfo,
    _e = _a.isTooltipIconHidden,
    isTooltipIconHidden = _e === void 0 ? false : _e,
    tooltipPortalSelector = _a.tooltipPortalSelector,
    sortingArrowsOnHover = _a.sortingArrowsOnHover,
    classNameOverride = _a.classNameOverride,
    // There aren't any other props in the type definition, so I'm unsure why we
    // have this spread.
    otherProps = __rest(_a, ["labelText", "onClick", "href", "width", "flex", "icon", "checkable", "checkedStatus", "checkboxLabel", "onCheck", "reversed", "sorting", "wrapping", "align", "tooltipInfo", "isTooltipIconHidden", "tooltipPortalSelector", "sortingArrowsOnHover", "classNameOverride"]);
  var sorting = sortingRaw;
  var _f = React.useState(false),
    isHovered = _f[0],
    setIsHovered = _f[1];
  var updateHoverState = function (hoverState) {
    if (sortingArrowsOnHover && hoverState != isHovered) setIsHovered(hoverState);
  };
  var headerColor = reversed ? 'white-reduced-opacity' : 'dark-reduced-opacity';
  var hoveredHeaderColor = reversed ? 'white' : 'dark';
  // For this "cellContents" variable, we start at the inner most child, and
  // wrap it elements, depending on what the props dictate.
  var cellContents = /*#__PURE__*/React.createElement("div", {
    className: styles.headerRowCellLabelAndIcons
  }, icon && (/*#__PURE__*/React.createElement("span", {
    className: styles.headerRowCellIcon
  }, /*#__PURE__*/cloneElement(icon, (_b = {
    title: labelText
  }, _b['aria-label'] = labelText, _b.role = 'img', _b)))), checkable && (/*#__PURE__*/React.createElement("div", {
    className: styles.headerRowCellCheckbox
  }, /*#__PURE__*/React.createElement(Checkbox, {
    checkedStatus: checkedStatus,
    onCheck: onCheck,
    "aria-label": checkboxLabel
  }))), tooltipInfo != null && !isTooltipIconHidden ? (/*#__PURE__*/React.createElement("div", {
    className: styles.headerRowCellTooltipIcon
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "error",
    isPresentational: true,
    isFilled: true
  }))) : null, !icon ? (/*#__PURE__*/React.createElement(Heading, {
    tag: "div",
    variant: "heading-6",
    color: sorting || isHovered ? hoveredHeaderColor : headerColor,
    classNameOverride: styles.headerRowCellLabel
  }, labelText)) : null, (sorting !== null && sorting !== void 0 ? sorting : isHovered && sortingArrowsOnHover) && (/*#__PURE__*/React.createElement("div", {
    className: classnames(align === 'center' && styles.headerRowCellIconAlignCenter, align === 'end' && styles.headerRowCellIconAlignEnd, reversed && styles.whiteText)
  }, sorting === 'ascending' || sortingArrowsOnHover === 'ascending' ? (/*#__PURE__*/React.createElement(Icon, {
    name: "arrow_drop_up",
    isPresentational: true
  })) : (/*#__PURE__*/React.createElement(Icon, {
    name: "arrow_drop_down",
    isPresentational: true
  })))));
  cellContents = href ? (/*#__PURE__*/React.createElement("a", {
    className: classnames(styles.headerRowCellButton, reversed && styles.headerRowCellButtonReversed),
    href: href,
    onClick: onClick,
    onMouseEnter: function () {
      return updateHoverState(true);
    },
    onFocus: function () {
      return updateHoverState(true);
    },
    onMouseLeave: function () {
      return updateHoverState(false);
    },
    onBlur: function () {
      return updateHoverState(false);
    }
  }, cellContents)) : onClick ? (/*#__PURE__*/React.createElement("button", {
    type: "button",
    className: classnames(styles.headerRowCellButton, reversed && styles.headerRowCellButtonReversed),
    onClick: onClick,
    onMouseEnter: function () {
      return updateHoverState(true);
    },
    onFocus: function () {
      return updateHoverState(true);
    },
    onMouseLeave: function () {
      return updateHoverState(false);
    },
    onBlur: function () {
      return updateHoverState(false);
    }
  }, cellContents)) : (
  /*#__PURE__*/
  // This div wrapper probably isn't needed, but it's a bit easier
  // for this flex positioning, to have the dom tree depth match for
  // each permutation.
  React.createElement("div", {
    className: styles.headerRowCellNoButton
  }, cellContents));
  cellContents = tooltipInfo != null ? (/*#__PURE__*/React.createElement(Tooltip, {
    animationDuration: 0,
    classNameOverride: styles.headerRowCellTooltip,
    text: tooltipInfo,
    portalSelector: tooltipPortalSelector
  }, cellContents)) : (
  /*#__PURE__*/
  // Again, this wrapper is just to make the dom tree consistent between
  // different permutations.
  React.createElement("div", {
    className: styles.headerRowCellTooltip
  }, cellContents));
  return /*#__PURE__*/React.createElement("div", __assign({
    className: classnames(styles.headerRowCell, wrapping === 'nowrap' && styles.headerRowCellNoWrap, align === 'center' && styles.headerRowCellAlignCenter, align === 'end' && styles.headerRowCellAlignEnd, sorting && styles.headerRowCellActive, classNameOverride),
    style: {
      width: ratioToPercent(width),
      flex: flex
    },
    role: "columnheader"
  }, otherProps), cellContents);
};
var TableCard = function (_a) {
  var children = _a.children,
    expanded = _a.expanded,
    _b = _a.expandedStyle,
    expandedStyle = _b === void 0 ? 'well' : _b,
    onClick = _a.onClick,
    href = _a.href,
    _c = _a.forceHoverState,
    forceHoverState = _c === void 0 ? false : _c,
    classNameOverride = _a.classNameOverride,
    otherProps = __rest(_a, ["children", "expanded", "expandedStyle", "onClick", "href", "forceHoverState", "classNameOverride"]);
  var className = classnames(styles.card, expanded && styles.expanded, expanded && styles[expandedStyle], (forceHoverState || onClick != null || href != null) && styles.hasHoverState, classNameOverride);
  return href != null ? (/*#__PURE__*/React.createElement("a", __assign({
    href: href,
    className: className,
    onClick: onClick
  }, otherProps), children)) : onClick ? (/*#__PURE__*/React.createElement("button", __assign({
    type: "button",
    className: className,
    onClick: onClick
  }, otherProps), children)) : (/*#__PURE__*/React.createElement("div", __assign({
    className: className
  }, otherProps), children));
};
var TableRow = function (_a) {
  var children = _a.children,
    classNameOverride = _a.classNameOverride,
    otherProps = __rest(_a, ["children", "classNameOverride"]);
  return /*#__PURE__*/React.createElement("div", __assign({
    className: classnames(styles.row, classNameOverride),
    role: "row"
  }, otherProps), children);
};
var TableRowCell = function (_a) {
  var children = _a.children,
    width = _a.width,
    flex = _a.flex,
    href = _a.href,
    classNameOverride = _a.classNameOverride,
    otherProps = __rest(_a, ["children", "width", "flex", "href", "classNameOverride"]);
  return href != null ? (/*#__PURE__*/React.createElement("a", __assign({
    // eslint-disable-next-line jsx-a11y/no-interactive-element-to-noninteractive-role
    role: "cell",
    style: {
      width: ratioToPercent(width),
      flex: flex
    },
    className: classnames(styles.rowCell, classNameOverride),
    href: href
  }, otherProps), children)) : (/*#__PURE__*/React.createElement("div", __assign({
    role: "cell",
    style: {
      width: ratioToPercent(width),
      flex: flex
    },
    className: classnames(styles.rowCell, classNameOverride)
  }, otherProps), children));
};
export { TableCard, TableContainer, TableHeader, TableHeaderRowCell, TableRow, TableRowCell };
