import { __rest, __assign } from 'tslib';
import React, { useRef, useState } from 'react';
import { Tab as Tab$1 } from '@reach/tabs';
import classnames from 'classnames';
import { useFocusable } from 'react-aria';
import { Badge } from '../../Badge/Badge.mjs';
import styles from './Tab.module.scss.mjs';

/**
 * A tab button
 */
var Tab = function (props) {
  var isSelected = props.isSelected,
    badge = props.badge,
    disabled = props.disabled,
    children = props.children,
    classNameOverride = props.classNameOverride,
    restProps = __rest(props, ["isSelected", "badge", "disabled", "children", "classNameOverride"]);
  var ref = useRef(null);
  var _a = useState(false),
    isHovered = _a[0],
    setIsHovered = _a[1];
  var _b = useState(false),
    isFocused = _b[0],
    setIsFocused = _b[1];
  var showActiveBadge = Boolean(isSelected || isHovered || isFocused);
  var tabProps = __assign({
    disabled: disabled,
    className: classnames(styles.tab, classNameOverride, isSelected && styles.selected),
    onFocus: function (event) {
      var _a;
      setIsFocused(true);
      (_a = props.onFocus) === null || _a === void 0 ? void 0 : _a.call(props, event);
    },
    onBlur: function (event) {
      var _a;
      setIsFocused(false);
      (_a = props.onBlur) === null || _a === void 0 ? void 0 : _a.call(props, event);
    },
    onMouseEnter: function () {
      return setIsHovered(true);
    },
    onMouseLeave: function () {
      return setIsHovered(false);
    }
  }, restProps);
  var focusableProps = useFocusable(tabProps, ref).focusableProps;
  // Reach is setting and managing tabIndex for us here, so we remove it from the focusableProps (also it needs to be non-defined, undefined is not enough)
  delete focusableProps.tabIndex;
  return /*#__PURE__*/React.createElement(Tab$1, __assign({
    ref: ref
  }, tabProps, focusableProps), children, badge && (/*#__PURE__*/React.createElement("span", {
    className: styles.badge
  }, /*#__PURE__*/React.createElement(Badge, {
    variant: showActiveBadge ? 'active' : 'default'
  }, badge))));
};
export { Tab };
