import { __rest, __assign } from 'tslib';
import React, { useId } from 'react';
import classnames from 'classnames';
import { FieldGroup } from '../FieldGroup/FieldGroup.mjs';
import { FieldMessage } from '../FieldMessage/FieldMessage.mjs';
import { Input } from '../Input/Input/Input.mjs';
import '../Input/InputRange/InputRange.mjs';
import '../Input/InputSearch/InputSearch.mjs';
import { Label } from '../Label/Label.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
import styles from './TextField.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081928705/Text+Field Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-text-field--docs Storybook}
 */
const TextField = /*#__PURE__*/function () {
  const TextField = function (_a) {
    var propsId = _a.id,
      labelText = _a.labelText,
      _b = _a.inline,
      inline = _b === void 0 ? false : _b,
      icon = _a.icon,
      validationMessage = _a.validationMessage,
      description = _a.description,
      status = _a.status,
      _c = _a.reversed,
      reversed = _c === void 0 ? false : _c,
      disabled = _a.disabled,
      restProps = __rest(_a, ["id", "labelText", "inline", "icon", "validationMessage", "description", "status", "reversed", "disabled"]);
    var fallbackId = useId();
    var id = propsId !== null && propsId !== void 0 ? propsId : fallbackId;
    var validationMessageAria = validationMessage ? "".concat(id, "-field-validation-message") : '';
    var descriptionAria = description ? "".concat(id, "-field-description") : '';
    var ariaDescribedBy = [validationMessageAria, descriptionAria].reduce(function (prev, curr) {
      return curr ? [curr, prev].join(' ') : prev;
    }, '');
    return /*#__PURE__*/React.createElement(FieldGroup, {
      id: "".concat(id, "-field-group"),
      "data-testid": "".concat(id, "-field-group"),
      inline: inline,
      classNameOverride: classnames(reversed && styles.reversed)
    }, /*#__PURE__*/React.createElement(Label, {
      id: "".concat(id, "-field-label"),
      "data-testid": "".concat(id, "-field-label"),
      htmlFor: "".concat(id, "-field-input"),
      labelText: labelText,
      reversed: reversed,
      disabled: disabled
    }), /*#__PURE__*/React.createElement(Input, __assign({
      id: "".concat(id, "-field-input"),
      "data-testid": "".concat(id, "-field-input"),
      "aria-describedby": ariaDescribedBy,
      classNameOverride: styles.input,
      disabled: disabled,
      reversed: reversed,
      status: status,
      startIconAdornment: icon,
      endIconAdornment: status === 'success' && (/*#__PURE__*/React.createElement("div", {
        className: classnames(styles.icon, styles.success, disabled && styles.disabled)
      }, /*#__PURE__*/React.createElement(Icon, {
        name: "check_circle",
        isPresentational: true,
        isFilled: true
      })))
    }, restProps)), validationMessage && (/*#__PURE__*/React.createElement("div", {
      className: classnames(styles.message, disabled && styles.disabled)
    }, /*#__PURE__*/React.createElement(FieldMessage, {
      id: validationMessageAria,
      message: validationMessage,
      status: status,
      reversed: reversed
    }))), description && (/*#__PURE__*/React.createElement("div", {
      className: classnames(styles.message, disabled && styles.disabled)
    }, /*#__PURE__*/React.createElement(FieldMessage, {
      id: descriptionAria,
      message: description,
      reversed: reversed
    }))));
  };
  TextField.displayName = 'TextField';
  return TextField;
}();
export { TextField };
