import { __rest, __assign } from 'tslib';
import React, { useState, useRef, useEffect } from 'react';
import { useIntl } from '@cultureamp/i18n-react-intl';
import classnames from 'classnames';
import { Button } from '../../../Button/Button/Button.mjs';
import { IconButton } from '../../../Button/IconButton/IconButton.mjs';
import { Heading } from '../../../Heading/Heading.mjs';
import { Text } from '../../../Text/Text.mjs';
import { Icon } from '../../../__next__/Icon/Icon.mjs';
import styles from './GenericTile.module.scss.mjs';
const GenericTile = /*#__PURE__*/function () {
  const GenericTile = function (_a) {
    var children = _a.children,
      title = _a.title,
      _b = _a.titleTag,
      titleTag = _b === void 0 ? 'h3' : _b,
      metadata = _a.metadata,
      information = _a.information,
      infoButtonLabel = _a.infoButtonLabel,
      mood = _a.mood,
      _c = _a.variant,
      variant = _c === void 0 ? 'default' : _c,
      footer = _a.footer,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["children", "title", "titleTag", "metadata", "information", "infoButtonLabel", "mood", "variant", "footer", "classNameOverride"]);
    var _d = useState(),
      isFlipped = _d[0],
      setIsFlipped = _d[1];
    var formatMessage = useIntl().formatMessage;
    var infoButtonRef = useRef(null);
    var infoButtonReturnRef = useRef(null);
    useEffect(function () {
      if (isFlipped === true) return infoButtonReturnRef.current.focus();
      if (isFlipped === false) return infoButtonRef.current.focus();
    }, [isFlipped]);
    var translatedInfoLabel = formatMessage({
      id: 'kzGenericTile.infoButtonLabel',
      defaultMessage: 'View more information:',
      description: 'Prompts user to interact with button to reveal more information'
    });
    var renderTitle = function () {
      return /*#__PURE__*/React.createElement("div", {
        className: styles.title
      }, /*#__PURE__*/React.createElement(Heading, {
        variant: "heading-3",
        tag: titleTag
      }, title), metadata && (/*#__PURE__*/React.createElement("div", {
        className: styles.titleMeta
      }, /*#__PURE__*/React.createElement(Text, {
        variant: "small",
        color: "dark-reduced-opacity"
      }, metadata))));
    };
    var renderFront = function () {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(styles.face, styles.faceFront, mood ? styles[mood] : styles[variant])
      }, information && (/*#__PURE__*/React.createElement("div", {
        className: styles.informationBtn
      }, /*#__PURE__*/React.createElement(IconButton, {
        label: infoButtonLabel !== null && infoButtonLabel !== void 0 ? infoButtonLabel : "".concat(translatedInfoLabel, " ").concat(title),
        icon: /*#__PURE__*/React.createElement(Icon, {
          name: "info",
          isPresentational: true,
          isFilled: true
        }),
        onClick: function () {
          return setIsFlipped(true);
        },
        disabled: isFlipped,
        "aria-hidden": isFlipped,
        ref: infoButtonRef
      }))), renderTitle(), /*#__PURE__*/React.createElement("div", {
        className: styles.children
      }, children && children), footer && /*#__PURE__*/React.createElement("div", {
        className: styles.footer
      }, footer));
    };
    var renderInformation = function (informationProp) {
      var _a;
      if (informationProp && typeof informationProp === 'object' && 'text' in informationProp) {
        return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Text, {
          variant: "body"
        }, informationProp.text), ((_a = informationProp.primaryAction) !== null && _a !== void 0 ? _a : informationProp.secondaryAction) && (/*#__PURE__*/React.createElement("div", {
          className: styles.footer
        }, /*#__PURE__*/React.createElement("div", {
          className: styles.actions
        }, informationProp.secondaryAction && (/*#__PURE__*/React.createElement(Button, __assign({
          secondary: true,
          disabled: !isFlipped
        }, informationProp.secondaryAction))), informationProp.primaryAction && (/*#__PURE__*/React.createElement(Button, __assign({
          disabled: !isFlipped
        }, informationProp.primaryAction)))))));
      }
      return informationProp;
    };
    var renderBack = function () {
      if (!information) return null;
      var returnButtonLabel = formatMessage({
        id: 'kzGenericTile.infoButtonReturnLabel',
        defaultMessage: 'Hide information:',
        description: 'Prompts user to interact with button to hide information'
      });
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(styles.face, styles.faceBack)
      }, /*#__PURE__*/React.createElement("div", {
        className: styles.informationBtn
      }, /*#__PURE__*/React.createElement(IconButton, {
        label: "".concat(returnButtonLabel, " ").concat(title),
        icon: /*#__PURE__*/React.createElement(Icon, {
          name: "arrow_back",
          isPresentational: true
        }),
        onClick: function () {
          return setIsFlipped(false);
        },
        disabled: !isFlipped,
        "aria-hidden": !isFlipped,
        ref: infoButtonReturnRef
      })), /*#__PURE__*/React.createElement("div", {
        className: styles.information
      }, renderInformation(information)));
    };
    return /*#__PURE__*/React.createElement("div", __assign({
      className: classnames(styles.root, classNameOverride)
    }, restProps), /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.tile, isFlipped && styles.isFlipped)
    }, /*#__PURE__*/React.createElement(React.Fragment, null, renderFront(), renderBack())));
  };
  GenericTile.displayName = 'GenericTile';
  return GenericTile;
}();
export { GenericTile };
