import { __assign, __rest } from 'tslib';
import React, { useId } from 'react';
import { Time } from '@internationalized/date';
import { useTimeField } from '@react-aria/datepicker';
import { I18nProvider } from '@react-aria/i18n';
import { useTimeFieldState } from '@react-stately/datepicker';
import classnames from 'classnames';
import { FieldMessage } from '../FieldMessage/FieldMessage.mjs';
import { Label } from '../Label/Label.mjs';
import { TimeSegment } from './subcomponents/TimeSegment/TimeSegment.mjs';
import styles from './TimeField.module.scss.mjs';

// This needed to be placed directly below the props because
// the prop descriptions wouldn't show in Storybook otherwise.
const TimeField = /*#__PURE__*/function () {
  const TimeField = function (props) {
    return /*#__PURE__*/React.createElement(I18nProvider, {
      locale: props.locale
    }, /*#__PURE__*/React.createElement(TimeFieldComponent, __assign({}, props)));
  };
  TimeField.displayName = 'TimeField';
  return TimeField;
}();
const TimeFieldComponent = /*#__PURE__*/function () {
  const TimeFieldComponent = function (_a) {
    var propsId = _a.id,
      label = _a.label,
      locale = _a.locale,
      onChange = _a.onChange,
      value = _a.value,
      _b = _a.status,
      status = _b === void 0 ? 'default' : _b,
      validationMessage = _a.validationMessage,
      isDisabled = _a.isDisabled,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["id", "label", "locale", "onChange", "value", "status", "validationMessage", "isDisabled", "classNameOverride"]);
    var reactId = useId();
    var id = propsId !== null && propsId !== void 0 ? propsId : reactId;
    var handleOnChange = function (timeValue) {
      if (timeValue === null) {
        return onChange(null);
      }
      onChange({
        hour: timeValue.hour,
        minutes: timeValue.minute
      });
    };
    var state = useTimeFieldState(__assign(__assign({}, restProps), {
      value: value ? new Time(value.hour, value.minutes) : null,
      onChange: handleOnChange,
      isDisabled: isDisabled,
      hideTimeZone: true,
      locale: locale,
      validationState: status === 'default' ? 'valid' : 'invalid'
    }));
    var hasError = !!validationMessage && status === 'error';
    var descriptionId = hasError ? "".concat(id, "-field-message") : undefined;
    var inputRef = React.useRef(null);
    var _c = useTimeField(__assign(__assign({}, restProps), {
        label: label,
        isDisabled: isDisabled,
        'aria-describedby': descriptionId
      }), state, inputRef),
      fieldProps = _c.fieldProps,
      labelProps = _c.labelProps;
    return /*#__PURE__*/React.createElement("div", {
      className: classNameOverride
    }, /*#__PURE__*/React.createElement(Label, __assign({
      disabled: state.isDisabled
    }, labelProps, {
      classNameOverride: styles.label
    }), label), /*#__PURE__*/React.createElement("div", {
      className: styles.wrapper
    }, /*#__PURE__*/React.createElement("div", __assign({}, fieldProps, {
      id: id,
      ref: inputRef,
      className: classnames(styles.input, state.isDisabled && styles.isDisabled, state.validationState === 'invalid' && styles.error)
    }), state.segments.map(function (segment, i) {
      return /*#__PURE__*/React.createElement(TimeSegment, {
        key: i,
        segment: segment,
        state: state,
        hasPadding: ![8294, 8297].includes(segment.text.charCodeAt(0))
      });
    }), /*#__PURE__*/React.createElement("div", {
      className: styles.focusRing
    }))), hasError && /*#__PURE__*/React.createElement(FieldMessage, {
      id: descriptionId,
      message: validationMessage,
      status: status
    }));
  };
  TimeFieldComponent.displayName = 'TimeFieldComponent';
  return TimeFieldComponent;
}();
export { TimeField };
