import { __assign } from 'tslib';
import React, { useState, useCallback, useEffect } from 'react';
import classnames from 'classnames';
import { FocusOn } from 'react-focus-on';
import { MenuList, MenuHeading, MenuItem } from '../../Menu/index.mjs';
import { Icon } from '../../__next__/Icon/Icon.mjs';
import { TITLE_BLOCK_ZEN_OTHER_ACTIONS_HTML_ID } from '../constants.mjs';
import { isMenuGroupNotButton, convertSecondaryActionsToMenuItems } from '../utils.mjs';
import { TitleBlockMenuItem } from './TitleBlockMenuItem.mjs';
import styles from './MobileActions.module.scss.mjs';
var menuItemIsLink = function (item) {
  return 'href' in item;
};
var defaultActionIsLink = function (action) {
  return 'href' in action;
};
var defaultActionIsButton = function (action) {
  return !('href' in action) && 'onClick' in action || 'component' in action;
};
var filterActions = function (menuItems, filterType) {
  return menuItems.filter(function (item) {
    return filterType === 'link' ? menuItemIsLink(item) : !menuItemIsLink(item);
  });
};
/** Returns a filtered array of TitleBlockMenuItem based on actionType
 * This is use to sort a selectively render the action into a specifc order
 */
var renderPrimaryActionDrawerContent = function (primaryAction, actionType) {
  if (!primaryAction) return null;
  if (isMenuGroupNotButton(primaryAction)) {
    var filteredActions = filterActions(primaryAction.menuItems, actionType);
    return filteredActions.map(function (item, idx) {
      var itemType = menuItemIsLink(item) ? 'link' : 'action';
      return /*#__PURE__*/React.createElement(TitleBlockMenuItem, __assign({}, item, {
        key: "title-block-mobile-actions-primary-".concat(itemType, "-").concat(idx),
        "data-automation-id": "title-block-mobile-actions-primary-".concat(itemType, "-").concat(idx),
        "data-testid": "title-block-mobile-actions-primary-".concat(itemType, "-").concat(idx)
      }));
    });
  }
  return null;
};
var renderDefaultLink = function (defaultAction) {
  if (!defaultActionIsLink(defaultAction)) return;
  if ('component' in defaultAction) {
    return /*#__PURE__*/React.createElement(TitleBlockMenuItem, __assign({}, defaultAction, {
      key: "title-block-mobile-actions-default-link",
      "data-automation-id": "title-block-mobile-actions-default-link",
      "data-testid": "title-block-mobile-actions-default-link"
    }));
  }
  return /*#__PURE__*/React.createElement(MenuItem, {
    href: defaultAction.href,
    label: defaultAction.label,
    icon: defaultAction.icon,
    disabled: defaultAction.disabled,
    key: "title-block-mobile-actions-default-link",
    "data-automation-id": "title-block-mobile-actions-default-link",
    "data-testid": "title-block-mobile-actions-default-link",
    id: defaultAction.id
  });
};
var renderDefaultAction = function (defaultAction) {
  if (!defaultActionIsLink(defaultAction)) {
    return /*#__PURE__*/React.createElement(TitleBlockMenuItem, __assign({}, defaultAction, {
      key: "title-block-mobile-actions-default-action",
      "data-automation-id": "title-block-mobile-actions-default-action",
      "data-testid": "title-block-mobile-actions-default-action"
    }));
  }
  return null;
};
var renderSecondaryActions = function (secondaryActions) {
  if (!secondaryActions) return null;
  var secondaryActionMenuItems = convertSecondaryActionsToMenuItems(secondaryActions);
  return secondaryActionMenuItems.map(function (item, idx) {
    return /*#__PURE__*/React.createElement(TitleBlockMenuItem, __assign({}, item, {
      key: "title-block-mobile-actions-secondary-action-".concat(idx),
      "data-testid": "title-block-mobile-actions-secondary-action"
    }));
  });
};
var renderSecondaryOverflowMenuItems = function (secondaryOverflowMenuItems) {
  return secondaryOverflowMenuItems.map(function (item, idx) {
    return /*#__PURE__*/React.createElement(TitleBlockMenuItem, __assign({}, item, {
      key: "title-block-mobile-actions-overflow-menu-item-".concat(idx),
      "data-testid": "title-block-mobile-actions-overflow-menu-item"
    }));
  });
};
var DrawerMenuContent = function (_a) {
  var _b, _c, _d;
  var primaryAction = _a.primaryAction,
    defaultAction = _a.defaultAction,
    secondaryActions = _a.secondaryActions,
    secondaryOverflowMenuItems = _a.secondaryOverflowMenuItems;
  var showOtherActionsHeading = (_c = (_b = defaultAction && defaultActionIsButton(defaultAction)) !== null && _b !== void 0 ? _b : secondaryActions) !== null && _c !== void 0 ? _c : secondaryOverflowMenuItems;
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(MenuList, null, primaryAction && renderPrimaryActionDrawerContent(primaryAction, 'link'), defaultAction && renderDefaultLink(defaultAction), primaryAction && renderPrimaryActionDrawerContent(primaryAction, 'action')), ((_d = defaultAction !== null && defaultAction !== void 0 ? defaultAction : secondaryActions) !== null && _d !== void 0 ? _d : secondaryOverflowMenuItems) && (/*#__PURE__*/React.createElement(MenuList, {
    heading: showOtherActionsHeading ? /*#__PURE__*/React.createElement(MenuHeading, null, "Other actions") : undefined
  }, defaultAction && renderDefaultAction(defaultAction), secondaryActions && renderSecondaryActions(secondaryActions), secondaryOverflowMenuItems && renderSecondaryOverflowMenuItems(secondaryOverflowMenuItems))));
};
var renderDrawerHandleLabel = function (label, icon, drawerHandleLabelIconPosition) {
  if (drawerHandleLabelIconPosition === 'end') {
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
      className: styles.drawerHandleLabelText,
      "data-testid": "drawer-handle-lable-text"
    }, label), /*#__PURE__*/React.createElement(React.Fragment, null, icon && /*#__PURE__*/React.createElement("span", {
      className: styles.drawerHandleIcon
    }, icon)));
  } else {
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(React.Fragment, null, icon && /*#__PURE__*/React.createElement("span", {
      className: styles.drawerHandleIcon
    }, icon)), /*#__PURE__*/React.createElement("span", {
      className: styles.drawerHandleLabelText,
      "data-testid": "drawer-handle-lable-text"
    }, label));
  }
};
var ButtonOrLink = function (_a) {
  var action = _a.action,
    children = _a.children;
  if (typeof action === 'object' && 'onClick' in action && 'href' in action) {
    return /*#__PURE__*/React.createElement("a", {
      onClick: action.onClick,
      href: action.href,
      className: classnames(styles.mobileActionsPrimaryLabel, styles.mobileActionsPrimaryButton),
      "data-testid": "title-block-mobile-actions-primary-button"
    }, children);
  }
  if (typeof action === 'function') {
    return /*#__PURE__*/React.createElement("button", {
      type: "button",
      onClick: action,
      className: classnames(styles.mobileActionsPrimaryLabel, styles.mobileActionsPrimaryButton),
      "data-testid": "title-block-mobile-actions-primary-button"
    }, children);
  }
  if (typeof action === 'string') {
    return /*#__PURE__*/React.createElement("a", {
      href: action,
      className: classnames(styles.mobileActionsPrimaryLabel, styles.mobileActionsPrimaryButton),
      "data-testid": "title-block-mobile-actions-primary-button"
    }, children);
  }
  // when there's no action (e.g. primary button is disabled)
  return /*#__PURE__*/React.createElement("button", {
    type: "button",
    className: classnames(styles.mobileActionsPrimaryLabel, styles.mobileActionsPrimaryButton),
    "data-testid": "title-block-mobile-actions-primary-button"
  }, children);
};
var getAction = function (primaryAction) {
  if (primaryAction && !primaryAction.disabled) {
    if (primaryAction.onClick && primaryAction.href) {
      return {
        href: primaryAction.href,
        onClick: primaryAction.onClick
      };
    }
    if (primaryAction.onClick) {
      return primaryAction.onClick;
    }
    if (primaryAction.href) {
      return primaryAction.href;
    }
  }
  return undefined;
};
var DrawerHandle = function (_a) {
  var _b;
  var primaryAction = _a.primaryAction,
    secondaryActions = _a.secondaryActions,
    defaultAction = _a.defaultAction,
    secondaryOverflowMenuItems = _a.secondaryOverflowMenuItems,
    drawerHandleLabelIconPosition = _a.drawerHandleLabelIconPosition,
    toggleDisplay = _a.toggleDisplay,
    isOpen = _a.isOpen;
  var showDrawer = (_b = defaultAction !== null && defaultAction !== void 0 ? defaultAction : secondaryActions) !== null && _b !== void 0 ? _b : secondaryOverflowMenuItems;
  if (primaryAction) {
    // If the primary action is a menu
    if (isMenuGroupNotButton(primaryAction)) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(styles.mobileActionsTopRow, styles.mobileActionsTopRowSingleButton),
        "data-testid": "title-block-mobile-actions-drawer-handle"
      }, /*#__PURE__*/React.createElement("button", {
        type: "button",
        className: classnames(styles.mobileActionsExpandButton, styles.mobileActionsPrimaryLabel),
        onClick: toggleDisplay,
        "aria-expanded": isOpen
      }, primaryAction.label, /*#__PURE__*/React.createElement("span", {
        className: styles.mobileActionsChevronSquare
      }, /*#__PURE__*/React.createElement(Icon, {
        name: isOpen ? 'keyboard_arrow_down' : 'keyboard_arrow_up',
        isPresentational: true
      }))));
    }
    // If the primary action is a button, or has no onClick/href/action
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.mobileActionsTopRow, !showDrawer && styles.mobileActionsTopRowSingleButton),
      "data-testid": "title-block-mobile-actions-drawer-handle"
    }, 'component' in primaryAction ? (/*#__PURE__*/React.createElement(primaryAction.component, __assign({
      className: classnames(styles.mobileActionsPrimaryLabel, styles.mobileActionsPrimaryButton)
    }, primaryAction), primaryAction.label && renderDrawerHandleLabel(primaryAction.label, primaryAction.icon, drawerHandleLabelIconPosition))) : (/*#__PURE__*/React.createElement(ButtonOrLink, {
      action: getAction(primaryAction)
    }, renderDrawerHandleLabel(primaryAction.label, primaryAction.icon, drawerHandleLabelIconPosition))), showDrawer && (/*#__PURE__*/React.createElement("button", {
      type: "button",
      className: styles.mobileActionsExpandButton,
      onClick: toggleDisplay,
      "aria-expanded": isOpen,
      id: TITLE_BLOCK_ZEN_OTHER_ACTIONS_HTML_ID,
      "aria-label": "Other actions"
    }, /*#__PURE__*/React.createElement(Icon, {
      name: isOpen ? 'keyboard_arrow_down' : 'keyboard_arrow_up',
      isPresentational: true
    }))));
  }
  // if there are default/secondary actions but no primary action
  if (showDrawer) {
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.mobileActionsTopRow, styles.mobileActionsTopRowSingleButton),
      "data-testid": "title-block-mobile-actions-drawer-handle"
    }, /*#__PURE__*/React.createElement("button", {
      type: "button",
      className: classnames(styles.mobileActionsExpandButton, styles.mobileActionsPrimaryLabel),
      onClick: toggleDisplay,
      "aria-expanded": isOpen,
      id: TITLE_BLOCK_ZEN_OTHER_ACTIONS_HTML_ID
    }, renderDrawerHandleLabel('Other actions'), /*#__PURE__*/React.createElement("span", {
      className: styles.mobileActionsChevronSquare
    }, /*#__PURE__*/React.createElement(Icon, {
      name: isOpen ? 'keyboard_arrow_down' : 'keyboard_arrow_up',
      isPresentational: true
    }))));
  }
  return null;
};
const MobileActions = /*#__PURE__*/function () {
  const MobileActions = function (_a) {
    var _b, _c;
    var primaryAction = _a.primaryAction,
      defaultAction = _a.defaultAction,
      secondaryActions = _a.secondaryActions,
      secondaryOverflowMenuItems = _a.secondaryOverflowMenuItems,
      drawerHandleLabelIconPosition = _a.drawerHandleLabelIconPosition,
      _d = _a.autoHide,
      autoHide = _d === void 0 ? false : _d;
    var _e = useState(false),
      isOpen = _e[0],
      setIsOpen = _e[1];
    var menuContent = /*#__PURE__*/React.createRef();
    var toggleDisplay = function () {
      setIsOpen(!isOpen);
    };
    // This callback handler will not run when autoHide === "off"
    var handleDocumentClickForAutoHide = useCallback(function (e) {
      var _a;
      if (isOpen && e.target instanceof Node && ((_a = menuContent.current) === null || _a === void 0 ? void 0 : _a.contains(e.target))) {
        setIsOpen(false);
      }
    },
    // @todo: Fix if possible - avoiding breaking in eslint upgrade
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [menuContent]);
    useEffect(function () {
      if (autoHide) {
        document.addEventListener('click', handleDocumentClickForAutoHide, true);
      }
      return function () {
        if (autoHide) {
          document.removeEventListener('click', handleDocumentClickForAutoHide, true);
        }
      };
    }, [autoHide, handleDocumentClickForAutoHide]);
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.mobileActionsContainer, isOpen && styles.isOpen)
    }, /*#__PURE__*/React.createElement(FocusOn, {
      enabled: isOpen,
      scrollLock: false
    }, /*#__PURE__*/React.createElement(DrawerHandle, {
      primaryAction: primaryAction,
      secondaryActions: secondaryActions,
      defaultAction: defaultAction,
      secondaryOverflowMenuItems: secondaryOverflowMenuItems,
      drawerHandleLabelIconPosition: drawerHandleLabelIconPosition,
      toggleDisplay: toggleDisplay,
      isOpen: isOpen
    }), ((_c = (_b = defaultAction !== null && defaultAction !== void 0 ? defaultAction : secondaryActions) !== null && _b !== void 0 ? _b : secondaryOverflowMenuItems) !== null && _c !== void 0 ? _c : primaryAction && isMenuGroupNotButton(primaryAction)) && (/*#__PURE__*/React.createElement("div", {
      ref: menuContent,
      className: styles.mobileActionsMenuContainer
    }, /*#__PURE__*/React.createElement(DrawerMenuContent, {
      primaryAction: primaryAction,
      defaultAction: defaultAction,
      secondaryActions: secondaryActions,
      secondaryOverflowMenuItems: secondaryOverflowMenuItems
    })))));
  };
  MobileActions.displayName = 'MobileActions';
  return MobileActions;
}();
export { MobileActions };
