import { __rest, __assign } from 'tslib';
import React, { useState } from 'react';
import { useDebouncedCallback } from 'use-debounce';
var ANIM_DURATION_MS = 400;
var AnimationContext = /*#__PURE__*/React.createContext({
  isVisible: false,
  isAnimIn: false,
  isAnimOut: false
});
/**
 * Simply applies a css animation to transition a component in and out.
 * When the component is no longer needed, it will no longer be rendered to the
 * dom.
 */
var AnimationProvider = function (_a) {
  var isVisible = _a.isVisible,
    _b = _a.animationDuration,
    animationDuration = _b === void 0 ? ANIM_DURATION_MS : _b,
    otherProps = __rest(_a, ["isVisible", "animationDuration"]);
  var _c = useState(false),
    isAnimIn = _c[0],
    setIsAnimIn = _c[1];
  var _d = useState(false),
    isAnimOut = _d[0],
    setIsAnimOut = _d[1];
  var _e = useState(false),
    prevIsOpen = _e[0],
    setPrevIsOpen = _e[1];
  // Keeps the modal visible while the css animation is completing
  var trackAnimOutCompleted = useDebouncedCallback(function () {
    setIsAnimOut(false);
  }, animationDuration, {
    leading: false
  });
  // Allows us to flash the component in an "invisible" state, for one frame.
  // Then set it to "visible". This allows us to make sure the css transition
  // actually works.
  var trackAnimInCompleted = useDebouncedCallback(function () {
    setIsAnimIn(false);
  }, 0, {
    leading: false
  });
  if (isVisible !== prevIsOpen) {
    setPrevIsOpen(isVisible);
    if (!isVisible) {
      trackAnimInCompleted.cancel();
      setIsAnimOut(true);
      trackAnimOutCompleted();
    } else {
      trackAnimOutCompleted.cancel();
      setIsAnimIn(true);
      trackAnimInCompleted();
    }
  }
  return /*#__PURE__*/React.createElement(AnimationContext.Provider, __assign({
    value: {
      isVisible: isVisible,
      isAnimOut: isAnimOut,
      isAnimIn: isAnimIn
    }
  }, otherProps));
};
var useAnimation = function () {
  var context = React.useContext(AnimationContext);
  if (!context) {
    throw new Error('useAnimation must be used within a AnimationProvider');
  }
  return context;
};
export { AnimationContext, AnimationProvider, useAnimation };
