import { __rest, __assign } from 'tslib';
import React, { useState, useRef, useId, useContext, useEffect } from 'react';
import classnames from 'classnames';
import { TabListStateContext, TabList as TabList$1 } from 'react-aria-components';
import { Icon } from '../../../Icon/Icon.mjs';
import { isRTL } from '../../../../utils/isRTL/isRTL.mjs';
import { SCROLL_AMOUNT } from '../../constants.mjs';
import styles from './TabList.module.css.mjs';

/**
 * Wrapper for the tabs themselves
 */
var TabList = function (props) {
  var ariaLabel = props["aria-label"],
    _a = props.noPadding,
    noPadding = _a === void 0 ? false : _a,
    children = props.children,
    className = props.className,
    testId = props["data-testid"],
    restProps = __rest(props, ['aria-label', "noPadding", "children", "className", 'data-testid']);
  var _b = useState(false),
    isDocumentReady = _b[0],
    setIsDocumentReady = _b[1];
  var _c = useState(false),
    leftArrowEnabled = _c[0],
    setLeftArrowEnabled = _c[1];
  var _d = useState(false),
    rightArrowEnabled = _d[0],
    setRightArrowEnabled = _d[1];
  var tabListRef = useRef(null);
  var tabListId = useId();
  var _e = useState(false),
    isRTL$1 = _e[0],
    setIsRTL = _e[1];
  var _f = useState(),
    containerElement = _f[0],
    setContainerElement = _f[1];
  var tabListContext = useContext(TabListStateContext);
  var selectedKey = tabListContext === null || tabListContext === void 0 ? void 0 : tabListContext.selectedKey;
  useEffect(function () {
    if (!isDocumentReady) {
      setIsDocumentReady(true);
      return;
    }
    var container = document.getElementById(tabListId);
    setContainerElement(container);
    setIsRTL(container ? isRTL(container) : false);
  }, [isDocumentReady, tabListId]);
  useEffect(function () {
    if (!isDocumentReady) {
      return;
    }
    var tabs = containerElement === null || containerElement === void 0 ? void 0 : containerElement.querySelectorAll('[data-kz-tab]');
    if (!tabs || tabs.length === 0) {
      return;
    }
    var firstTabObserver = new IntersectionObserver(function (entries) {
      if (!entries[0].isIntersecting) {
        setLeftArrowEnabled(true);
        return;
      }
      setLeftArrowEnabled(false);
    }, {
      threshold: 0.75,
      root: containerElement
    });
    firstTabObserver.observe(isRTL$1 ? tabs[tabs.length - 1] : tabs[0]);
    var lastTabObserver = new IntersectionObserver(function (entries) {
      if (!entries[0].isIntersecting) {
        setRightArrowEnabled(true);
        return;
      }
      setRightArrowEnabled(false);
    }, {
      threshold: 0.75,
      root: containerElement
    });
    lastTabObserver.observe(isRTL$1 ? tabs[0] : tabs[tabs.length - 1]);
    return function () {
      firstTabObserver.disconnect();
      lastTabObserver.disconnect();
    };
  }, [isDocumentReady, containerElement, isRTL$1]);
  useEffect(function () {
    var _a;
    if (!isDocumentReady) {
      return;
    }
    // Scroll selected tab into view
    (_a = containerElement === null || containerElement === void 0 ? void 0 : containerElement.querySelector('[role="tab"][data-selected=true]')) === null || _a === void 0 ? void 0 : _a.scrollIntoView({
      block: 'nearest',
      inline: 'center'
    });
  }, [selectedKey, containerElement, isDocumentReady]);
  var handleArrowPress = function (direction) {
    if (tabListRef.current) {
      var tabListScrollPos = tabListRef.current.scrollLeft;
      var newSpot = direction === 'left' ? tabListScrollPos - SCROLL_AMOUNT : tabListScrollPos + SCROLL_AMOUNT;
      tabListRef.current.scrollLeft = newSpot;
    }
  };
  return /*#__PURE__*/React.createElement("div", {
    className: styles.container,
    id: tabListId
  }, leftArrowEnabled && (
  /*#__PURE__*/
  // making a conscious decision to use <div onClick> over <button> here, because:
  // - <button> would add pointless noise for a screen reader user
  // - keyboard only user can toggle through tabs with left/right arrow keys already
  // eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions
  React.createElement("div", {
    onClick: function () {
      return handleArrowPress('left');
    },
    className: styles.leftArrow,
    "data-testid": testId ? "".concat(testId, "-kz-tablist-left-arrow") : undefined
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "chevron_left",
    isPresentational: true
  }))), /*#__PURE__*/React.createElement(TabList$1, __assign({
    "aria-label": ariaLabel,
    ref: tabListRef,
    className: classnames(styles.tabList, className, noPadding && styles.noPadding)
  }, restProps), children), rightArrowEnabled && (
  /*#__PURE__*/
  // eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions
  React.createElement("div", {
    onClick: function () {
      return handleArrowPress('right');
    },
    className: styles.rightArrow,
    "data-testid": testId ? "".concat(testId, "-kz-tablist-right-arrow") : undefined
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "chevron_right",
    isPresentational: true
  }))));
};
export { TabList };
