import { __assign } from 'tslib';
import React, { useMemo, useState, useEffect } from 'react';
var subtractOnePixel = function (breakpoint) {
  return "".concat(parseInt(breakpoint, 10) - 1, "px");
};
var useMediaQueries = function (propQueries) {
  if (propQueries === void 0) {
    propQueries = {};
  }
  if (typeof window === 'undefined') {
    return {
      queries: {
        isSmall: false,
        isMedium: false,
        isLarge: false,
        isMediumOrSmaller: false,
        isMediumOrLarger: true
      },
      components: {
        SmallOnly: function () {
          return /*#__PURE__*/React.createElement(React.Fragment, null);
        },
        MediumOnly: function () {
          return /*#__PURE__*/React.createElement(React.Fragment, null);
        },
        LargeOnly: function () {
          return /*#__PURE__*/React.createElement(React.Fragment, null);
        },
        MediumOrSmaller: function () {
          return /*#__PURE__*/React.createElement(React.Fragment, null);
        },
        MediumOrLarger: function (props) {
          return /*#__PURE__*/React.createElement(React.Fragment, null, props.children);
        }
      }
    };
  }
  // Ensure these match the tokens in @kaizen/design-tokens
  var breakpoints = {
    medium: '768px',
    large: '1080px'
  };
  // The `addEventListener` calls blow up legacy Edge (<= v18/pre chromium),
  // so we disable the functionality of updating after page load.
  var isLegacyEdge = /Edge/.exec(navigator.userAgent);
  var isUnsupportedSafari = window.matchMedia('').addEventListener === undefined;
  // ---------------------------------------
  // Create Kaizen breakpoint matches for initial state
  // ---------------------------------------
  var smallMatchMedia = useMemo(function () {
    return window.matchMedia("(max-width: ".concat(subtractOnePixel(breakpoints.medium), ")"));
  }, [breakpoints.medium]);
  var mediumMatchMedia = useMemo(function () {
    return window.matchMedia("(min-width: ".concat(breakpoints.medium, ") and (max-width: ").concat(subtractOnePixel(breakpoints.large), ")"));
  }, [breakpoints.large]);
  var largeMatchMedia = useMemo(function () {
    return window.matchMedia("(min-width: ".concat(breakpoints.large, ")"));
  }, [breakpoints.large]);
  var isSmall = smallMatchMedia.matches || false;
  var isMedium = mediumMatchMedia.matches || false;
  var isLarge = largeMatchMedia.matches || false;
  var _a = useState({
      isSmall: isSmall,
      isMedium: isMedium,
      isLarge: isLarge,
      isMediumOrSmaller: !isLarge,
      isMediumOrLarger: !isSmall
      // Note: ^the last two will need an adjustment in logic if/when we add more breakpoints
    }),
    kaizenMatches = _a[0],
    setKaizenMatches = _a[1];
  // ---------------------------------------
  // Create an event listener based on the small and large breakpoints and update state whenever one of those changes
  // ---------------------------------------
  useEffect(function () {
    if (isLegacyEdge || isUnsupportedSafari) {
      return;
    }
    var updateMatches = function () {
      var isSmallAfterUpdate = smallMatchMedia.matches || false;
      var isMediumAfterUpdate = mediumMatchMedia.matches || false;
      var isLargeAfterUpdate = largeMatchMedia.matches || false;
      setKaizenMatches({
        isSmall: isSmallAfterUpdate,
        isMedium: isMediumAfterUpdate,
        isLarge: isLargeAfterUpdate,
        isMediumOrSmaller: !isLargeAfterUpdate,
        isMediumOrLarger: !isSmallAfterUpdate
      });
    };
    smallMatchMedia.addEventListener('change', updateMatches, true);
    largeMatchMedia.addEventListener('change', updateMatches, true);
    return function () {
      smallMatchMedia.removeEventListener('change', updateMatches);
      largeMatchMedia.removeEventListener('change', updateMatches);
    };
  }, []);
  // ---------------------------------------
  // Create custom queries matches for initial state
  // ---------------------------------------
  var customQueryMatchMedias = new Map();
  var customQueryMatches = {};
  new Map(Object.entries(propQueries)).forEach(function (queryString, queryName) {
    var matchMedia = window.matchMedia(queryString);
    customQueryMatches[queryName] = matchMedia.matches || false;
    // Store this matchMedia so that we can loop over it later and add event listeners
    customQueryMatchMedias.set(queryName, matchMedia);
  });
  var _b = useState(customQueryMatches),
    customMatches = _b[0],
    setCustomMatches = _b[1];
  // ---------------------------------------
  // Create an event listener for each custom query
  // ---------------------------------------
  useEffect(function () {
    if (isLegacyEdge || isUnsupportedSafari) {
      return;
    }
    var updateCustomMatches = function (matchMedia, queryName) {
      var _a;
      return setCustomMatches(__assign(__assign({}, customQueryMatches), (_a = {}, _a[queryName] = matchMedia.matches || false, _a)));
    };
    var allEventListeners = new Map();
    customQueryMatchMedias.forEach(function (matchMedia, queryName) {
      // Store this method so that we can reference it in the cleanup function below
      var updateCustomMatchesForQuery = function () {
        updateCustomMatches(matchMedia, queryName);
      };
      allEventListeners.set(matchMedia, updateCustomMatchesForQuery);
      // Add the event listener
      matchMedia.addEventListener('change', updateCustomMatchesForQuery, true);
    });
    return function () {
      allEventListeners.forEach(function (eventListener, matchMedia) {
        matchMedia.removeEventListener('change', eventListener);
      });
    };
  }, []);
  var kaizenComponents = {
    SmallOnly: function (props) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, kaizenMatches.isSmall && props.children);
    },
    MediumOnly: function (props) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, kaizenMatches.isMedium && props.children);
    },
    LargeOnly: function (props) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, kaizenMatches.isLarge && props.children);
    },
    MediumOrSmaller: function (props) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, kaizenMatches.isMediumOrSmaller && props.children);
    },
    MediumOrLarger: function (props) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, kaizenMatches.isMediumOrLarger && props.children);
    }
  };
  // ---------------------------------------
  // Create custom query helper components
  // ---------------------------------------
  var customComponents = {};
  Object.keys(propQueries).map(function (key) {
    var componentName = key.charAt(0).toUpperCase() + key.slice(1);
    customComponents[componentName] = function (props) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, customMatches[key] && props.children);
    };
  });
  return {
    queries: __assign(__assign({}, kaizenMatches), customQueryMatches),
    components: __assign(__assign({}, kaizenComponents), customComponents)
  };
};
export { subtractOnePixel, useMediaQueries };
