import { useRef, useState, useCallback, useEffect } from 'react';
import ResizeObserver from 'resize-observer-polyfill';
var defaultCallback = function (entry) {
  return entry;
};
/**
 * Hook for observing changes to a DOM element via ResizeObserver.
 *
 * @param {resolveEntryCallback} resolveEntry - Callback for resolving the
 * desired value from each ResizeObserverEntry emitted by ResizeObserver
 * @return {Array} An array containing a ref for binding to the observed DOM
 * element, and the current value of the callback-resolved ResizeObserverEntry
 * @callback resolveEntryCallback
 * @deprecated use native `ResizeObserver` DOM API instead
 */
var useResizeObserver = function (resolveEntry) {
  if (resolveEntry === void 0) {
    resolveEntry = defaultCallback;
  }
  var destroyResizeObserverRef = useRef(undefined);
  var _a = useState(undefined),
    dimensions = _a[0],
    setDimensions = _a[1];
  var resolveEntryRef = useRef(resolveEntry);
  var ref = useCallback(function (node) {
    if (node) {
      var resizeObserver_1 = new ResizeObserver(function (entries) {
        for (var _i = 0, entries_1 = entries; _i < entries_1.length; _i++) {
          var entry = entries_1[_i];
          var value = resolveEntryRef.current(entry);
          if (value) {
            setDimensions(value);
          }
        }
      });
      resizeObserver_1.observe(node);
      destroyResizeObserverRef.current = function () {
        resizeObserver_1.disconnect();
      };
    }
  }, [destroyResizeObserverRef, setDimensions, resolveEntryRef]);
  // Ensure the resolveEntryRef has the latest value
  useEffect(function () {
    resolveEntryRef.current = resolveEntry;
  }, [resolveEntry]);
  // Destroy the observer on unmount
  useEffect(function () {
    return function () {
      if (destroyResizeObserverRef.current) {
        destroyResizeObserverRef.current();
      }
    };
  }, []);
  return [ref, dimensions];
};
export { useResizeObserver };
