import { type HTMLAttributes, type PropsWithChildren } from 'react';
import { type OverrideClassName } from "../types/OverrideClassName";
type BadgeCommonProps = PropsWithChildren<{
    /**
     * The "dark" variant is no longer in the UI kit
     */
    variant?: 'default' | 'active' | 'dark';
    /**
     * renders reversed colors. Use on purple background
     */
    reversed?: boolean;
    /**
     * Supports "small" and "large" sizes - defaults to "small"
     */
    size?: 'small' | 'large';
}> & OverrideClassName<HTMLAttributes<HTMLSpanElement>>;
type DotProps = Omit<BadgeCommonProps, 'variant'> & {
    children?: never;
    variant: 'dot';
};
export type BadgeProps = BadgeCommonProps | DotProps;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3064857333/Badge Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-badge--docs Storybook}
 */
export declare const Badge: {
    ({ children, variant, reversed, size, classNameOverride, ...restProps }: BadgeProps): JSX.Element;
    displayName: string;
};
export declare const BadgeAnimated: (props: BadgeProps) => JSX.Element;
export {};
