import { type HTMLAttributes, type ReactElement, type ReactNode } from 'react';
import { type ButtonProps } from "../Button";
import { type SceneProps } from "../Illustration";
import { type OverrideClassName } from "../types/OverrideClassName";
type DeprecatedMoodProps = {
    /** @deprecated Use `variant` instead */
    mood: 'informative' | 'positive' | 'negative';
    variant?: never;
};
type VariantProps = {
    /**
     * If you are transitioning from `mood`:
     * - `informative` remains as `informative`
     * - `positive` should be `success`
     * - `negative` should be `warning`
     */
    variant: 'informative' | 'success' | 'warning';
    /** @deprecated Use `variant` instead */
    mood?: never;
};
export type BrandMomentProps = {
    illustration: ReactElement<SceneProps>;
    header: ReactNode;
    body?: ReactNode;
    primaryAction?: ButtonProps;
    secondaryAction?: ButtonProps;
    text: {
        title: ReactNode;
        subtitle?: ReactNode;
        body?: ReactNode;
        footer?: ReactNode;
    };
} & OverrideClassName<HTMLAttributes<HTMLDivElement>> & (DeprecatedMoodProps | VariantProps);
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082061589/Brand+Moment Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-brand-moment--docs Storybook}
 */
export declare const BrandMoment: {
    ({ mood, variant, illustration, header, body, primaryAction, secondaryAction, text, classNameOverride, ...restProps }: BrandMomentProps): JSX.Element;
    displayName: string;
};
export {};
