import { type RefObject } from 'react';
import { type DateRange } from 'react-day-picker';
import { type DisabledDayMatchers } from "../Calendar";
import { type LegacyCalendarRangeProps } from "../Calendar/LegacyCalendarRange";
export type DateRangePickerProps = {
    id?: string;
    classNameOverride?: string;
    labelText: string;
    isDisabled?: boolean;
    buttonRef?: RefObject<HTMLButtonElement>;
    description?: string;
    /**
     * Selected date range which is being updated in handleDayClick and checked
     * if within range/not disabled and then passed back to the client to update
     * the state.
     */
    selectedDateRange?: DateRange;
    /**
     * String that is formatted by the client with our helper formatDateRangeValue
     * and then passed into the button to display the readable range.
     */
    value?: string;
    /**
     * Accepts a DayOfWeek value to start the week on that day.
     * By default it adapts to the provided locale.
     */
    weekStartsOn?: LegacyCalendarRangeProps['weekStartsOn'];
    /**
     * Accepts a date to display that month on first render.
     */
    defaultMonth?: LegacyCalendarRangeProps['defaultMonth'];
    /**
     * Event passed from consumer to handle the date on change.
     */
    onChange: (dateRange: DateRange) => void;
} & DisabledDayMatchers;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082094237/Date+Range+Picker Guidance} |
 * {@link https://cultureamp.design/storybook/?path=/docs/components-date-controls-daterangepicker--docs Storybook}
 */
export declare const DateRangePicker: {
    ({ id: propsId, buttonRef, description: _description, labelText, isDisabled, classNameOverride, disabledDates, disabledDaysOfWeek, disabledRange, disabledBeforeAfter, disabledBefore, disabledAfter, weekStartsOn, defaultMonth, selectedDateRange, value, onChange, ...inputProps }: DateRangePickerProps): JSX.Element;
    displayName: string;
};
