import { type HTMLAttributes } from 'react';
import { type CalendarSingleProps, type DisabledDays } from "../../../../Calendar";
import { type DateInputDescriptionProps } from "../../../../DateInput";
import { type DatePickerSupportedLocales } from "../../../../DatePicker/utils/getLocale";
import { type FilterProps } from "../../../Filter";
import { type DataAttributes } from "../../../../types/DataAttributes";
import { type OverrideClassName } from "../../../../types/OverrideClassName";
import { type DateValidationResponse, type ValidationMessage } from '../../types';
import { type DateInputFieldProps } from '../DateInputField';
type FilterInputProps<InputProps> = Omit<Partial<InputProps>, 'value'> & DataAttributes;
export type FilterDatePickerFieldProps = {
    id?: string;
    locale: DatePickerSupportedLocales;
    /**
     * Sets first displayed month to month of provided date if there isn't a date set.
     */
    defaultMonth?: CalendarSingleProps['defaultMonth'];
    /**
     * The date range passed in from the consumer that renders in the inputs and calendar.
     */
    selectedDate: Date | undefined;
    /**
     * Callback when date is updated either by the calendar picker or by typing and blurring.
     * Date will return as `undefined` if empty, invalid or disabled.
     */
    onDateChange: (date: Date | undefined) => void;
    /**
     * Callback when date is saved/committed/submitted valid date by either by the calendar picker or by typing and blurring.
     * Date will return as `undefined` if empty, invalid or disabled.
     *
     * Distinctly different from `change` where that is triggered on any kind of event, we expect the final valid date in this function.
     */
    onDateSubmit?: (date: Date | undefined) => void;
    /**
     * See https://react-day-picker.js.org/api/types/Matcher
     */
    disabledDays?: DisabledDays;
    inputProps?: FilterInputProps<DateInputFieldProps>;
    /**
     * Custom description to provide extra context (input format help text remains).
     */
    description?: DateInputDescriptionProps['description'];
    validationMessage?: ValidationMessage;
    /**
     * Callback when a date is selected. Utilises internal validation if not set.
     */
    onValidate?: (validationResponse: DateValidationResponse) => void;
    setIsFilterOpen?: FilterProps['setIsOpen'];
} & OverrideClassName<HTMLAttributes<HTMLDivElement>>;
export declare const FilterDatePickerField: ({ id: propsId, inputProps, locale: propsLocale, defaultMonth, selectedDate, onDateChange, onDateSubmit, disabledDays, description, validationMessage, onValidate, classNameOverride, ...restProps }: FilterDatePickerFieldProps) => JSX.Element;
export {};
