import { type HTMLAttributes } from 'react';
import { type CalendarRangeProps, type DateRange, type DisabledDays } from "../../../../Calendar";
import { type DatePickerSupportedLocales } from "../../../../DatePicker/utils/getLocale";
import { type DateValidationResponse } from "../../../FilterDatePicker";
import { type DataAttributes } from "../../../../types/DataAttributes";
import { type OverrideClassName } from "../../../../types/OverrideClassName";
import { type DateRangeInputFieldProps } from '../DateRangeInputField';
import { type DateRangeFieldValidationMessage } from './types';
type InputStartDateProps = DateRangeInputFieldProps['inputStartDateProps'];
type InputEndDateProps = DateRangeInputFieldProps['inputEndDateProps'];
type FilterInputProps<InputProps> = Omit<Partial<InputProps>, 'value'> & DataAttributes;
export type FilterDateRangePickerFieldProps = {
    id: string;
    label: string;
    locale: DatePickerSupportedLocales;
    /**
     * Sets first displayed month to month of provided date if there isn't a date set.
     */
    defaultMonth?: CalendarRangeProps['defaultMonth'];
    /**
     * The date range passed in from the consumer that renders in the inputs and calendar.
     */
    selectedRange: DateRange | undefined;
    /**
     * Callback when date is updated either by the calendar picker or by typing and blurring.
     * Date will return as `undefined` if empty, invalid or disabled.
     */
    onRangeChange: (range: DateRange | undefined) => void;
    /**
     * See https://react-day-picker.js.org/api/types/Matcher
     */
    disabledDays?: DisabledDays;
    inputStartDateProps?: FilterInputProps<InputStartDateProps>;
    inputEndDateProps?: FilterInputProps<InputEndDateProps>;
    /**
     * Custom description to provide extra context (input format help text remains).
     */
    description?: DateRangeInputFieldProps['description'];
    validationMessage?: DateRangeFieldValidationMessage;
    /**
     * Callback when a date is selected. Utilises internal validation if not set.
     */
    onValidate?: {
        dateStart?: (validationResponse: DateValidationResponse) => void;
        dateEnd?: (validationResponse: DateValidationResponse) => void;
    };
} & OverrideClassName<HTMLAttributes<HTMLDivElement>>;
export declare const FilterDateRangePickerField: {
    ({ id, label, locale: propsLocale, defaultMonth, selectedRange, onRangeChange, disabledDays, inputStartDateProps, inputEndDateProps, description, validationMessage, onValidate, classNameOverride, ...restProps }: FilterDateRangePickerFieldProps): JSX.Element;
    displayName: string;
};
export {};
