import { type HTMLAttributes } from 'react';
import { type OverrideClassName } from "../types/OverrideClassName";
export type HeadingVariants = 'display-0' | 'composable-header-title' | 'heading-1' | 'heading-2' | 'heading-3' | 'heading-4' | 'heading-5' | 'heading-6';
export type AllowedHeadingTags = 'pre' | 'p' | 'div' | 'span' | 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6' | 'label';
export type AllowedHeadingColors = 'dark' | 'dark-reduced-opacity' | 'white' | 'white-reduced-opacity' | 'positive' | 'negative';
export type HeadingProps = {
    children: React.ReactNode;
    /**
     * HTML elements that are allowed on Headings. When not supplied, the tag is inferred from
     * the variant. E.g. display-0 will infer h1
     */
    tag?: AllowedHeadingTags;
    /**
     * Allowed heading variants
     */
    variant: HeadingVariants;
    color?: AllowedHeadingColors;
} & OverrideClassName<HTMLAttributes<HTMLElement>>;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3074885298/Typography#Headings Guidance}
 * {@link https://cultureamp.design/?path=/docs/components-typography-heading--display-0 Storybook}
 */
export declare const Heading: {
    ({ children, tag, variant, color, classNameOverride, ...restProps }: HeadingProps): JSX.Element;
    displayName: string;
};
