import React, { type SyntheticEvent } from 'react';
export type StatelessMenuProps = {
    /**
     * Whether the menu is to be used on the left or right
     * side of the viewport. If left, the left of the dropdown
     * is aligned to the left of the button (and vice versa)
     * @default "left"
     */
    'align'?: 'left' | 'right';
    /**
     * The width of the dropdown.
     * "default": a fixed width of 248px
     * "contain": contain the children's width (will be same width as children)
     * @default "default"
     */
    'dropdownWidth'?: 'default' | 'contain';
    /**
     * @deprecated use data-testid instead
     */
    'automationId'?: string;
    'data-testid'?: string;
    'dropdownId'?: string;
    /**
     * Determines when the menu should automatically hide.
     * @default: "on"
     */
    'autoHide'?: 'on' | 'outside-click-only' | 'off';
    /**
     * The content to appear inside the dropdown when it is open
     */
    'children': React.ReactNode;
    /**
     * Render the tooltip inside a react portal, given the CSS selector.
     * This is typically used for instances where the menu is a descendant of an
     * `overflow: scroll` or `overflow: hidden` element.
     */
    'portalSelector'?: string;
    'isMenuVisible': boolean;
    'toggleMenuDropdown': () => void;
    'hideMenuDropdown': () => void;
    'renderButton': (args: {
        'onClick': (e: any) => void;
        'onMouseDown': (e: any) => void;
        'aria-haspopup': boolean;
        'aria-expanded': boolean;
    }) => React.ReactElement;
    'onClick'?: (event: SyntheticEvent) => void;
};
export declare const StatelessMenu: {
    ({ align, dropdownWidth, autoHide, "data-testid": dataTestId, dropdownId, children, portalSelector, isMenuVisible, toggleMenuDropdown, hideMenuDropdown, renderButton, onClick, }: StatelessMenuProps): JSX.Element;
    displayName: string;
};
