import React, { type HTMLAttributes } from 'react';
export type ContextModalSecondaryActionProps = {
    secondaryLabel: string;
    onSecondaryAction: () => void;
} | {
    secondaryLabel?: undefined;
    onSecondaryAction?: never;
};
export type ContextModalProps = Readonly<{
    isOpen: boolean;
    unpadded?: boolean;
    /**
     * Defines the orientation layout of the image and content
     */
    layout?: 'portrait' | 'landscape';
    title: string;
    onConfirm?: () => void;
    onDismiss: () => void;
    /** A callback that is triggered after the modal is opened. */
    onAfterEnter?: () => void;
    /** A callback that is triggered after the modal is closed. */
    onAfterLeave?: () => void;
    confirmLabel?: string;
    confirmWorking?: {
        label: string;
        labelHidden?: boolean;
    };
    /**
     * @deprecated use data-testid instead
     */
    automationId?: string;
    renderBackground?: () => React.ReactNode;
    image?: React.ReactNode;
    children: React.ReactNode;
    contentHeader?: React.ReactNode;
} & ContextModalSecondaryActionProps & HTMLAttributes<HTMLDivElement>>;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093114/Modal Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-modals--contextmodal--docs Storybook}
 */
export declare const ContextModal: {
    ({ isOpen, unpadded, layout, title, onConfirm, onDismiss: propsOnDismiss, onAfterLeave, onAfterEnter, confirmLabel, confirmWorking, renderBackground, children, contentHeader, image, secondaryLabel, onSecondaryAction, className, ...props }: ContextModalProps): JSX.Element;
    displayName: string;
};
