import React, { type HTMLAttributes } from 'react';
import { type OverrideClassName } from "../types/OverrideClassName";
import { type Placement, type PopoverSize, type PopoverVariant } from './types';
export type PopoverProps = {
    children: React.ReactNode;
    /**
     * @deprecated We are no longer supporting different variants for Popover, instead there will only be a single default variant.
     */
    variant?: PopoverVariant;
    placement?: Placement;
    size?: PopoverSize;
    heading?: string;
    dismissible?: boolean;
    onClose?: (event: React.MouseEvent<HTMLButtonElement>) => void;
    singleLine?: boolean;
    /**
     * @deprecated This was for customising the icon provided with variants.
     */
    customIcon?: JSX.Element;
    referenceElement: HTMLElement | null;
} & OverrideClassName<HTMLAttributes<HTMLDivElement>>;
/**
 * {@link https://cultureamp.design/components/popover/ Guidance} |
 * {@link https://cultureamp.design/storybook/?path=/docs/components-popover--default-kaizen-site-demo Storybook}
 */
export declare const Popover: {
    ({ children, variant, placement, size, heading, dismissible, onClose, singleLine, customIcon, referenceElement, classNameOverride, ...restProps }: PopoverProps): JSX.Element;
    displayName: string;
};
type PopoverPropsWithoutRef = Omit<PopoverProps, 'referenceElement'>;
/**
 * How to use:
 *
 * const [referenceElementRef, Popover] = usePopover()
 *
 * return (<>
 *   <button ref={referenceElementRef}>
 *     Hello world
 *   </button>
 *   <Popover>Hello world</Popover>
 * </>)
 *
 * The purpose of this hook is to abstract away some of the awkwardness with the
 * requirement of passing in refs with popper. We need to use `useState` instead
 * of `useRef`, which may not be immediately intuitive.
 *
 * The popper documentation to help provide more context:
 *   https://popper.js.org/react-popper/v2/hook/
 */
export declare const usePopover: () => [(element: HTMLElement | null) => void, (props: PopoverPropsWithoutRef) => JSX.Element | null];
export {};
