import { type HTMLAttributes } from 'react';
import { type OverrideClassName } from "../types/OverrideClassName";
export type ProgressBarMood = {
    /**
     * @deprecated Use `color` prop instead
     */
    mood: 'positive' | 'informative' | 'negative' | 'cautionary';
    color?: never;
};
export type ProgressBarColor = {
    /**
     * @deprecated Use `color` prop instead
     */
    mood?: never;
    /**
     * If transitioning from `mood`:
     * - `cautionary` -> `yellow`
     * - `informative` -> `blue`
     * - `negative` -> `red`
     * - `positive` -> `green`
     */
    color: 'blue' | 'green' | 'red' | 'yellow';
};
export type ProgressBarBaseProps = {
    /** A value that represents completed progress */
    value: number;
    /** A value that sets the maximum progress that can be achieved */
    max: number;
    /** Adds an animated state to indicate loading progress */
    isAnimating: boolean;
    subtext?: string;
    label?: string;
    isReversed: boolean;
} & OverrideClassName<Omit<HTMLAttributes<HTMLDivElement>, 'color'>>;
export type ProgressBarProps = ProgressBarBaseProps & (ProgressBarMood | ProgressBarColor);
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896891/Progress+Bar Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-progress-bar--docs Storybook}
 */
export declare const ProgressBar: {
    ({ value, max, isAnimating, mood, color, subtext, label, classNameOverride, isReversed, ...restProps }: ProgressBarProps): JSX.Element;
    displayName: string;
};
