import { type InputHTMLAttributes } from 'react';
import { type OverrideClassName } from "../../types/OverrideClassName";
export type RadioProps = OverrideClassName<Omit<InputHTMLAttributes<HTMLInputElement>, 'id' | 'name' | 'value' | 'checked' | 'type'>> & {
    /** Required to ensure the Radio always gets an ID to match a label when composed. */
    id: string;
    /** Unique identifier for the group this Radio belongs to. Required for keyboard navigation of the group. See also [Defining a radio group](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input/radio#defining_a_radio_group) on MDN. E.g. the question ID for which this is one possible answer to. */
    name: string;
    /** The value for this form field when this radio button is selected. */
    value?: string | readonly string[] | number;
    selectedStatus?: boolean;
    reversed?: boolean;
};
export declare const Radio: {
    ({ name, value, selectedStatus, reversed, onChange, classNameOverride, ...restProps }: RadioProps): JSX.Element;
    displayName: string;
};
