import React from 'react';
import { type UseFloatingReturn } from '@floating-ui/react-dom';
import { type SelectProps as AriaSelectProps } from '@react-stately/select';
import { type Key } from '@react-types/shared';
import { type OverrideClassName } from "../../types/OverrideClassName";
import { type SelectPopoverContentsProps, type SelectToggleProps } from './subcomponents';
import { type SelectItem, type SelectOption } from './types';
type OmittedAriaSelectProps = 'children' | 'items';
export type SelectProps<Option extends SelectOption = SelectOption> = {
    /**
     * Item objects in the collection.
     */
    items: SelectItem<Option>[];
    id?: string;
    trigger?: (selectToggleProps: SelectToggleProps & {
        ref: UseFloatingReturn<HTMLButtonElement>['refs']['setReference'];
    }, ref: UseFloatingReturn<HTMLButtonElement>['refs']['setReference']) => JSX.Element;
    children?: SelectPopoverContentsProps<Option>['children'];
    /**
     * Updates the styling of the validation FieldMessage.
     */
    status?: 'error' | 'caution';
    /**
     * A descriptive message for the 'status' states.
     */
    validationMessage?: React.ReactNode | undefined;
    /**
     * Use the `reversed` styles.
     */
    isReversed?: boolean;
    /**
     * Use the `fullWidth` styles.
     */
    isFullWidth?: boolean;
    /**
     * @deprecated: Either define `disabled` in your `Option` (in `items`), or use `disabledKeys`
     */
    disabledValues?: Key[];
    /**
     * Creates a portal for the Popover to the matching element id
     */
    portalContainerId?: string;
    /**
     * @deprecated Use of placeholder text goes against our a11y standards.
     * Use the `labelText` prop to provide a concise name, and the `description` prop for any help text.
     */
    placeholder?: string;
} & OverrideClassName<Omit<AriaSelectProps<Option>, OmittedAriaSelectProps>>;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896474/Select Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-select--docs Storybook}
 */
export declare const Select: {
    <Option extends SelectOption = SelectOption>({ label, items, id: propsId, trigger, children, status, validationMessage, isReversed, isFullWidth, disabledValues, classNameOverride, selectedKey, description, placeholder, isDisabled, portalContainerId, ...restProps }: SelectProps<Option>): JSX.Element;
    displayName: string;
    Section: {
        <Option extends SelectOption = SelectOption>({ section, }: import("./subcomponents").ListBoxSectionProps<Option>): JSX.Element;
        displayName: string;
    };
    SectionDivider: {
        (): JSX.Element;
        displayName: string;
    };
    Option: {
        <Option extends SelectOption = SelectOption>({ item, classNameOverride, ...props }: import("./subcomponents").OptionProps<Option>): JSX.Element;
        displayName: string;
    };
    ItemDefaultRender: {
        <Option extends SelectOption = SelectOption>({ item, }: import("./subcomponents").ListItemProps<Option>): JSX.Element;
        displayName: string;
    };
    TriggerButton: React.ForwardRefExoticComponent<{
        label: React.ReactNode;
        labelProps: import("@react-types/shared").DOMAttributes<import("@react-types/shared").FocusableElement>;
        value: React.ReactNode;
        valueProps: import("@react-types/shared").DOMAttributes<import("@react-types/shared").FocusableElement>;
        isOpen?: boolean;
        placeholder?: string;
        status?: "error" | "caution";
        isDisabled?: boolean;
        isReversed?: boolean;
    } & Omit<React.HTMLAttributes<HTMLButtonElement>, "className"> & {
        classNameOverride?: string;
    } & React.RefAttributes<HTMLButtonElement>>;
    ListBox: {
        <Option extends SelectOption>({ children, menuProps, classNameOverride, ...restProps }: import("./subcomponents").SingleListBoxProps<Option>): JSX.Element;
        displayName: string;
    };
};
export {};
