import React from 'react'
import { render, waitFor } from '@testing-library/react'
import userEvent from '@testing-library/user-event'
import { vi } from 'vitest'
import { type CheckboxProps } from './Checkbox'
import { Checkbox } from '.'
const user = userEvent.setup()

const defaultProps = {
  id: 'someCheckboxId',
  checkedStatus: 'off',
  disabled: false,
  name: 'someCheckboxName',
  onCheck: vi.fn(),
} satisfies CheckboxProps

describe('<Checkbox />', () => {
  it('calls the `onCheck` event when clicked', async () => {
    const { getByTestId } = render(<Checkbox {...defaultProps} data-testid="checkbox" />)
    const checkbox = getByTestId('checkbox')

    await user.click(checkbox)
    await waitFor(() => {
      expect(defaultProps.onCheck).toHaveBeenCalledTimes(1)
    })
  })
})
