import React from 'react'
import { type Meta } from '@storybook/react'
import { Avatar } from '~components/Avatar'
import { StickerSheet, type StickerSheetStory } from '~storybook/components/StickerSheet'
import { Tag } from '../index'
import { TagVariants } from '../types'

export default {
  title: 'Components/Tag/Tag (deprecated)',
  parameters: {
    chromatic: { disable: false },
    controls: { disable: true },
    a11y: {
      config: {
        rules: [
          {
            // Known issue as we do not have a "presentational" Avatar yet
            // But the use case in this stickersheet is valid.
            id: 'image-redundant-alt',
            enabled: false,
          },
        ],
      },
    },
  },
} satisfies Meta

const StickerSheetTemplate: StickerSheetStory = {
  render: ({ isReversed }) => (
    <StickerSheet isReversed={isReversed} headers={['Default', 'Dismissable']}>
      {TagVariants.map((variant) => (
        <StickerSheet.Row key={variant} header={variant}>
          <>
            <Tag variant={variant}>Tag</Tag>
            <Tag variant={variant} size="small">
              Small
            </Tag>
          </>
          <>
            <Tag variant={variant} dismissible={variant !== 'statusLive'}>
              Tag
            </Tag>
            <Tag variant={variant} size="small" dismissible={variant !== 'statusLive'}>
              Small
            </Tag>
          </>
        </StickerSheet.Row>
      ))}
      <StickerSheet.Row header="Avatar">
        <Tag
          variant="profile"
          avatar={
            <Avatar
              size="small"
              avatarSrc="https://www.cultureampcom-preview-1.usw2.wp-dev-us.cultureamp-cdn.com/assets/slices/main/assets/public/media/chapters-card-1@2x.05e547444387f29f14df0b82634bf2b6.png"
              fullName="Jane Doe"
            />
          }
        >
          Jane Doe
        </Tag>
        <Tag
          variant="profile"
          avatar={
            <Avatar
              size="small"
              avatarSrc="https://www.cultureampcom-preview-1.usw2.wp-dev-us.cultureamp-cdn.com/assets/slices/main/assets/public/media/chapters-card-1@2x.05e547444387f29f14df0b82634bf2b6.png"
              fullName="Jane Doe"
            />
          }
          dismissible
        >
          Jane Doe
        </Tag>
      </StickerSheet.Row>
    </StickerSheet>
  ),
}

export const StickerSheetDefault: StickerSheetStory = {
  ...StickerSheetTemplate,
  name: 'Sticker Sheet (Default)',
}

export const StickerSheetReversed: StickerSheetStory = {
  ...StickerSheetTemplate,
  name: 'Sticker Sheet (Reversed)',
  parameters: {
    backgrounds: { default: 'Purple 700' },
  },
  args: { isReversed: true },
}

export const StickerSheetRTL: StickerSheetStory = {
  ...StickerSheetTemplate,
  name: 'Sticker Sheet (RTL)',
  parameters: {
    textDirection: 'rtl',
  },
}
